% postproccessing on gibbs sampler results for Bayesian CEV models for
% multivariate interest rate swap rates of various maturities



%% results using full sample

% load saved samples of parameters
d=load('mu_full_panel_chain1.txt');
T8=size(d,1);
mu_sample=reshape(d(:,2),T8/8,8);
d=load('rho_full_panel_chain1.txt');
rho_sample=reshape(d(:,2),T8/8,8);
d=load('sigma_full_panel_chain1.txt');
sigma_sample=reshape(d(:,2),T8/8,8);
d=load('gamma_full_panel_chain1.txt');
gamma_sample=d(:,2);
d=load('nu_full_panel_chain1.txt');
nu_sample=reshape(d(:,2),T8/8,8);

% transform mu and rho parameter draws into draws of mu and kappa
kappa_sample=1-rho_sample;
theta_sample=mu_sample./kappa_sample;

% compute some simple statistics
mean_theta=mean(theta_sample);
median_theta=median(theta_sample);
p025_theta=prctile(theta_sample,2.5);
p975_theta=prctile(theta_sample,97.5);
std_theta=std(theta_sample);

mean_kappa=mean(kappa_sample);
median_kappa=median(kappa_sample);
p025_kappa=prctile(kappa_sample,2.5);
p975_kappa=prctile(kappa_sample,97.5);
std_kappa=std(kappa_sample);

mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);
p025_sigma=prctile(sigma_sample,2.5);
p975_sigma=prctile(sigma_sample,97.5);
std_sigma=std(sigma_sample);

mean_gamma=mean(gamma_sample);
median_gamma=median(gamma_sample);
p025_gamma=prctile(gamma_sample,2.5);
p975_gamma=prctile(gamma_sample,97.5);
std_gamma=std(gamma_sample);

mean_nu=mean(nu_sample);
median_nu=median(nu_sample);
p025_nu=prctile(nu_sample,2.5);
p975_nu=prctile(nu_sample,97.5);
std_nu=std(nu_sample);

NM=8;
NV=5;
medians=[median_theta;median_kappa;median_sigma;median_gamma*ones(1,NM);median_nu];
p025=[p025_theta;p025_kappa;p025_sigma;p025_gamma*ones(1,NM);p025_nu];
p975=[p975_theta;p975_kappa;p975_sigma;p975_gamma*ones(1,NM);p975_nu];
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'theta','kappa','sigma','gamma','nu'};


% save posterior medians and posterior 95% confidence intervals into a file
fid=fopen('irswap_bcev4_panel_full_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','Posterior Median',...
    'Posterior 2.5th percentile','Posterior 97.5th percentile');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            medians(j,i),p025(j,i),p975(j,i));
    end
end
fclose(fid);

% kernel-smoothed density plots of posterior marginal densities
NMC=size(nu_sample,1);
NK=100;
% all maturity-dependent densities
% theta
ksd_theta=NaN(NM,NK);
xsd_theta=NaN(NM,NK);
for i=1:NM
    lb=prctile(theta_sample(:,i),2.5);
    ub=prctile(theta_sample(:,i),97.5);
    il=find(theta_sample(:,i)>lb);
    gsample=theta_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_theta(i,:),xsd_theta(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_theta(i,:),ksd_theta(i,:),'r-','LineWidth',2);
    xlabel('\theta');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=['theta_',swap_maturity{i},'_fullpanel_ksd'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% kappa
ksd_kappa=NaN(NM,NK);
xsd_kappa=NaN(NM,NK);
for i=1:NM
    lb=prctile(kappa_sample(:,i),2.5);
    ub=prctile(kappa_sample(:,i),97.5);
    il=find(kappa_sample(:,i)>lb);
    gsample=kappa_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_kappa(i,:),xsd_kappa(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_kappa(i,:),ksd_kappa(i,:),'r-','LineWidth',2);
    xlabel('\kappa');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=['kappa_',swap_maturity{i},'_fullpanel_ksd'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% sigma
ksd_sigma=NaN(NM,NK);
xsd_sigma=NaN(NM,NK);
for i=1:NM
    lb=prctile(sigma_sample(:,i),2.5);
    ub=prctile(sigma_sample(:,i),97.5);
    il=find(sigma_sample(:,i)>lb);
    gsample=sigma_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_sigma(i,:),xsd_sigma(i,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
    figure;
    plot(xsd_sigma(i,:),ksd_sigma(i,:),'r-','LineWidth',2);
    xlabel('\sigma');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=['sigma_',swap_maturity{i},'_fullpanel_ksd'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% nu
ksd_nu=NaN(NM,NK);
xsd_nu=NaN(NM,NK);
for i=1:NM
    lb=prctile(nu_sample(:,i),2.5);
    ub=prctile(nu_sample(:,i),97.5);
    il=find(nu_sample(:,i)>lb);
    gsample=nu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_nu(i,:),xsd_nu(i,:)]=ksdensity(fsample,'npoints',NK,'support',[2,30]);
    figure;
    plot(xsd_nu(i,:),ksd_nu(i,:),'r-','LineWidth',2);
    xlabel('\nu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=['nu_',swap_maturity{i},'_fullpanel_ksd'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% gamma is not maturity dependent
ksd_gamma=NaN(3,NK); % for 3 sub-samples
xsd_gamma=NaN(3,NK);
lb=prctile(gamma_sample,2.5);
ub=prctile(gamma_sample,97.5);
il=find(gamma_sample>lb);
gsample=gamma_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_gamma(1,:),xsd_gamma(1,:)]=ksdensity(fsample,'npoints',NK,'support',[-1.001,2.001]);
figure;
plot(xsd_gamma(1,:),ksd_gamma(1,:),'r-','LineWidth',2);
xlabel('\gamma');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (full sample)']);
filename=['gamma_fullpanel_ksd'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

save irswap_bcev4_fullpanel_postprocess.mat

%% results using last 4 years

% load saved samples of parameters
d=load('mu_sample4_panel_chain1.txt');
T8=size(d,1);
mu_sample=reshape(d(:,2),T8/8,8);
d=load('rho_sample4_panel_chain1.txt');
rho_sample=reshape(d(:,2),T8/8,8);
d=load('sigma_sample4_panel_chain1.txt');
sigma_sample=reshape(d(:,2),T8/8,8);
d=load('gamma_sample4_panel_chain1.txt');
gamma_sample=d(:,2);
d=load('nu_sample4_panel_chain1.txt');
nu_sample=reshape(d(:,2),T8/8,8);

% transform mu and rho parameter draws into draws of mu and kappa
kappa_sample=1-rho_sample;
theta_sample=mu_sample./kappa_sample;

% compute some simple statistics
mean_theta=mean(theta_sample);
median_theta=median(theta_sample);
p025_theta=prctile(theta_sample,2.5);
p975_theta=prctile(theta_sample,97.5);
std_theta=std(theta_sample);

mean_kappa=mean(kappa_sample);
median_kappa=median(kappa_sample);
p025_kappa=prctile(kappa_sample,2.5);
p975_kappa=prctile(kappa_sample,97.5);
std_kappa=std(kappa_sample);

mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);
p025_sigma=prctile(sigma_sample,2.5);
p975_sigma=prctile(sigma_sample,97.5);
std_sigma=std(sigma_sample);

mean_gamma=mean(gamma_sample);
median_gamma=median(gamma_sample);
p025_gamma=prctile(gamma_sample,2.5);
p975_gamma=prctile(gamma_sample,97.5);
std_gamma=std(gamma_sample);

mean_nu=mean(nu_sample);
median_nu=median(nu_sample);
p025_nu=prctile(nu_sample,2.5);
p975_nu=prctile(nu_sample,97.5);
std_nu=std(nu_sample);

NM=8;
NV=5;
medians=[median_theta;median_kappa;median_sigma;median_gamma*ones(1,NM);median_nu];
p025=[p025_theta;p025_kappa;p025_sigma;p025_gamma*ones(1,NM);p025_nu];
p975=[p975_theta;p975_kappa;p975_sigma;p975_gamma*ones(1,NM);p975_nu];
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'theta','kappa','sigma','gamma','nu'};


% save posterior medians and posterior 95% confidence intervals into a file
fid=fopen('irswap_bcev4_panel_sample4_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','Posterior Median',...
    'Posterior 2.5th percentile','Posterior 97.5th percentile');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            medians(j,i),p025(j,i),p975(j,i));
    end
end
fclose(fid);

% kernel-smoothed density plots of posterior marginal densities
NMC=size(nu_sample,1);
NK=100;
% all maturity-dependent densities
% theta
ksd_theta=NaN(NM,NK);
xsd_theta=NaN(NM,NK);
for i=1:NM
    lb=prctile(theta_sample(:,i),2.5);
    ub=prctile(theta_sample(:,i),97.5);
    il=find(theta_sample(:,i)>lb);
    gsample=theta_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_theta(i,:),xsd_theta(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_theta(i,:),ksd_theta(i,:),'r-','LineWidth',2);
    xlabel('\theta');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=['theta_',swap_maturity{i},'_sample4_panel_ksd'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% kappa
ksd_kappa=NaN(NM,NK);
xsd_kappa=NaN(NM,NK);
for i=1:NM
    lb=prctile(kappa_sample(:,i),2.5);
    ub=prctile(kappa_sample(:,i),97.5);
    il=find(kappa_sample(:,i)>lb);
    gsample=kappa_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_kappa(i,:),xsd_kappa(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_kappa(i,:),ksd_kappa(i,:),'r-','LineWidth',2);
    xlabel('\kappa');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=['kappa_',swap_maturity{i},'_sample4_panel_ksd'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% sigma
ksd_sigma=NaN(NM,NK);
xsd_sigma=NaN(NM,NK);
for i=1:NM
    lb=prctile(sigma_sample(:,i),2.5);
    ub=prctile(sigma_sample(:,i),97.5);
    il=find(sigma_sample(:,i)>lb);
    gsample=sigma_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_sigma(i,:),xsd_sigma(i,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
    figure;
    plot(xsd_sigma(i,:),ksd_sigma(i,:),'r-','LineWidth',2);
    xlabel('\sigma');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=['sigma_',swap_maturity{i},'_sample4_panel_ksd'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% nu
ksd_nu=NaN(NM,NK);
xsd_nu=NaN(NM,NK);
for i=1:NM
    lb=prctile(nu_sample(:,i),2.5);
    ub=prctile(nu_sample(:,i),97.5);
    il=find(nu_sample(:,i)>lb);
    gsample=nu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_nu(i,:),xsd_nu(i,:)]=ksdensity(fsample,'npoints',NK,'support',[2,30]);
    figure;
    plot(xsd_nu(i,:),ksd_nu(i,:),'r-','LineWidth',2);
    xlabel('\nu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=['nu_',swap_maturity{i},'_sample4_panel_ksd'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% gamma is not maturity dependent
lb=prctile(gamma_sample,2.5);
ub=prctile(gamma_sample,97.5);
il=find(gamma_sample>lb);
gsample=gamma_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_gamma(2,:),xsd_gamma(2,:)]=ksdensity(fsample,'npoints',NK,'support',[-1.001,2.001]);
figure;
plot(xsd_gamma(2,:),ksd_gamma(2,:),'r-','LineWidth',2);
xlabel('\gamma');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (4-year sample)']);
filename=['gamma__sample4_panel_ksd'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

save irswap_bcev4_sample4_panel_postprocess.mat

%% results using last 1 year

% load saved samples of parameters
d=load('mu_sample1_panel_chain1.txt');
T8=size(d,1);
mu_sample=reshape(d(:,2),T8/8,8);
d=load('rho_sample1_panel_chain1.txt');
rho_sample=reshape(d(:,2),T8/8,8);
d=load('sigma_sample1_panel_chain1.txt');
sigma_sample=reshape(d(:,2),T8/8,8);
d=load('gamma_sample1_panel_chain1.txt');
gamma_sample=d(:,2);
d=load('nu_sample1_panel_chain1.txt');
nu_sample=reshape(d(:,2),T8/8,8);

% transform mu and rho parameter draws into draws of mu and kappa
kappa_sample=1-rho_sample;
theta_sample=mu_sample./kappa_sample;

% compute some simple statistics
mean_theta=mean(theta_sample);
median_theta=median(theta_sample);
p025_theta=prctile(theta_sample,2.5);
p975_theta=prctile(theta_sample,97.5);
std_theta=std(theta_sample);

mean_kappa=mean(kappa_sample);
median_kappa=median(kappa_sample);
p025_kappa=prctile(kappa_sample,2.5);
p975_kappa=prctile(kappa_sample,97.5);
std_kappa=std(kappa_sample);

mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);
p025_sigma=prctile(sigma_sample,2.5);
p975_sigma=prctile(sigma_sample,97.5);
std_sigma=std(sigma_sample);

mean_gamma=mean(gamma_sample);
median_gamma=median(gamma_sample);
p025_gamma=prctile(gamma_sample,2.5);
p975_gamma=prctile(gamma_sample,97.5);
std_gamma=std(gamma_sample);

mean_nu=mean(nu_sample);
median_nu=median(nu_sample);
p025_nu=prctile(nu_sample,2.5);
p975_nu=prctile(nu_sample,97.5);
std_nu=std(nu_sample);

NM=8;
NV=5;
medians=[median_theta;median_kappa;median_sigma;median_gamma*ones(1,NM);median_nu];
p025=[p025_theta;p025_kappa;p025_sigma;p025_gamma*ones(1,NM);p025_nu];
p975=[p975_theta;p975_kappa;p975_sigma;p975_gamma*ones(1,NM);p975_nu];
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'theta','kappa','sigma','gamma','nu'};


% save posterior medians and posterior 95% confidence intervals into a file
fid=fopen('irswap_bcev4_panel_sample1_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','Posterior Median',...
    'Posterior 2.5th percentile','Posterior 97.5th percentile');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            medians(j,i),p025(j,i),p975(j,i));
    end
end
fclose(fid);

% kernel-smoothed density plots of posterior marginal densities
NMC=size(nu_sample,1);
NK=100;
% all maturity-dependent densities
% theta
ksd_theta=NaN(NM,NK);
xsd_theta=NaN(NM,NK);
for i=1:NM
    lb=prctile(theta_sample(:,i),2.5);
    ub=prctile(theta_sample(:,i),97.5);
    il=find(theta_sample(:,i)>lb);
    gsample=theta_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_theta(i,:),xsd_theta(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_theta(i,:),ksd_theta(i,:),'r-','LineWidth',2);
    xlabel('\theta');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=['theta_',swap_maturity{i},'_sample1_panel_ksd'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% kappa
ksd_kappa=NaN(NM,NK);
xsd_kappa=NaN(NM,NK);
for i=1:NM
    lb=prctile(kappa_sample(:,i),2.5);
    ub=prctile(kappa_sample(:,i),97.5);
    il=find(kappa_sample(:,i)>lb);
    gsample=kappa_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_kappa(i,:),xsd_kappa(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_kappa(i,:),ksd_kappa(i,:),'r-','LineWidth',2);
    xlabel('\kappa');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i}, ' US Interest Rate Swaps (1-year sample)']);
    filename=['kappa_',swap_maturity{i},'_sample1_panel_ksd'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% sigma
ksd_sigma=NaN(NM,NK);
xsd_sigma=NaN(NM,NK);
for i=1:NM
    lb=prctile(sigma_sample(:,i),2.5);
    ub=prctile(sigma_sample(:,i),97.5);
    il=find(sigma_sample(:,i)>lb);
    gsample=sigma_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_sigma(i,:),xsd_sigma(i,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
    figure;
    plot(xsd_sigma(i,:),ksd_sigma(i,:),'r-','LineWidth',2);
    xlabel('\sigma');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=['sigma_',swap_maturity{i},'_sample1_panel_ksd'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% nu
ksd_nu=NaN(NM,NK);
xsd_nu=NaN(NM,NK);
for i=1:NM
    lb=prctile(nu_sample(:,i),2.5);
    ub=prctile(nu_sample(:,i),97.5);
    il=find(nu_sample(:,i)>lb);
    gsample=nu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_nu(i,:),xsd_nu(i,:)]=ksdensity(fsample,'npoints',NK,'support',[2,30]);
    figure;
    plot(xsd_nu(i,:),ksd_nu(i,:),'r-','LineWidth',2);
    xlabel('\nu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=['nu_',swap_maturity{i},'_sample1_panel_ksd'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% gamma is not maturity dependent
lb=prctile(gamma_sample,2.5);
ub=prctile(gamma_sample,97.5);
il=find(gamma_sample>lb);
gsample=gamma_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_gamma(3,:),xsd_gamma(3,:)]=ksdensity(fsample,'npoints',NK,'support',[-1.001,2.001]);
figure;
plot(xsd_gamma(3,:),ksd_gamma(3,:),'r-','LineWidth',2);
xlabel('\gamma');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (1-year sample)']);
filename=['gamma_sample1_panel_ksd'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

save irswap_bcev4_sample1_panel_postprocess.mat

%% combined plot of 3 gamma densities
figure;
plot(xsd_gamma(1,:),ksd_gamma(1,:),'r-','LineWidth',2);hold on;
plot(xsd_gamma(2,:),ksd_gamma(2,:),'b-','LineWidth',2);hold on;
plot(xsd_gamma(3,:),ksd_gamma(3,:),'g-','LineWidth',2);
xlabel('\gamma');
ylabel('Marginal Posterior Density');
legend('Full sample','4-year sample','1-year sample');
filename=['gamma_panel_ksd_comparison'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);