function G=cev3_jacobian(b,infoz,stat,y,X,Z)

% X is r(t-1), y is r(t)-r(t-1) Z is [1 r(t-1) r(t-1)^2]
% See ckls_d for a more complete specification of the model
%
% infoz.parms is a 3-vector indicating if the pararmeter is restricted
%   To impose a restriction, pass the value in the desired element, else
%   pass a NaN.
%   The parameter vector is arranged as [alpha beta sigmasq gamma]
  
parms = repmat(NaN,3,1);
parms(isnan(infoz.parms)) = b;
parms(~isnan(infoz.parms)) = infoz.parms(~isnan(infoz.parms));
mu = parms(1);
sigma = parms(2);
gamma = parms(3);


% --- Form model residuals -------------------------------------------
T = rows(X);
e1 = y - mu;
e2 = e1.^2 - (sigma^2*X.^(2*gamma));
e3 = e1.^2;
e4 = e1.^4;

% --- Take partials of residuals wrt parameters ----------------------
de1db1 = -ones(T,1);
de1db2 = zeros(T,1);
de1db3 = zeros(T,1);
de2db1 = 2*e1.*de1db1;
de2db2 = -2*sigma*X.^(2*gamma);
de2db3 = -2*sigma^2*X.^(2*gamma).*log(X);
de3db1 = 3*e1.^2.*de1db1;
de3db2 = zeros(T,1);
de3db3 = zeros(T,1);
de4db1 = 4*e3.*de1db1;
de4db2 = -12*sigma^3*X.^(4*gamma);
de4db3 = -12*sigma^4*X.^(4*gamma).*log(X);

% --- Form Jacobian by inner product with instruments ----------------
G = [Z'*[de1db1 de1db2 de1db3]; ...
     Z'*[de2db1 de2db2 de2db3]]/T;
%  G = [Z'*[de1db1 de1db2 de1db3]; ...
%      Z'*[de2db1 de2db2 de2db3];...
%      Z'*[de3db1 de3db2 de3db3]]/T;
%  G = [Z'*[de1db1 de1db2 de1db3]; ...
%      Z'*[de2db1 de2db2 de2db3];...
%      Z'*[de3db1 de3db2 de3db3];...
%      Z'*[de4db1 de4db2 de4db3]]/T;
G = G(:,find(isnan(infoz.parms)));