% estimate constant elasticity of volatility model with normal
% innovations on irswap data with maximum likelihood

% load data
data=csvread('../data/irswap_daily_20000703_20120726.csv',1,1);
[T,N]=size(data);
dates=csvread('../data/irswap_daily_20000703_20120726.csv',1,0,[1,0,T,0]);
p=NaN(3,N);
pse=NaN(3,N);
ci=NaN(2,3,N);
J=NaN(N,1);
Jpval=NaN(N,1);
p4=NaN(3,N);
pse4=NaN(3,N);
ci4=NaN(2,3,N);
J4=NaN(N,1);
Jpval4=NaN(N,1);
p1=NaN(3,N);
pse1=NaN(3,N);
ci1=NaN(2,3,N);
J1=NaN(N,1);
Jpval1=NaN(N,1);
alpha=0.05;
lm=norminv(0.025);
um=norminv(0.975);
% last 4 years
i4=find(dates>=dates(end)-40000);
data4=data(i4,:);
T4=size(data4,1);
% last 1 year
i1=find(dates>=dates(end)-10000);
data1=data(i1,:);
T1=size(data1,1);
names={'US IRSWAPS 1y','US IRSWAPS 2y','US IRSWAPS 3y','US IRSWAPS 4y',...
    'US IRSWAPS 5y','US IRSWAPS 7y','US IRSWAPS 10y','US IRSWAPS 30y'};
null=[0 0 0]';
vnames=strvcat('mu','sigma','gamma');	% Names
IWM='Z';
SD='gn';
S='W';
wlags=20;
gmmit=3;
gmmtol=1e-7;
maxit=25;
Strim=1;
Slast=1;

mp=NaN(6,N);
mp4=NaN(6,N);
mp1=NaN(6,N);

% full sample
for i=1:N
    % starting guess for full sample
    i
    start=[0,std(diff(data(:,i))),0.75]';
    [p(:,i),pse(:,i),pvals,f,J(i),Jpval(i),jdf,pcov,mp(:,i)] = cev3_gmm(data(:,i),start,null,vnames,IWM,SD,S,wlags,gmmit,gmmtol,maxit,Strim,Slast);
    ci(1,:,i)=p(:,i)'+lm*pse(:,i)';
    ci(2,:,i)=p(:,i)'+um*pse(:,i)';
end

% last 4 years
IWM='Z';
SD='gn';
S='W';
wlags=20;
gmmit=3;
gmmtol=1e-7;
maxit=25;
Strim=1;
Slast=1;
for i=1:N
    % starting guess for full sample
    i
    start=p(:,i);%[0,std(diff(data4(:,i))),0.75]';
    [p4(:,i),pse4(:,i),pvals,f,J4(i),Jpval4(i),jdf,pcov,mp4(:,i)] = cev3_gmm(data4(:,i),start,null,vnames,IWM,SD,S,wlags,gmmit,gmmtol,maxit,Strim,Slast); 
    ci4(1,:,i)=p4(:,i)'+lm*pse4(:,i)';
    ci4(2,:,i)=p4(:,i)'+um*pse4(:,i)';
end

% last 1 year
for i=1:N
    % starting guess for full sample
    i
    start=p4(:,i);%[0,std(diff(data1(:,i))),0.75]';
    [p1(:,i),pse1(:,i),pvals,f,J1(i),Jpval1(i),jdf,pcov,mp1(:,i)] = cev3_gmm(data1(:,i),start,null,vnames,IWM,SD,S,wlags,gmmit,gmmtol,maxit,Strim,Slast);   
    ci1(1,:,i)=p1(:,i)'+lm*pse1(:,i)';
    ci1(2,:,i)=p1(:,i)'+um*pse1(:,i)';
end

% save results in csv files
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'mu','sigma','gamma'};
NM=8;
NV=3;

% full sample
fid=fopen('irswap_cev3_full_gmmstats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','GMM Estimate',...
    '2.5th percentile bound','97.5th percentile bound');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            p(j,i),ci(1,j,i),ci(2,j,i));
    end
end
fclose(fid);

% 4-year sample
fid=fopen('irswap_cev3_sample4_gmmstats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','GMM Estimate',...
    '2.5th percentile bound','97.5th percentile bound');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            p4(j,i),ci4(1,j,i),ci4(2,j,i));
    end
end
fclose(fid);

% 1-year sample
fid=fopen('irswap_cev3_sample1_gmmstats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','GMM Estimate',...
    '2.5th percentile bound','97.5th percentile bound');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            p1(j,i),ci1(1,j,i),ci1(2,j,i));
    end
end
fclose(fid);

% chi-square model fit statistics for all 3 subsamples in one file
fid = fopen('irswap_cev3_gmmfit.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s,%s,%s\n','Swap Maturity','Full sample J',...
    'Full sample J p-value','4y sample J','4y sample J p-value',...
    '1y sample J','1y sample J p-value');
for i=1:NM
    fprintf(fid,'%s,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},...
        J(i),Jpval(i),J4(i),Jpval4(i),J1(i),Jpval1(i));
end;
fclose(fid);

% moment p-values
fid = fopen('irswap_cev3_gmm_moment_pvalues.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap maturity','Moment Condition','full sample p-value',...
    '4-year sample p-value','1-year sample p-value');
for i=1:NM
    for j=1:6
        fprintf(fid,'%s,%g,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},j,mp(j,i),mp4(j,i),mp1(j,i));
    end
end
fclose(fid);