% maximum likelihood estimator of constant elasticity of volatility
% model with normal innovations
% INPUTS:
% y(1:T)     = univariate data time-series
% alpha      = (optional) confidence level for estimates, defualt is 0.95
% start      = (optional) vector of starting guesses
% OUTPUTS:
% p(1:2) = estimated model parameters, namely
%   p(1)    = sigmabar = scale of volatility
%   p(2)    = gamma = elasticity of volatility at low levels
% ci(1:2,1:2)   = confidence bounds at significance level alpha
% aic       = Akaike information criterion
function [p,ci,aic] = cev2_normal_mle(y,alpha,start)

if nargin<2
    alpha=0.05;
end
if nargin<3
    start=[log(std(y)),0.75];
end
T=size(y,1);

myoptions=statset('MaxFunEvals',10*T,'MaxIter',10000);


lb=[-10,-10];
ub=Inf(1,2);ub(1)=1;


cevnormal_loglikelihood=@(params,data,cens,freq)(-cev2_normal_llf(params,data,cens,freq));
[p,ci]=mle(y, 'nloglf', cevnormal_loglikelihood, 'start',start,'options',myoptions,'lowerbound',lb,'upperbound',ub,'optimfun','fmincon','alpha',alpha);
%[p,ci]=mle(y, 'nloglf', hpevnormal_loglikelihood, 'start',start,'options',myoptions,'optimfun','fmincon','alpha',alpha);
%[p,ci]=mle(y, 'nloglf', hpevnormal_loglikelihood, 'start',start,'options',myoptions,'lowerbound',lb,'upperbound',ub,'optimfun','fminsearch','alpha',alpha);
aic=2*2+2*cevnormal_loglikelihood(p,y,[],[]);
% back to scale levels
p(1)=exp(p(1));
ci(:,1)=exp(ci(:,1));