% maximum likelihood estimator of constant elasticity of volatility
% model with Student t innovations
% INPUTS:
% y(1:T)     = univariate data time-series
% alpha      = (optional) confidence level for estimates, defualt is 0.95
% start      = (optional) vector of starting guesses
% OUTPUTS:
% p(1:2) = estimated model parameters, namely
%   p(1)    = sigmabar = scale of volatility
%   p(2)    = gamma = elasticity of volatility at low levels
%   p(3)    = nu    = degrees of freedom parameter
% ci(1:2,1:2)   = confidence bounds at significance level alpha
% aic       = Akaike information criterion
function [p,ci,aic] = cev2_t_mle(y,alpha,start)

if nargin<2
    alpha=0.05;
end
if nargin<3
    start=[log(std(y)),0.75,8];
end
T=size(y,1);

myoptions=statset('MaxFunEvals',10*T,'MaxIter',10000);


lb=[-10,-10,1];
ub=Inf(1,3);ub(1)=1;ub(3)=100;


cevt_loglikelihood=@(params,data,cens,freq)(-cev2_t_llf(params,data,cens,freq));
[p,ci]=mle(y, 'nloglf', cevt_loglikelihood, 'start',start,'options',myoptions,'lowerbound',lb,'upperbound',ub,'optimfun','fmincon','alpha',alpha);
aic=2*3+2*cevt_loglikelihood(p,y,[],[]);
% back to scale levels
p(1)=exp(p(1));
ci(:,1)=exp(ci(:,1));