% function r =
% cev3_normal_simulator(T,musigma,gammabar,rho,sigma_eta,y0,gamma0)
% Simulating constant elasticity of volatility model
% r(t)-r(t-1)=mu+sigmabar*(abs(r(t-1)))^gamma*epsilon(t) where
% epsilon(t)~iid N(0,1)
% INPUTS
% T         = length of time-series to simulate
% mu        = mean parameter
% sigmabar  = scale of volatility
% gamma     = elasticity of volatility at low r levels
% r0 = initial value of observed time-series
% OUTPUTS
% r(1:T)    = simulated output series
% sigma(1:T)= simulated volatility series
function [r,sigma] = cev3_normal_simulator(T,mu,sigmabar,gamma,r0)

r=NaN(T,1);
sigma=NaN(T,1);
epsilon=randn(T,1);
r(1)=r0+mu+sigmabar*abs(r0)^gamma*epsilon(1);
sigma(1)=sigmabar*abs(r0)^gamma;
if T>1
    for t=2:T
        r(t)=r(t-1)+mu+sigmabar*abs(r(t-1))^gamma*epsilon(t);
        sigma(t)=sigmabar*abs(r(t-1))^gamma;
    end
end
