% Nyblom stability test for CEV normal model estimated with MLE
% function [nyb,pv]=cev3_nyblom(y,mu,sigma,alpha)
% INPUTS:
% y(1:T,1)      = univariate time-series for which CEV models with normal residuals was fit
% mu            = ML estimate for mean drift
% sigma         = ML estimate of scale of volatility
% gamma         = ML estimate of elasticity of volatility
% OUTPUTS:
% nyb           = Nyblom stability statistics
% pv            = p-value of nyb
function [nyb,pv]=cev3_nyblom(y,mu,sigma,gamma)
    T=size(y,1);
    sv3=cumsum(score_gamma(mu,sigma,gamma,diff(y),y(1:end-1)));
    numerator=sum(sv3(1:end-1).^2)/(T-1);
    %sv4=cumsum(score_nu(mu,sigma,gamma,nu,diff(y),y(1:end-1)));
    denominator=sum(hess_gamma(mu,sigma,gamma,diff(y),y(1:end-1)));
    nyb=numerator/denominator;
    pv=NaN;
    if exist('test_cev3_nyblom_null.mat','file')==2
        load('test_cev3_nyblom_null.mat','nybs','NMC');
        if nyb<min(nybs)
            pv=1.0;
        elseif nyb>=max(nybs)
            pv=0.0;
        else
            nybs=sort(nybs);
            il=max(find(nybs<nyb));
            ih=min(find(nybs>nyb));
            w=(nyb-nybs(il))/(nybs(ih)-nybs(il));
            pl=il/NMC;
            ph=ih/NMC;
            pv=pl*(1-w)+w*ph;
            pv=1-pv;
        end
    end
    
end


function S3=score_gamma(mu,sigma,gamma,dr,r)
    S3=((dr-mu).^2.*r.^(-2*gamma)./sigma.^2-1).*log(r);
end


function H33=hess_gamma(mu,sigma,gamma,dr,r)
    H33=2*r.^(-2*gamma).*(dr-mu).^2.*(log(r)).^2./sigma.^2;
end
