% compute log-likelihood function for const drift cev process with Student t innovations
% INPUTS
% r0        = initial value
% r(1:T)    = sample, purpotedly from CEV with Student t innovations
% mu        = mean parameter
% kappa     = speed of mean reversion
% sigma     = scale of variance
% gamma     = elasticity of variance
% nu        = degrees of freedom parameter
% OUTPUTS
% L         = log-likelihood function

function L = cev3_t_loglik(r0,r,mu,sigma,gamma,nu)

L=log(tpdf((r(1)-r0-mu)/(sigma*abs(r0)^gamma),nu)/(sigma*abs(r0)^gamma));
if ~isnan(L)
    L=L+nansum(log(tpdf((r(2:end)-r(1:end-1)-mu)./(sigma.*abs(r(1:end-1)).^gamma),nu)./(sigma.*abs(r(1:end-1)).^gamma)));
else
    L=nansum(log(tpdf((r(2:end)-r(1:end-1)-mu)./(sigma.*abs(r(1:end-1)).^gamma),nu)./(sigma.*abs(r(1:end-1)).^gamma)));
end