% maximum likelihood estimator of constant elasticity of volatility
% model with Student t innovations
% INPUTS:
% y(1:T)     = univariate data time-series
% alpha      = (optional) confidence level for estimates, default is 0.95
% start      = (optional) vector of starting guesses
% OUTPUTS:
% p(1:3) = estimated model parameters, namely
%   p(1)    = mu = constant drift parameter
%   p(2)    = sigmabar = scale of volatility
%   p(3)    = gamma = elasticity of volatility at low levels
%   p(4)    = nu = degrees of freedom parameter
% ci(1:2,1:3)   = confidence bounds at significance level alpha
% aic       = Akaike information criterion
function [p,ci,aic] = cev3_t_mle(y,alpha,start)

if nargin<2
    alpha=0.05;
end
if nargin<3
    start=[mean(diff(y)),log(std(diff(y))),0.5,8];
end
T=size(y,1);

myoptions=statset('MaxFunEvals',10*T,'MaxIter',10000);


lb=[-Inf,-10,-10,2];
ub=Inf(1,4);ub(2)=1;


cevt_loglikelihood=@(params,data,cens,freq)(-cev3_t_llf(params,data,cens,freq));
[p,ci]=mle(y, 'nloglf', cevt_loglikelihood, 'start',start,'options',myoptions,'lowerbound',lb,'upperbound',ub,'optimfun','fmincon','alpha',alpha);
aic=2*4+2*cevt_loglikelihood(p,y,[],[]);
% back to scale levels
p(2)=exp(p(2));
ci(:,2)=exp(ci(:,2));