% maximum likelihood estimator of constant elasticity of volatility
% model with Student t innovations
% INPUTS:
% y(1:T)     = univariate data time-series
% alpha      = (optional) confidence level for estimates, defualt is 0.95
% start      = (optional) vector of starting guesses
% OUTPUTS:
% p(1:7) = estimated model parameters, namely
%   p(1)    = theta = long-run mean
%   p(2)    = kappa = speed of mean reversion
%   p(3)    = sigmabar = scale of volatility
%   p(4)    = gamma = elasticity of volatility at low levels
% ci(1:2,1:4)   = confidence bounds at significance level alpha
% aic       = Akaike information criterion
function [p,ci,aic] = cev4_t_mle(y,alpha,start)

if nargin<2
    alpha=0.05;
end
if nargin<3
    start=[mean(y),0,log(std(diff(y))),0.75,10];
end
T=size(y,1);

myoptions=statset('MaxFunEvals',10*T,'MaxIter',10000);


lb=[-Inf,-Inf,-10,-10,1];
ub=Inf(1,5);ub(3)=0;ub(5)=100;ub(4)=2;


cevt_loglikelihood=@(params,data,cens,freq)(-cev4_t_llf(params,data,cens,freq));
[p,ci]=mle(y, 'nloglf', cevt_loglikelihood, 'start',start,'options',myoptions,'lowerbound',lb,'upperbound',ub,'optimfun','fmincon','alpha',alpha);
%[p,ci]=mle(y, 'nloglf', hpevnormal_loglikelihood, 'start',start,'options',myoptions,'optimfun','fmincon','alpha',alpha);
%[p,ci]=mle(y, 'nloglf', hpevnormal_loglikelihood, 'start',start,'options',myoptions,'lowerbound',lb,'upperbound',ub,'optimfun','fminsearch','alpha',alpha);
aic=2*5+2*cevt_loglikelihood(p,y,[],[]);
% back to scale levels
p(3)=exp(p(3));
ci(:,3)=exp(ci(:,3));