% Nyblom stability test for CEV t model estimated with MLE
% function [nyb,pv]=cevt_nyblom(y,mu,sigma,alpha,nu)
% INPUTS:
% y(1:T,1)      = univariate time-series for which CEV models with Student t residuals was fit
% mu            = ML estimate for mean drift
% sigma         = ML estimate of scale of volatility
% alpha         = ML estimate of elasticity of volatility
% nu            = ML estimate of Student t degrees of freedom parameter
% OUTPUTS:
% nyb           = Nyblom stability statistics
% pv            = p-value of nyb
function [nyb,pv]=cevt_nyblom(y,mu,sigma,alpha,nu)
    T=size(y,1);
    %sv1=cumsum(score_mu(mu,sigma,alpha,nu,diff(y),y(1:end-1)));
    %sv2=cumsum(score_sigma(mu,sigma,alpha,nu,diff(y),y(1:end-1)));
    sv3=cumsum(score_gamma(mu,sigma,alpha,nu,diff(y),y(1:end-1)));
    numerator=sum(sv3(1:end-1,:).^2)/(T-1);
    %sv4=cumsum(score_nu(mu,sigma,alpha,nu,diff(y),y(1:end-1)));
    denominator=sum(hess_gamma(mu,sigma,alpha,nu,diff(y),y(1:end-1)));
    %denominator=score_gamma(mu,sigma,alpha,nu,diff(y),y(1:end-1))'*score_gamma(mu,sigma,alpha,nu,diff(y),y(1:end-1));
    nyb=numerator/denominator;
    pv=NaN;
    if exist('test_cevt_nyblom_null.mat','file')==2
        load('test_cevt_nyblom_null.mat','nybs','NMC');
        if nyb<min(nybs)
            pv=1.0;
        elseif nyb>=max(nybs)
            pv=0.0;
        else
            nybs=sort(nybs);
            il=max(find(nybs<nyb));
            ih=min(find(nybs>nyb));
            w=(nyb-nybs(il))/(nybs(ih)-nybs(il));
            pl=il/NMC;
            ph=ih/NMC;
            pv=pl*(1-w)+w*ph;
            pv=1-pv;
        end
    end
            
    
end

% function S1=score_mu(mu,sigma,alpha,nu,r,dr)
%     S1=(dr-mu).*(1+nu)./((dr-mu).^2+nu.*r.^(2*alpha).*sigma.^2);
% end

% function S2=score_sigma(mu,sigma,alpha,nu,dr,r)
%     S2=nu./sigma.*((dr-mu).^2-r.^(2*alpha).*sigma.^2)./((dr-mu).^2+nu.*r.^(2*alpha).*sigma.^2);
% 
% end

function S3=score_gamma(mu,sigma,alpha,nu,dr,r)
    S3=nu.*((dr-mu).^2-r.^(2*alpha).*sigma.^2)./((dr-mu).^2+nu.*r.^(2*alpha).*sigma.^2).*log(r);
end

% function S4=score_nu(mu,sigma,alpha,nu,dr,r)
% 
% end

function H33=hess_gamma(mu,sigma,alpha,nu,dr,r)
    H33=2.*nu.*(nu+1).*sigma.^2.*(dr-mu).^2.*r.^(2*alpha).*log(r).^2./((dr-mu).^2+nu.*sigma.^2.*r.^(2*alpha)).^2;
end
