% Nyblom Stability test for CEV model with Student t errors
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
NM=8; % number of maturities
NS=3; % number of (sub)samples

% load data
data=csvread('../data/irswap_daily_20000703_20120726.csv',1,1);
[T,N]=size(data);
dates=csvread('../data/irswap_daily_20000703_20120726.csv',1,0,[1,0,T,0]);
% last 4 years
i4=find(dates>=dates(end)-40000);
data4=data(i4,:);
T4=size(data4,1);
% last 1 year
i1=find(dates>=dates(end)-10000);
data1=data(i1,:);
T1=size(data1,1);
Nyt=NaN(NM,NS);
pval=NaN(NM,NS);
mu=NaN(NM,NS);
sigma=NaN(NM,NS);
gamma=NaN(NM,NS);
nu=NaN(NM,NS);

% load ML estimates of model parameters
param_full=csvread('irswap_cevt3_full_stats.csv',1,2);
param_4y=csvread('irswap_cevt3_sample4_stats.csv',1,2);
param_1y=csvread('irswap_cevt3_sample1_stats.csv',1,2);
mu=[param_full(1:4:29,1),param_4y(1:4:29,1),param_1y(1:4:29,1)];
sigma=[param_full(2:4:30,1),param_4y(2:4:30,1),param_1y(2:4:30,1)];
gamma=[param_full(3:4:31,1),param_4y(3:4:31,1),param_1y(3:4:31,1)];
nu=[param_full(4:4:32,1),param_4y(4:4:32,1),param_1y(4:4:32,1)];

% Nyblom
for i=1:NM
    [Nyt(i,1),pval(i,1)]=cevt_nyblom(data(:,i),mu(i,1),sigma(i,1),gamma(i,1),nu(i,1));
    [Nyt(i,2),pval(i,2)]=cevt_nyblom(data4(:,i),mu(i,2),sigma(i,2),gamma(i,2),nu(i,2));
    [Nyt(i,3),pval(i,3)]=cevt_nyblom(data1(:,i),mu(i,3),sigma(i,3),gamma(i,3),nu(i,3));
end
  


save irswaps_cev3t_nyblom.mat

% save to csv files
fid=fopen('irswap_cev3t_nyblomstats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s,%s,%s\n','Swap Maturity',...
    'Full sample Nyblom test','Full sample p-value','4-year sample Nyblom test',...
    '4-year sample p-value','1-year sample Nyblom test',...
    '1-year sample p-value');
for i=1:NM
        fprintf(fid,'%s,%7.2f,%11.8f,%7.2f,%11.8f,%7.2f,%11.8f\n',...
            swap_maturity{i},Nyt(i,1),pval(i,1),Nyt(i,2),pval(i,2),...
            Nyt(i,3),pval(i,3));
end
fclose(fid);


