% testing cev3_normal_mle function

% generate artificial time-series from the model
T=10240;
r0=2.9;
sigmabar=0.02;
mu=0.001;
gamma=0.75;
[r,sigma] = cev3_normal_simulator(T,mu,sigmabar,gamma,r0);
figure;
plot(r);axis tight;
xlabel('t');
ylabel('r');

% regime counts
['CEV Regime  ','Difference Regime  ','Return Regime  ']
disp([sum(sigma<sigmabar),sum(sigma==sigmabar),sum(sigma>sigmabar)]);


% evaluate loglikelihood of the sample at true parameters
L=cev3_normal_loglik(r0,r,mu,sigmabar,gamma);

% estimate
alpha=0.05; % significance level
% preliminary search for good starting values
fun=@(x)(-cev3_normal_llf(x,r));
start=[0,log(std(diff(r))),0.5];
lb=[-Inf,-10,-10];
ub=Inf(1,3);ub(2)=1;
[x0,f0]=simulannealbnd(fun,start,lb,ub)

[p,ci,aic] = cev3_normal_mle(r,alpha,x0);
% report
disp(['   True mu             ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([mu, p(1),ci(1,1),ci(2,1)]);
disp(['   True sigmabar       ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([sigmabar, p(2),ci(1,2),ci(2,2)]);
disp(['   True gamma          ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([gamma, p(3),ci(1,3),ci(2,3)]);


% test convergence of estimates
T0=1024;
dT=128;
TF=linspace(T0,T,(T-T0)/dT+1);
NT=size(TF,2);
pt=NaN(NT,3);
cit=NaN(2,3,NT);
aict=NaN(NT,1);
for t=1:NT
    [t,TF(t)]
    % select best starting point
    st=x0;
    if t>1
        L1=cev3_normal_loglik(r0,r,pt(t-1,1),pt(t-1,2),pt(t-1,3));
        L2=cev3_normal_loglik(r0,r,x0(1),exp(x0(2)),x0(3));
        if L1>L2
            st=[pt(t-1,1),log(pt(t-1,2)),pt(t-1,3)];
        end
    end
    [pt(t,:),cit(:,:,t),aict(t)] = cev3_normal_mle(r(1:TF(t)),alpha,st);
end

% convergence of mean estimates
figure;
plot(TF,pt(:,1),'r-'); hold on;
plot(TF,ones(size(TF))*mu,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \mu');


% convergence of estimates of volatility scale and gamma
figure;
subplot(2,1,1);
plot(TF,pt(:,2),'r-'); hold on;
plot(TF,ones(size(TF))*sigmabar,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \sigma');
subplot(2,1,2);
plot(TF,pt(:,3),'r-'); hold on;
plot(TF,ones(size(TF))*gamma,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \gamma');
