% testing cev3_t_loglik function

% generate artificial time-series from the model
T=10240;
r0=2.9;
sigmabar=0.2;
mu=0.01;
gamma=0.75;
nu=2.5;
[r,sigma] = cev3_t_simulator(T,mu,sigmabar,gamma,nu,r0);
% regime counts
['CEV Regime  ','Difference Regime  ','Return Regime  ']
disp([sum(sigma<sigmabar),sum(sigma==sigmabar),sum(sigma>sigmabar)]);

% evaluate loglikelihood of the sample
L=cev3_t_loglik(r0,r,mu,sigmabar,gamma,nu)

% evaluate loglikelihood on a one-dimensional slice surrounding true values
N=64;% slice size
% mu slice
mu_grid=linspace(-2,6,N);
Ln_mu=NaN(N,1);
Lt_mu=NaN(N,1);
for i=1:N
    Ln_mu(i)=cev3_normal_loglik(r0,r,mu_grid(i),sigmabar,gamma);
    Lt_mu(i)=cev3_t_loglik(r0,r,mu_grid(i),sigmabar,gamma,nu);
end
figure1=figure;
set(figure1,'DefaultTextInterpreter','tex');
plot(mu_grid,Ln_mu,'b-'); hold on;
plot(mu_grid,Lt_mu,'m-'); hold on;
plot(mu,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([mu,mu],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\mu');
ylabel('Log-likelihood');

% sigmabar slice
sigmabar_grid=logspace(-1.5,1,N);
Ln_sigmabar=NaN(N,1);
Lt_sigmabar=NaN(N,1);
for i=1:N
    Ln_sigmabar(i)=cev3_normal_loglik(r0,r,mu,sigmabar_grid(i),gamma);
    Lt_sigmabar(i)=cev3_t_loglik(r0,r,mu,sigmabar_grid(i),gamma,nu);
end
figure3=figure;
set(figure3,'DefaultTextInterpreter','tex');
plot(log(sigmabar_grid),Ln_sigmabar,'b-'); hold on;
plot(log(sigmabar_grid),Lt_sigmabar,'m-'); hold on;
plot(log(sigmabar),L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([log(sigmabar),log(sigmabar)],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('log \sigma');
ylabel('Log-likelihood');

% gamma slice
gamma_grid=linspace(-1.0,1.5,N);
Ln_gamma=NaN(N,1);
Lt_gamma=NaN(N,1);
for i=1:N
    Ln_gamma(i)=cev3_normal_loglik(r0,r,mu,sigmabar,gamma_grid(i));
    Lt_gamma(i)=cev3_t_loglik(r0,r,mu,sigmabar,gamma_grid(i),nu);
end
figure4=figure;
set(figure4,'DefaultTextInterpreter','tex');
plot(gamma_grid,Ln_gamma,'b-'); hold on;
plot(gamma_grid,Lt_gamma,'m-'); hold on;
plot(gamma,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([gamma,gamma],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\gamma');
ylabel('Log-likelihood');

% nu slice
nu_grid=linspace(1,32,N);
Ln_nu=NaN(N,1);
Lt_nu=NaN(N,1);
for i=1:N
    Ln_nu(i)=cev3_normal_loglik(r0,r,mu,sigmabar,gamma);
    Lt_nu(i)=cev3_t_loglik(r0,r,mu,sigmabar,gamma,nu_grid(i));
end
figure4=figure;
set(figure4,'DefaultTextInterpreter','tex');
plot(nu_grid,Ln_nu,'b-'); hold on;
plot(nu_grid,Lt_nu,'m-'); hold on;
plot(nu,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([nu,nu],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\nu');
ylabel('Log-likelihood');