% testing cev4_normal_loglik function

% generate artificial time-series from the model
T=1024;
r0=2.9;
sigmabar=0.2;
theta=2.6;
kappa=0.03;
gamma=0.5;
[r,sigma] = cev_normal_simulator(T,theta,kappa,sigmabar,gamma,r0);
% regime counts
['CEV Regime  ','Difference Regime  ','Return Regime  ']
disp([sum(sigma<sigmabar),sum(sigma==sigmabar),sum(sigma>sigmabar)]);

% evaluate loglikelihood of the sample
L=cev4_normal_loglik(r0,r,theta,kappa,sigmabar,gamma)

% evaluate loglikelihood on a one-dimensional slice surrounding true values
N=64;% slice size
% theta slice
theta_grid=linspace(-2,6,N);
L_theta=NaN(N,1);
for i=1:N
    L_theta(i)=cev4_normal_loglik(r0,r,theta_grid(i),kappa,sigmabar,gamma);
end
figure1=figure;
set(figure1,'DefaultTextInterpreter','tex');
plot(theta_grid,L_theta,'b-'); hold on;
plot(theta,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([theta,theta],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\theta');
ylabel('Log-likelihood');


% kappa slice
kappa_grid=linspace(-0.3,0.3,N);
L_kappa=NaN(N,1);
for i=1:N
    L_kappa(i)=cev4_normal_loglik(r0,r,theta,kappa_grid(i),sigmabar,gamma);
end
figure2=figure;
set(figure2,'DefaultTextInterpreter','tex');
plot(kappa_grid,L_kappa,'b-'); hold on;
plot(kappa,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([kappa,kappa],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\kappa');
ylabel('Log-likelihood');

% sigmabar slice
sigmabar_grid=logspace(-2,1,N);
L_sigmabar=NaN(N,1);
for i=1:N
    L_sigmabar(i)=cev4_normal_loglik(r0,r,theta,kappa,sigmabar_grid(i),gamma);
end
figure3=figure;
set(figure3,'DefaultTextInterpreter','tex');
plot(log(sigmabar_grid),L_sigmabar,'b-'); hold on;
plot(log(sigmabar),L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([log(sigmabar),log(sigmabar)],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('log \sigma');
ylabel('Log-likelihood');

% gamma slice
gamma_grid=linspace(0,1.5,N);
L_gamma=NaN(N,1);
for i=1:N
    L_gamma(i)=cev4_normal_loglik(r0,r,theta,kappa,sigmabar,gamma_grid(i));
end
figure4=figure;
set(figure4,'DefaultTextInterpreter','tex');
plot(gamma_grid,L_gamma,'b-'); hold on;
plot(gamma,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([gamma,gamma],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\gamma');
ylabel('Log-likelihood');

