% testing cev4_t_mle function

% generate artificial time-series from the model
T=10240;
r0=2.9;
sigmabar=0.2;
theta=2.6;
kappa=0.03;
gamma=0.75;
nu=5.5;
[r,sigma] = cev_t_simulator(T,theta,kappa,sigmabar,gamma,nu,r0);
figure;
plot(r);axis tight;
xlabel('t');
ylabel('r');

% regime counts
['CEV Regime  ','Difference Regime  ','Return Regime  ']
disp([sum(sigma<sigmabar),sum(sigma==sigmabar),sum(sigma>sigmabar)]);


% evaluate loglikelihood of the sample at true parameters
L=cev4_t_loglik(r0,r,theta,kappa,sigmabar,gamma,nu);

% estimate
alpha=0.05; % significance level
% preliminary search for good starting values
fun=@(x)(-cev4_t_llf(x,r));
start=[mean(r),0,log(std(diff(r)./r(1:end-1).^0.5)),0.5,10];
lb=[-Inf,-Inf,-10,-10,1];
ub=Inf(1,4);ub(3)=1;ub(5)=100;
options = saoptimset('HybridFcn',@fminsearch,'InitialTemperature',1200,'TemperatureFcn',@temperatureboltz,'AnnealingFcn',@annealingboltz,'MaxFunEval',100000); 
[x0,f0]=simulannealbnd(fun,start,lb,ub,options)

[p,ci,aic] = cev4_t_mle(r,alpha,x0);
% report
disp(['   True theta          ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([theta, p(1),ci(1,1),ci(2,1)]);
disp(['   True kappa          ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([kappa, p(2),ci(1,2),ci(2,2)]);
disp(['   True sigmabar       ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([sigmabar, p(3),ci(1,3),ci(2,3)]);
disp(['   True gamma          ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([gamma, p(4),ci(1,4),ci(2,4)]);
disp(['   True nu             ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([nu, p(5),ci(1,5),ci(2,5)]);

% test convergence of estimates
T0=1024;
dT=128;
TF=linspace(T0,T,(T-T0)/dT+1);
NT=size(TF,2);
pt=NaN(NT,5);
cit=NaN(2,5,NT);
aict=NaN(NT,1);
for t=1:NT
    [t,TF(t)]
    % select best starting point
    st=x0;
    if t>1
        L1=cev4_t_loglik(r0,r,pt(t-1,1),pt(t-1,2),pt(t-1,3),pt(t-1,4),pt(t-1,5));
        L2=cev4_t_loglik(r0,r,x0(1),x0(2),exp(x0(3)),x0(4),x0(5));
        if L1>L2
            st=[pt(t-1,1),pt(t-1,2),log(pt(t-1,3)),pt(t-1,4),pt(t-1,5)];
        end
    end
    [pt(t,:),cit(:,:,t),aict(t)] = cev4_t_mle(r(1:TF(t)),alpha,st);
end

% convergence of mean estimates
figure;
subplot(2,1,1);
plot(TF,pt(:,1),'r-'); hold on;
plot(TF,ones(size(TF))*theta,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \theta');
subplot(2,1,2);
plot(TF,pt(:,2),'r-'); hold on;
plot(TF,ones(size(TF))*kappa,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \kappa');

% convergence of estimates of volatility scale, gamma and nu
figure;
subplot(3,1,1);
plot(TF,pt(:,3),'r-'); hold on;
plot(TF,ones(size(TF))*sigmabar,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \sigma');
subplot(3,1,2);
plot(TF,pt(:,4),'r-'); hold on;
plot(TF,ones(size(TF))*gamma,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \gamma');
subplot(3,1,3);
plot(TF,pt(:,5),'r-'); hold on;
plot(TF,ones(size(TF))*nu,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \nu');