% maximum likelihood estimator of zero elasticity of volatility
% model with normal innovations
% INPUTS:
% y(1:T)     = univariate data time-series
% alpha      = (optional) confidence level for estimates, defualt is 0.95
% start      = (optional) vector of starting guesses
% OUTPUTS:
% p(1:3) = estimated model parameters, namely
%   p(1)    = theta = long-run mean
%   p(2)    = kappa = speed of mean reversion
%   p(3)    = sigmabar = scale of volatility
% ci(1:2,1:3)   = confidence bounds at significance level alpha
% aic       = Akaike information criterion
function [p,ci,aic] = zev_normal_mle(y,alpha,start)

if nargin<2
    alpha=0.05;
end
if nargin<3
    start=[mean(y),0,log(std(diff(y)))];
end
T=size(y,1);

myoptions=statset('MaxFunEvals',10*T,'MaxIter',10000);


lb=[-Inf,-Inf,-10];
ub=Inf(1,3);ub(3)=1;


zevnormal_loglikelihood=@(params,data,cens,freq)(-zev_normal_llf(params,data,cens,freq));
[p,ci]=mle(y, 'nloglf', zevnormal_loglikelihood, 'start',start,'options',myoptions,'lowerbound',lb,'upperbound',ub,'optimfun','fmincon','alpha',alpha);
%[p,ci]=mle(y, 'nloglf', hpevnormal_loglikelihood, 'start',start,'options',myoptions,'optimfun','fmincon','alpha',alpha);
%[p,ci]=mle(y, 'nloglf', hpevnormal_loglikelihood, 'start',start,'options',myoptions,'lowerbound',lb,'upperbound',ub,'optimfun','fminsearch','alpha',alpha);
aic=2*3+2*zevnormal_loglikelihood(p,y,[],[]);
% back to scale levels
p(3)=exp(p(3));
ci(:,3)=exp(ci(:,3));