% function [aic,bic] = ict(y)
% compute information criteria for location-scale Student t fit
% INPUTS
% y     = data
% OUTPUTS
% aic   = Akaike Information Criterios
% bic   = Bayesian Information Criterion
% aicc  = AIC with small sample correction
function [aic,bic,aicc] = ict(y)

T=numel(y);
vf=mle(y,'distribution','tlocationscale');
nlogL=-sum(log(tpdf((y-vf(1))/vf(2),vf(3))));
aic=6+2*nlogL;
aicc=aic+24/(T-4);
bic=2*nlogL+2*log(T);
