% goodness-of-fit  tests

% load data
data=csvread('../data/irswap_daily_20000703_20120726.csv',1,1);
[T,N]=size(data);
dates=csvread('../data/irswap_daily_20000703_20120726.csv',1,0,[1,0,T,0]);
% last 4 years
i4=find(dates>=dates(end)-40000);
data4=data(i4,:);
T4=size(data4,1);
% last 1 year
i1=find(dates>=dates(end)-10000);
data1=data(i1,:);
T1=size(data1,1);
names={'US IRSWAPS 1y','US IRSWAPS 2y','US IRSWAPS 3y','US IRSWAPS 4y',...
    'US IRSWAPS 5y','US IRSWAPS 7y','US IRSWAPS 10y','US IRSWAPS 30y'};

% Pearson chi-square test
Ppearson=NaN(N,2); % one for diff, other for rets
Ppearson4=NaN(N,2);
Ppearson1=NaN(N,2);
nbins=floor(2.28*T^0.4);
nbins1=floor(2.28*T1^0.4);
nbins4=floor(2.28*T4^0.4);
for i=1:N
    [h,Ppearson(i,1)]=chi2gof(diff(data(:,i)),'nbins',nbins);
    [h,Ppearson(i,2)]=chi2gof(diff(data(:,i))./data(1:end-1,i),'nbins',nbins);
    [h,Ppearson4(i,1)]=chi2gof(diff(data4(:,i)),'nbins',nbins4);
    [h,Ppearson4(i,2)]=chi2gof(diff(data4(:,i))./data4(1:end-1,i),'nbins',nbins4);
    [h,Ppearson1(i,1)]=chi2gof(diff(data1(:,i)),'nbins',nbins1);
    [h,Ppearson1(i,2)]=chi2gof(diff(data1(:,i))./data1(1:end-1,i),'nbins',nbins1);
end

% BIC, AIC and AICC
bic=NaN(N,2); % one for diff, other for rets
bic4=NaN(N,2);
bic1=NaN(N,2);
aic=NaN(N,2); % one for diff, other for rets
aic4=NaN(N,2);
aic1=NaN(N,2);
aicc=NaN(N,2); % one for diff, other for rets
aicc4=NaN(N,2);
aicc1=NaN(N,2);
for i=1:N
    i
    [aic(i,1),bic(i,1),aicc(i,1)]=ic(diff(data(:,i)));
    [aic4(i,1),bic4(i,1),aicc4(i,1)]=ic(diff(data4(:,i)));
    [aic1(i,1),bic1(i,1),aicc1(i,1)]=ic(diff(data1(:,i)));
    [aic(i,2),bic(i,2),aicc(i,2)]=ic(diff(data(:,i))./data(1:end-1,i));
    [aic4(i,2),bic4(i,2),aicc4(i,2)]=ic(diff(data4(:,i))./data4(1:end-1,i));
    [aic1(i,2),bic1(i,2),aicc1(i,2)]=ic(diff(data1(:,i))./data1(1:end-1,i));
end

% Kolmogorov-Smirnov test
Pkstest=NaN(N,2); % one for diff, other for rets
Pkstest4=NaN(N,2);
Pkstest1=NaN(N,2);
for i=1:N
    [h,Pkstest(i,1)]=kstest(diff(data(:,i)));
    [h,Pkstest(i,2)]=kstest(diff(data(:,i))./data(1:end-1,i));
    [h,Pkstest4(i,1)]=kstest(diff(data4(:,i)));
    [h,Pkstest4(i,2)]=kstest(diff(data4(:,i))./data4(1:end-1,i));
    [h,Pkstest1(i,1)]=kstest(diff(data1(:,i)));
    [h,Pkstest1(i,2)]=kstest(diff(data1(:,i))./data1(1:end-1,i));
end

% Anderson-Darling test
Padtest=NaN(N,2); % one for diff, other for rets
Padtest4=NaN(N,2);
Padtest1=NaN(N,2);
for i=1:N
    [ad,ad2,Padtest(i,1)]=AnDartest(diff(data(:,i)));
    [ad,ad2,Padtest(i,2)]=AnDartest(diff(data(:,i))./data(1:end-1,i));
    [ad,ad2,Padtest4(i,1)]=AnDartest(diff(data4(:,i)));
    [ad,ad2,Padtest4(i,2)]=AnDartest(diff(data4(:,i))./data4(1:end-1,i));
    [ad,ad2,Padtest1(i,1)]=AnDartest(diff(data1(:,i)));
    [ad,ad2,Padtest1(i,2)]=AnDartest(diff(data1(:,i))./data1(1:end-1,i));
end

% Lilliefors test
Plillietest=NaN(N,2); % one for diff, other for rets
Plillietest4=NaN(N,2);
Plillietest1=NaN(N,2);
for i=1:N
    [h,Plillietest(i,1)]=lillietest(diff(data(:,i)));
    [h,Plillietest(i,2)]=lillietest(diff(data(:,i))./data(1:end-1,i));
    [h,Plillietest4(i,1)]=lillietest(diff(data4(:,i)));
    [h,Plillietest4(i,2)]=lillietest(diff(data4(:,i))./data4(1:end-1,i));
    [h,Plillietest1(i,1)]=lillietest(diff(data1(:,i)));
    [h,Plillietest1(i,2)]=lillietest(diff(data1(:,i))./data1(1:end-1,i));
end

% Jarque-Bera test
Pjbtest=NaN(N,2); % one for diff, other for rets
Pjbtest4=NaN(N,2);
Pjbtest1=NaN(N,2);
for i=1:N
    [h,Pjbtest(i,1)]=jbtest(diff(data(:,i)));
    [h,Pjbtest(i,2)]=jbtest(diff(data(:,i))./data(1:end-1,i));
    [h,Pjbtest4(i,1)]=jbtest(diff(data4(:,i)));
    [h,Pjbtest4(i,2)]=jbtest(diff(data4(:,i))./data4(1:end-1,i));
    [h,Pjbtest1(i,1)]=jbtest(diff(data1(:,i)));
    [h,Pjbtest1(i,2)]=jbtest(diff(data1(:,i))./data1(1:end-1,i));
end

% save to csv file
% save results in csv files
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
NM=8;


fid=fopen('irswap_gof_full_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n','Swap Maturity','Pearson Normal',...
    'Pearson Log-normal','AIC Normal','AIC Log-normal',...
    'KS Normal','KS Log-normal',...
    'AD Normal','AD Log-normal',...
    'Lilliefors Normal','Lilliefors Log-normal',...
    'JB Normal','JB Log-normal');
for i=1:N
    fprintf(fid,'%s,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f\n',...
        swap_maturity{i},Ppearson(i,1),Ppearson(i,2),aic(i,1),aic(i,2),...
        Pkstest(i,1),Pkstest(i,2),Padtest(i,1),Padtest(i,2),...
        Plillietest(i,1),Plillietest(i,2),Pjbtest(i,1),Pjbtest(i,2));
end
fclose(fid);

fid=fopen('irswap_gof_sample4_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n','Swap Maturity','Pearson Normal',...
    'Pearson Log-normal','AIC Normal','AIC Log-normal',...
    'KS Normal','KS Log-normal',...
    'AD Normal','AD Log-normal',...
    'Lilliefors Normal','Lilliefors Log-normal',...
    'JB Normal','JB Log-normal');
for i=1:N
    fprintf(fid,'%s,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f\n',...
        swap_maturity{i},Ppearson4(i,1),Ppearson4(i,2),aic4(i,1),aic4(i,2),...
        Pkstest4(i,1),Pkstest4(i,2),Padtest4(i,1),Padtest4(i,2),...
        Plillietest4(i,1),Plillietest4(i,2),Pjbtest4(i,1),Pjbtest4(i,2));
end
fclose(fid);


fid=fopen('irswap_gof_sample1_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s\n','Swap Maturity','Pearson Normal',...
    'Pearson Log-normal','AIC Normal','AIC Log-normal',...
    'KS Normal','KS Log-normal',...
    'AD Normal','AD Log-normal',...
    'Lilliefors Normal','Lilliefors Log-normal',...
    'JB Normal','JB Log-normal');
for i=1:N
    fprintf(fid,'%s,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f,%7.4f\n',...
        swap_maturity{i},Ppearson1(i,1),Ppearson1(i,2),aic1(i,1),aic1(i,2),...
        Pkstest1(i,1),Pkstest1(i,2),Padtest1(i,1),Padtest1(i,2),...
        Plillietest1(i,1),Plillietest1(i,2),Pjbtest1(i,1),Pjbtest1(i,2));
end
fclose(fid);