% function peaks = goldfeld_quandt(y,x)
% Compute nonparametric peaks test for homoscedasticity of Goldfels and
% Quandt
% INPUTS
% y(1:T,1)      = dependent variable
% x(1:T,1:N)    = covariates
% OUTPUTS
% peaks(1:2,1)  = count of peaks in origianl and deflated regressions
function peaks = goldfeld_quandt(y,x)

[T,N]=size(x);
peaks=NaN(2,1);
% check if N=1 and x is constant
if N<2 & abs(max(x)-min(x))<eps
    % implicit sorting is on t=1,...,T
    u=y-mean(y);
    peaks=peaks_count(u);
elseif N<2 % nonconstant single column
    % regress y on [1,x] and get residuals
    %[b,bint,u]=regress(y,[ones(T,1),x]);
    [b,bint,u]=regress(y,[x]);
    [z,ix]=sort(x);
    u2=u(ix);
    peaks(1)=peaks_count(u2);
    % regress y/x on 1 and get residuals
    u=y./x-mean(y./x);
    [z,ix]=sort(x,'descend');
    u2=u(ix);
    peaks(2)=peaks_count(u2);
else % multiple columns
    % check if last column is constant
    if abs(max(x(:,end))-min(x(:,end)))<eps
        % implicit sorting is on t=1,...,T
        [b,bint,u]=regress(y,x);
        peaks=peaks_count(u);
    else
        % regress y on x and get residuals
        [b,bint,u]=regress(y,x);
        % sort on last column
        [z,ix]=sort(x(:,end));
        u2=u(ix);
        peaks(1)=peaks_count(u2);
        % regress y/x(:,end) on x/x(:,end) and get residuals
        x2=x./repmat(x(:,end),1,N);
        [b,bint,u]=regress(y./x(:,end),x2);
        % sort on last column
        [z,ix]=sort(x(:,end),'descend');
        u2=u(ix);
        peaks(2)=peaks_count(u2);
    end
end


end
function peaks = peaks_count(z)
T=numel(z);
peaks=0;
for t=2:T-1
    if (abs(z(t))>=max(abs(z(1:t-1))))
        peaks=peaks+1;
    end
end

end


