% function [t1,t2,t3,t4] = imtest(y,x)
% Information matrix test and its Cameron-Trivedi decomposition
% INPUTS
% y(1:T,1)     = dependent variable
% x(1:T,1:N)   = independent varibles
% OUTPUTS
% imt          = IM test (=t2+t3+t4)
% t2           = heteroscedasticity component
% t3           = skewness component
% t4           = kurtosis component
% pimt         = p-value corresponding to imt in chi2(N+2)
% p2           = p-value corresponding to t2 in chi2(N)
% p3           = p-value corresponding to t3 in chi2(1)
% p4           = p-value corresponding to t4 in chi2(1)
function [imt,t2,t3,t4,pimt,p2,p3,p4] = imtest(y,x)

[b,bint,u,uint,stats]=regress(y,x);
[T,N]=size(x);
sigmasq=stats(4);
% 2nd order cross-product terms
z=x(:,1).^2;
for i=2:N
    for j=1:i
        z=[z,x(:,j).*x(:,i)];
    end
end
[b2,bint2,u2,uint2,stats2]=regress(u.^2-sigmasq,z);
%t2=T*stats2(1);
ss=sum((u.^2-sigmasq).^2);
rss=sum(u2.^2);
t2=T*(1-rss/ss);

[b3,bint3,u3,uint3,stats3]=regress(u.^3-3*sigmasq*u,x);
%[b3,bint3,u3,uint3,stats3]=regress((u/sqrt(sigmasq)).^3,x);
%t3=1/6*((u/sqrt(sigmasq)).^3)'*x*b3/sqrt(T)%
%t3=T*stats3(1)
ss=sum((u.^3-3*sigmasq*u).^2);
rss=sum(u3.^2);
t3=T*(1-rss/ss);

[b4,bint4,u4,uint4,stats4]=regress((u.^4-6*sigmasq*u.^2+3*sigmasq^2),ones(T,1));
%t4=T*stats4(1)
%t4=1/(24*T)*(sum((u/sqrt(sigmasq)).^4-3))^2
ss=sum((u.^4-6*sigmasq*u.^2+3*sigmasq^2).^2);
rss=sum(u4.^2);
t4=T*(1-rss/ss);

imt=t2+t3+t4;
pimt= 1-chi2cdf(imt,N+2);
p2=1-chi2cdf(t2,N);
p3=1-chi2cdf(t3,1);
p4=1-chi2cdf(t4,1);





