% lag selection for ARCH LM test
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
Form={'Diff','Ret'};
NM=8; % number of maturities
NF=2; % number of functional representations
NS=3; % number of (sub)samples
NL=[64,20,10]; % upper bound on ARCH lags depending on subsample


% load data
data=csvread('../data/irswap_daily_20000703_20120726.csv',1,1);
[T,N]=size(data);
dates=csvread('../data/irswap_daily_20000703_20120726.csv',1,0,[1,0,T,0]);
% last 4 years
i4=find(dates>=dates(end)-40000);
data4=data(i4,:);
T4=size(data4,1);
% last 1 year
i1=find(dates>=dates(end)-10000);
data1=data(i1,:);
T1=size(data1,1);
aicc=NaN(NM,NF,max(NL),NS);
olag=NaN(NM,NF,NS);
TS=[T,T4,T1];

% ARCH(L)
for s=1:NS
    clear y;
    for i=1:NM
        for j=1:NL(s)
            spec=garchset('Q',j);
            if s==1
                y=data(:,i);
            elseif s==2
                y=data4(:,i);
            else
                y=data1(:,1);
            end
            [Coeff,err,llf]=garchfit(spec,diff(y));
            aicc(i,1,j,s)=-2*llf+2*(j+1)+2*(j+1)*(j+2)/(TS(s)-j-2);
            [Coeff,err,llf]=garchfit(spec,diff(y)./y(1:end-1));
            aicc(i,2,j,s)=-2*llf+2*(j+1)+2*(j+1)*(j+2)/(TS(s)-j-2);
        end
        [baicc,olag(i,1,s)]=min(squeeze(aicc(i,1,:,s)));
        [baicc,olag(i,2,s)]=min(squeeze(aicc(i,2,:,s)));
    end
end


save irswaps_archlm_lags.mat

% save to csv files
fid=fopen('irswap_archolags_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Form',...
    'Full sample Optimal ARCH lags','4-year sample Optimal ARCH lags',...
    '1-year sample Optimal ARCH lags');
for i=1:NM
    for j=1:NF
        fprintf(fid,'%s,%s,%g,%g,%g\n',...
            swap_maturity{i},Form{j},squeeze(olag(i,j,:)));
    end
end
fclose(fid);

