% Rank-transformed Levene F-test (Nordstokke and Zumbo, 2010) 
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
Form={'Diff','Ret'};
NM=8; % number of maturities
NF=2; % number of functional representations
NS=3; % number of (sub)samples

% load data
data=csvread('../data/irswap_daily_20000703_20120726.csv',1,1);
[T,N]=size(data);
dates=csvread('../data/irswap_daily_20000703_20120726.csv',1,0,[1,0,T,0]);
% last 4 years
i4=find(dates>=dates(end)-40000);
data4=data(i4,:);
T4=size(data4,1);
% last 1 year
i1=find(dates>=dates(end)-10000);
data1=data(i1,:);
T1=size(data1,1);
Lt=NaN(NM,NF,NS);
pval=NaN(NM,NF,NS);
Lt2=NaN(NM,NF,NS);
pval2=NaN(NM,NF,NS);

% sorting on time
for i=1:NM
    [Lt(i,1,1),pval(i,1,1)]=levene3x_rank(diff(data(:,i)),[],'mean');
    [Lt(i,1,2),pval(i,1,2)]=levene3x_rank(diff(data4(:,i)),[],'mean');
    [Lt(i,1,3),pval(i,1,3)]=levene3x_rank(diff(data1(:,i)),[],'mean');
    [Lt(i,2,1),pval(i,2,1)]=levene3x_rank(diff(data(:,i))./data(1:end-1,i),[],'mean');
    [Lt(i,2,2),pval(i,2,2)]=levene3x_rank(diff(data4(:,i))./data4(1:end-1,i),[],'mean');
    [Lt(i,2,3),pval(i,2,3)]=levene3x_rank(diff(data1(:,i))./data1(1:end-1,i),[],'mean');
end
  
% sorting on level
for i=1:NM
    [Lt2(i,1,1),pval2(i,1,1)]=levene3x_rank(diff(data(:,i)),data(1:end-1,i),'mean');
    [Lt2(i,1,2),pval2(i,1,2)]=levene3x_rank(diff(data4(:,i)),data4(1:end-1,i),'mean');
    [Lt2(i,1,3),pval2(i,1,3)]=levene3x_rank(diff(data1(:,i)),data1(1:end-1,i),'mean');
    [Lt2(i,2,1),pval2(i,2,1)]=levene3x_rank(diff(data(:,i))./data(1:end-1,i),data(1:end-1,i),'mean');
    [Lt2(i,2,2),pval2(i,2,2)]=levene3x_rank(diff(data4(:,i))./data4(1:end-1,i),data4(1:end-1,i),'mean');
    [Lt2(i,2,3),pval2(i,2,3)]=levene3x_rank(diff(data1(:,i))./data1(1:end-1,i),data1(1:end-1,i),'mean');
end

save irswaps_levene3x_rank.mat

% save to csv files
fid=fopen('irswap_levene_rank_time_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s,%s,%s,%s\n','Swap Maturity','Form',...
    'Full sample Levene statistic','Full sample p-value','4-year sample Levene statistic',...
    '4-year sample p-value','1-year sample Levene statistics',...
    '1-year sample p-value');
for i=1:NM
    for j=1:NF
        fprintf(fid,'%s,%s,%7.2f,%11.8f,%7.2f,%11.8f,%7.2f,%11.8f\n',...
            swap_maturity{i},Form{j},Lt(i,j,1),pval(i,j,1),Lt(i,j,2),pval(i,j,2),...
            Lt(i,j,3),pval(i,j,3));
    end
end
fclose(fid);

% save to csv files
fid=fopen('irswap_levene_rank_level_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s,%s,%s,%s\n','Swap Maturity','Form',...
    'Full sample Levene statistic','Full sample p-value','4-year sample Levene statistic',...
    '4-year sample p-value','1-year sample Levene statistics',...
    '1-year sample p-value');
for i=1:NM
    for j=1:NF
        fprintf(fid,'%s,%s,%7.2f,%11.8f,%7.2f,%11.8f,%7.2f,%11.8f\n',...
            swap_maturity{i},Form{j},Lt2(i,j,1),pval2(i,j,1),Lt2(i,j,2),pval2(i,j,2),...
            Lt2(i,j,3),pval2(i,j,3));
    end
end
fclose(fid);