% function [Lt,pval]=levene3x_rank(y,x)
% Rank-transformed version of Levene test (Nordstokke and Zumbo, 2010)
% with sorting covariate using 1st and last thirds of the sample
% INPUTS:
% y(1:T,1)      = time-series to test equality ov varianes in 1st and last thirds
% x(1:T,1)      = sorting covariate (pass [] if not required)
% ct            = (optional) character indicator for the measure of central 
%                 tendency to use. Permitted values: 'mean', 'median', 
%                 'trimmean','mode'
% pct           = percentage of sample to trim (if ct='trimmean')
% OUTPUTS:
% Lt            = test statistic
% pval          = p-value corresponding to Lt
function [Lt,pval]=levene3x_rank(y,x,ct,pct)
[yso,iso]=sort(y);
if ~isempty(x);
    xso=x(iso);
else
    xso=x;
end
if nargin<3
    ct='mean';
    pct=[];
elseif nargin<4
    pct=[];
end
if isempty(ct)&& isempty(pct)
    [Lt,pval]=levene3x(yso,xso,[],[]);
elseif isempty(ct)
    [Lt,pval]=levene3x(yso,xso,[],pct);
elseif isempty(pct)
    [Lt,pval]=levene3x(yso,xso,ct,[]);
else
    [Lt,pval]=levene3x(yso,xso,ct,pct);
end

