% testing goldfeld_quandt under the null hypothesis
NMC=12800;
T=[253,1003,3019];
peaks=NaN(NMC,3);
h=waitbar(0,'Monte Carlo on Peaks Test ...');
for i=1:NMC
    waitbar(i/NMC);
    for s=1:3
        y=randn(T(s),1);
        x=ones(T(s),1);
        pks=goldfeld_quandt(y,x);
        peaks(i,s)=pks(1);
    end
end
close(h)

median(peaks)

[ecdf1,x1]=ecdf(peaks(:,1));
[ecdf2,x2]=ecdf(peaks(:,2));
[ecdf3,x3]=ecdf(peaks(:,3)); 
% realized range of peaks
xmin=0;
xmax=max([max(x1'),max(x2'),max(x3')]);
% load theoretical CDFs
cdf1=csvread('PeakTest253.csv');
cdf2=csvread('PeakTest1003.csv');
cdf3=csvread('PeakTest3019.csv');

figure;
subplot(3,1,1);
plot(x1(2:end),ecdf1(2:end),'r-');
hold on;
plot(x1(2:end),cdf1(x1(2:end)+1),'b-');
legend('Monte Carlo CDF','Exact CDF');
subplot(3,1,2);
plot(x2(2:end),ecdf2(2:end),'r-');
hold on;
plot(x2(2:end),cdf2(x2(2:end)+1),'b-');
legend('Monte Carlo CDF','Exact CDF');
subplot(3,1,3);
plot(x3(2:end),ecdf3(2:end),'r-');
hold on;
plot(x3(2:end),cdf3(x3(2:end)+1),'b-');
legend('Monte Carlo CDF','Exact CDF');

figure;
subplot(3,1,1);
plot(x1(2:end),cdf1(x1(2:end)+1),'b-');
ylabel('Cumulative probability');
title('Exact CDF of Goldfeld-Quandt Peaks Test');
subplot(3,1,2);
plot(x2(2:end),cdf2(x2(2:end)+1),'b-');
ylabel('Cumulative probability');
subplot(3,1,3);
plot(x3(2:end),cdf3(x3(2:end)+1),'b-');
xlabel('Number of peaks');
ylabel('Cumulative probability');
print('-depsc2','Goldfeld_Quandt_CDF.eps');
print('-djpeg','Goldfeld_Quandt_CDF.jpg');
print('-dpdf','Goldfeld_Quandt_CDF.pdf');