% compute log-likelihood function for hybrid piecewise elasticity of
% volatility model with normal innovations
% INPUTS
% r0        = initial value
% r(1:T)    = sample, purpotedly from HPEV with normal innovations
% mu        = mean drift
% sigmabar  = scale of variance
% gamma     = elasticity of variance
% lambda    = slope parameter for high level regime
% r_l       = bound for low level regime
% r_u       = bound for high level regime
% OUTPUTS
% L         = log-likelihood function

function L = hpev3_normal_loglikelihood(r0,r,mu,sigmabar,gamma,lambda,r_l,r_u)

T=numel(r);
H=ones(T-1,1);
H0=1;
if r0>r_u
    H0=1+lambda*(r0-r_u);
elseif r0<r_l 
    H0=(abs(r0)/r_l)^gamma;
end
for t=1:T-1
    if r(t)>r_u
        H(t)=1+lambda*(r(t)-r_u);
    elseif r(t)<r_l 
        H(t)=(abs(r(t))/r_l)^gamma;
    end
end
L=log(1/(sqrt(2*pi)*sigmabar*H0))-((r(1)-r0-mu)^2/(2*sigmabar^2*H0^2));
if isnan(L)
    L=0;
end
for t=2:T
    L1=log(1/(sqrt(2*pi)*sigmabar*H(t-1)))-((r(t)-r(t-1)-mu)^2/(2*sigmabar^2*H(t-1)^2));
    if ~isnan(L1)
        L=L+L1;
    end
end

