% maximum likelihood estimator of hybrid piecewise elasticity of volatility
% model with normal innovations
% INPUTS:
% y(1:T)     = univariate data time-series
% alpha      = (optional) confidence level for estimates, defualt is 0.95
% start      = (optional) vector of starting guesses
% OUTPUTS:
% p(1:7) = estimated model parameters, namely
%   p(1)    = mu = mean drift
%   p(2)    = sigmabar = scale of volatility
%   p(3)    = gamma = elasticity of volatility at low levels
%   p(4)    = lambda = slope of return relationship for high levels
%   p(5)    = r_l = bound for low levels
%   p(6)    = r_u = upper bound of medium regime
%   p(7)    = nu  = degrees of freedom parameter
% ci(1:2,1:7)   = confidence bounds at significance level alpha
% aic       = Akaike information criterion
function [p,ci,aic] = hpev3_t_mle(y,alpha,start)

if nargin<2
    alpha=0.05;
end
if nargin<3
    start=[0,log(std(diff(y))),0.75,0.5,2,1,5];
end
T=size(y,1);

myoptions=statset('MaxFunEvals',10*T,'MaxIter',10000);


lb=[-Inf,-10,-10,0,.1,-10,1];
ub=Inf(1,7);ub(2)=0;ub(6)=log(10);


hpevt_loglikelihood=@(params,data,cens,freq)(-hpev3_t_llf(params,data,cens,freq));
[p,ci]=mle(y, 'nloglf', hpevt_loglikelihood, 'start',start,'options',myoptions,'lowerbound',lb,'upperbound',ub,'optimfun','fmincon','alpha',alpha,'optimfun','fmincon');
aic=2*7+2*hpevt_loglikelihood(p,y,[],[]);
% constrain r_u>r_l by their differnce
p(6)=p(5)+exp(p(6));
ci(:,6)=ci(:,5)+exp(ci(:,6));
p(2)=exp(p(2));
ci(:,2)=exp(ci(:,2));