% function r =
% hpev_normal_simulator(T,theta,kappa,sigma,gammabar,rho,sigma_eta,y0,gamma0)
% Simulating hybrid piecewise elasticity of volatility model
% r(t)-r(t-1)=mu+sigmabar*H(abs(r(t-1)))*epsilon(t) where
% H(r) = (r/r_l)^gamma if r<r_l
% H(r) = 1 if r_l<=r<r_u
% H(r) = 1+lambda*(r-r_u) if r>r_u
% epsilon(t)~iid t(nu)
% INPUTS
% T         = length of time-series to simulate
% mu        = mean drift
% sigmabar  = scale of volatility
% gamma     = elasticity of volatility at low r levels
% lambda    = volatility slope at high r levels
% r_l       = cutoff for low r levels
% r_u       = cutoff for high r levels
% nu        = degrees of freedom parameter for Student t distribution
% r0 = initial value of observed time-series
% OUTPUTS
% r(1:T)    = simulated output series
% H(1:T)    = simulated volatility multiplier
function [r,H] = hpev3_t_simulator(T,mu,sigmabar,gamma,lambda,r_l,r_u,nu,r0)

r=NaN(T,1);
H=ones(T,1);
epsilon=trnd(nu,T,1);
if r0>r_u
    H(1)=1+lambda*(r0-r_u);
elseif r0<r_l
    H(1)=(abs(r0)/r_l)^gamma;
end
r(1)=r0+mu+sigmabar*H(1)*epsilon(1);
if T>1
    for t=2:T
        if r(t-1)>r_u
            H(t)=1+lambda*(r(t-1)-r_u);
        elseif r(t-1)<r_l 
            H(t)=(abs(r(t-1))/r_l)^gamma;
        end
        r(t)=r(t-1)+mu+sigmabar*H(t)*epsilon(t);
    end
end