% compute log-likelihood function for hybrid piecewise elasticity of
% volatility model with normal innovations
% INPUTS
% r0        = initial value
% r(1:T)    = sample, purpotedly from HPEV with normal innovations
% theta     = long-run mean
% kappa     = speed of mean reversion
% sigmabar  = scale of variance
% gamma     = elasticity of variance
% lambda    = slope parameter for high level regime
% r_l       = bound for low level regime
% r_u       = bound for high level regime
% OUTPUTS
% L         = log-likelihood function

function L = hpev_normal_loglikelihood(r0,r,theta,kappa,sigmabar,gamma,lambda,r_l,r_u)

T=numel(r);
H=ones(T-1,1);
H0=1;
if r0>r_u
    H0=1+lambda*(r0-r_u);
elseif r0<r_l 
    H0=(abs(r0)/r_l)^gamma;
end
for t=1:T-1
    if r(t)>r_u
        H(t)=1+lambda*(r(t)-r_u);
    elseif r(t)<r_l 
        H(t)=(abs(r(t))/r_l)^gamma;
    end
end
L=log(normpdf((r(1)-r0-kappa*(theta-r0))/(sigmabar*H0))/(sigmabar*H0));
if ~isnan(L)
    L=L+nansum(log(normpdf((r(2:end)-r(1:end-1)-kappa*(theta-r(1:end-1)))./(sigmabar.*H))./(sigmabar.*H)));
else
    L=nansum(log(normpdf((r(2:end)-r(1:end-1)-kappa*(theta-r(1:end-1)))./(sigmabar.*H))./(sigmabar.*H)));
end
