% estimate  HPEV3 model with normal
% innovations on irswap data with maximum likelihood

% load data
data=csvread('../data/irswap_daily_20000703_20120726.csv',1,1);
[T,N]=size(data);
dates=csvread('../data/irswap_daily_20000703_20120726.csv',1,0,[1,0,T,0]);
p=NaN(N,6);
ci=NaN(2,6,N);
aic=NaN(N,1);
p4=NaN(N,6);
ci4=NaN(2,6,N);
aic4=NaN(N,1);
p1=NaN(N,6);
ci1=NaN(2,6,N);
aic1=NaN(N,1);
alpha=0.05;
% last 4 years
i4=find(dates>=dates(end)-40000);
data4=data(i4,:);
T4=size(data4,1);
% last 1 year
i1=find(dates>=dates(end)-10000);
data1=data(i1,:);
T1=size(data1,1);
names={'US IRSWAPS 1y','US IRSWAPS 2y','US IRSWAPS 3y','US IRSWAPS 4y',...
    'US IRSWAPS 5y','US IRSWAPS 7y','US IRSWAPS 10y','US IRSWAPS 30y'};


% full sample
for i=1:N
    % starting guess for full sample
    i
    start=[0,log(std(diff(data(:,i)))),0.75, 0.5, 1,log(3)];
    [p(i,:),ci(:,:,i),aic(i)] = hpev3_normal_mle(data(:,i),alpha,start);
    
    
end

% last 4 years
for i=1:N
    % starting guess for full sample
    i
    start=[0,log(std(diff(data4(:,i)))),0.75,0.5,1,log(3)];
    [p4(i,:),ci4(:,:,i),aic4(i)] = hpev3_normal_mle(data4(:,i),alpha,start);
    
    
end

% last 1 year
for i=1:N
    % starting guess for full sample
    i
   start=[0,log(std(diff(data1(:,i)))),0.75,0.5,1,log(3)];
   [p1(i,:),ci1(:,:,i),aic1(i)] = hpev3_normal_mle(data1(:,i),alpha,start);
    
    
end

% save results in csv files
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'mu','sigma','gamma','lambda','r_l','r_u'};
NM=8;
NV=6;

% full sample
fid=fopen('irswap_hpev3_normal_full_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','ML Estimate',...
    '2.5th percentile bound','97.5th percentile bound');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            p(i,j),ci(1,j,i),ci(2,j,i));
    end
end
fclose(fid);

% 4-year sample
fid=fopen('irswap_hpev3_normal_sample4_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','ML Estimate',...
    '2.5th percentile bound','97.5th percentile bound');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            p4(i,j),ci4(1,j,i),ci4(2,j,i));
    end
end
fclose(fid);

% 1-year sample
fid=fopen('irswap_hpev3_normal_sample1_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','ML Estimate',...
    '2.5th percentile bound','97.5th percentile bound');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            p1(i,j),ci1(1,j,i),ci1(2,j,i));
    end
end
fclose(fid);