% estimate hybrid piecewise elasticity of volatility model with normal
% innovations on irswap data with maximum likelihood

% load data
data=csvread('../data/irswap_daily_20000703_20120726.csv',1,1);
[T,N]=size(data);
dates=csvread('../data/irswap_daily_20000703_20120726.csv',1,0,[1,0,T,0]);
p=NaN(N,7);
ci=NaN(2,7,N);
aic=NaN(N,1);
alpha=0.05;
% last 4 years
i4=find(dates>=dates(end)-40000);
data4=data(i4,:);
% last 1 year
i1=find(dates>=dates(end)-10000);
data1=data(i1,:);
names={'US IRSWAPS 1y','US IRSWAPS 2y','US IRSWAPS 3y','US IRSWAPS 4y',...
    'US IRSWAPS 5y','US IRSWAPS 7y','US IRSWAPS 10y','US IRSWAPS 30y'};

% statistics on fill-forwards

for i=1:N
    % starting guess for full sample
    i
    start=[mean(data(:,i)),0,log(std(diff(data(:,i)))),0.75,0.5,2,0];
    % use a version with preliminary brute-force search
    [p(i,:),ci(:,:,i),aic(i),restart] = hpev_normal_mle_brute(data(:,i),alpha,start);
    
    % follow up by a refined version of global search
    [p(i,:),ci(:,:,i),aic(i),restart] = hpev_normal_mle_globalsearch(data(:,i),alpha,restart);
    
    
end


% save results in csv files


% plot implied volatility function profiles

% full sample profiles
for i=1:N
    rmin=min(data(:,i));
    rmax=max(data(:,i));
    rspace=rmin:0.01:rmax;
    rl=p(i,6); 
    ru=p(i,7);
    sigmabar=p(i,3);
    gamma=p(i,4);
    lambda=p(i,5);
    NR=size(rspace,2);
    v=NaN(NR,1);
    for j=1:NR
        if rspace(j)<rl
            v(j)=sigmabar*(rspace(j)/rl)^gamma;
        elseif rspace(j)>ru
            v(j)=sigmabar*(1+lambda*(rspace(j)-ru));
        else
            v(j)=sigmabar;
        end
    end
    figure;
    plot(rspace,v,'r-','LineWidth',2);
    axis tight
    title([names{i},'  Full Sample']);
    xlabel('r');
    ylabel('Volatility');
end

% 4 year window profiles
for i=1:N
    rmin=min(data4(:,i));
    rmax=max(data4(:,i));
    rspace=rmin:0.01:rmax;
    rl=p(i,6); 
    ru=p(i,7);
    sigmabar=p(i,3);
    gamma=p(i,4);
    lambda=p(i,5);
    NR=size(rspace,2);
    v=NaN(NR,1);
    for j=1:NR
        if rspace(j)<rl
            v(j)=sigmabar*(rspace(j)/rl)^gamma;
        elseif rspace(j)>ru
            v(j)=sigmabar*(1+lambda*(rspace(j)-ru));
        else
            v(j)=sigmabar;
        end
    end
    figure;
    plot(rspace,v,'r-','LineWidth',2);
    axis tight
    title([names{i},'  Four-year Sample']);
    xlabel('r');
    ylabel('Volatility');
end

% 1y window profiles
for i=1:N
    rmin=min(data1(:,i));
    rmax=max(data1(:,i));
    rspace=rmin:0.01:rmax;
    rl=p(i,6); 
    ru=p(i,7);
    sigmabar=p(i,3);
    gamma=p(i,4);
    lambda=p(i,5);
    NR=size(rspace,2);
    v=NaN(NR,1);
    for j=1:NR
        if rspace(j)<rl
            v(j)=sigmabar*(rspace(j)/rl)^gamma;
        elseif rspace(j)>ru
            v(j)=sigmabar*(1+lambda*(rspace(j)-ru));
        else
            v(j)=sigmabar;
        end
    end
    figure;
    plot(rspace,v,'r-','LineWidth',2);
    axis tight
    title([names{i},'  One-year Sample']);
    xlabel('r');
    ylabel('Volatility');
end

% profiles for 3 subsamples in the same plot