% process results of Bayesian Hybrid Piecewise Elasticity of Volatility model

%% results using full sample
NM=8;
% load saved samples of parameters
d=load('mu_full_hpev3t_panel_chain1.txt');
NMC=size(d,1)/NM;
mu_sample=reshape(d(:,2),NMC,NM);

d=load('sigma_full_hpev3t_panel_chain1.txt');
sigma_sample=reshape(d(:,2),NMC,NM);

% rlow is the same for all maturities
d=load('rlow_full_hpev3t_panel_chain1.txt');
rlow_sample=d(:,2);

% rup is the same for all maturities
d=load('rup_full_hpev3t_panel_chain1.txt');
rup_sample=d(:,2);

% gamma is the same for all maturities
d=load('gamma_full_hpev3t_panel_chain1.txt');
gamma_sample=d(:,2);

d=load('nu_full_hpev3t_panel_chain1.txt');
nu_sample=reshape(d(:,2),NMC,NM);

% lambda is the same for all maturities
d=load('lambda_full_hpev3t_panel_chain1.txt');
lambda_sample=d(:,2);


% compute some simple statistics
mean_mu=mean(mu_sample);
median_mu=median(mu_sample);
p025_mu=prctile(mu_sample,2.5);
p975_mu=prctile(mu_sample,97.5);
std_mu=std(mu_sample);

mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);
p025_sigma=prctile(sigma_sample,2.5);
p975_sigma=prctile(sigma_sample,97.5);
std_sigma=std(sigma_sample);

mean_rlow=mean(rlow_sample);
median_rlow=median(rlow_sample);
p025_rlow=prctile(rlow_sample,2.5);
p975_rlow=prctile(rlow_sample,97.5);
std_rlow=std(rlow_sample);

mean_rup=mean(rup_sample);
median_rup=median(rup_sample);
p025_rup=prctile(rup_sample,2.5);
p975_rup=prctile(rup_sample,97.5);
std_rup=std(rup_sample);

mean_lambda=mean(lambda_sample);
median_lambda=median(lambda_sample);
p025_lambda=prctile(lambda_sample,2.5);
p975_lambda=prctile(lambda_sample,97.5);
std_lambda=std(lambda_sample);

mean_gamma=mean(gamma_sample);
median_gamma=median(gamma_sample);
p025_gamma=prctile(gamma_sample,2.5);
p975_gamma=prctile(gamma_sample,97.5);
std_gamma=std(gamma_sample);

mean_nu=mean(nu_sample);
median_nu=median(nu_sample);
p025_nu=prctile(nu_sample,2.5);
p975_nu=prctile(nu_sample,97.5);
std_nu=std(nu_sample);


medians=[median_mu;median_sigma;median_rlow*ones(1,NM);median_rup*ones(1,NM);median_gamma*ones(1,NM);median_lambda*ones(1,NM);median_nu];
p025=[p025_mu;p025_sigma;p025_rlow*ones(1,NM);p025_rup*ones(1,NM);p025_gamma*ones(1,NM);p025_lambda*ones(1,NM);p025_nu];
p975=[p975_mu;p975_sigma;p975_rlow*ones(1,NM);p975_rup*ones(1,NM);p975_gamma*ones(1,NM);p975_lambda*ones(1,NM);p975_nu];
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'mu','sigma','rlow','rup','gamma','lambda','nu'};
NV=7;

% save posterior medians and posterior 95% confidence intervals into a file
fid=fopen('irswap_hpev3t_full_panelstats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','Posterior Median',...
    'Posterior 2.5th percentile','Posterior 97.5th percentile');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            medians(j,i),p025(j,i),p975(j,i));
    end
end
fclose(fid);

% kernel-smoothed density plots of posterior marginal densities
NK=100;
% all maturity-dependent densities
% mu
ksd_mu=NaN(NM,NK);
xsd_mu=NaN(NM,NK);
for i=1:NM   
    lb=prctile(mu_sample(:,i),2.5);
    ub=prctile(mu_sample(:,i),97.5);
    il=find(mu_sample(:,i)>lb);
    gsample=mu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_mu(i,:),xsd_mu(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_mu(i,:),ksd_mu(i,:),'r-','LineWidth',2);
    xlabel('\mu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=['mu_',swap_maturity{i},'_full_panel_ksd_hpev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% sigma
ksd_sigma=NaN(NM,NK);
xsd_sigma=NaN(NM,NK);
for i=1:NM   
    lb=prctile(sigma_sample(:,i),2.5);
    ub=prctile(sigma_sample(:,i),97.5);
    il=find(sigma_sample(:,i)>lb);
    gsample=sigma_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_sigma(i,:),xsd_sigma(i,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
    figure;
    plot(xsd_sigma(i,:),ksd_sigma(i,:),'r-','LineWidth',2);
    xlabel('\sigma');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=['sigma_',swap_maturity{i},'_full_panel_ksd_hpev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% nu
ksd_nu=NaN(NM,NK);
xsd_nu=NaN(NM,NK);
for i=1:NM   
    lb=prctile(nu_sample(:,i),2.5);
    ub=prctile(nu_sample(:,i),97.5);
    il=find(nu_sample(:,i)>lb);
    gsample=nu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_nu(i,:),xsd_nu(i,:)]=ksdensity(fsample,'npoints',NK,'support',[0.99,130.1]);
    figure;
    plot(xsd_nu(i,:),ksd_nu(i,:),'r-','LineWidth',2);
    xlabel('\nu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=['nu_',swap_maturity{i},'_full_panel_ksd_hpev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% rlow is not maturity-dependent
ksd_rlow=NaN(3,NK); % for 3 sub-samples
xsd_rlow=NaN(3,NK);
lb=prctile(rlow_sample,2.5);
ub=prctile(rlow_sample,97.5);
il=find(rlow_sample>lb);
gsample=rlow_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_rlow(1,:),xsd_rlow(1,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_rlow(1,:),ksd_rlow(1,:),'r-','LineWidth',2);
xlabel('r_L');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (full sample)']);
filename=['rlow_fullpanel_ksd_hpev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% rup is not maturity-dependent
ksd_rup=NaN(3,NK); % for 3 sub-samples
xsd_rup=NaN(3,NK);
lb=prctile(rup_sample,2.5);
ub=prctile(rup_sample,97.5);
il=find(rup_sample>lb);
gsample=rup_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_rup(1,:),xsd_rup(1,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
figure;
plot(xsd_rup(1,:),ksd_rup(1,:),'r-','LineWidth',2);
xlabel('r_U');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (full sample)']);
filename=['rup_fullpanel_ksd_hpev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% gamma is not maturity-dependent
ksd_gamma=NaN(3,NK); % for 3 sub-samples
xsd_gamma=NaN(3,NK);
lb=prctile(gamma_sample,2.5);
ub=prctile(gamma_sample,97.5);
il=find(gamma_sample>lb);
gsample=gamma_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_gamma(1,:),xsd_gamma(1,:)]=ksdensity(fsample,'npoints',NK,'support',[-1.001,2.001]);
figure;
plot(xsd_gamma(1,:),ksd_gamma(1,:),'r-','LineWidth',2);
xlabel('\gamma');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (full sample)']);
filename=['gamma_fullpanel_ksd_hpev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% lambda is not maturity-dependent
ksd_lambda=NaN(3,NK); % for 3 sub-samples
xsd_lambda=NaN(3,NK);
lb=prctile(lambda_sample,2.5);
ub=prctile(lambda_sample,97.5);
il=find(lambda_sample>lb);
gsample=lambda_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_lambda(1,:),xsd_lambda(1,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_lambda(1,:),ksd_lambda(1,:),'r-','LineWidth',2);
xlabel('\lambda');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (full sample)']);
filename=['lambda_fullpanel_ksd_hpev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% save data to mat file
save irswap_panel_hpev3t_fullsample_postprocess.mat

%% 4-year subsample
% load saved samples of parameters
d=load('mu_sample4_hpev3t_panel_chain1.txt');
mu_sample=reshape(d(:,2),NMC,NM);

d=load('sigma_sample4_hpev3t_panel_chain1.txt');
sigma_sample=reshape(d(:,2),NMC,NM);

% rlow is the same for all maturities
d=load('rlow_sample4_hpev3t_panel_chain1.txt');
rlow_sample=d(:,2);

% rup is the same for all maturities
d=load('rup_sample4_hpev3t_panel_chain1.txt');
rup_sample=d(:,2);

% gamma is the same for all maturities
d=load('gamma_sample4_hpev3t_panel_chain1.txt');
gamma_sample=d(:,2);

d=load('nu_sample4_hpev3t_panel_chain1.txt');
nu_sample=reshape(d(:,2),NMC,NM);

% lambda is the same for all maturities
d=load('lambda_sample4_hpev3t_panel_chain1.txt');
lambda_sample=d(:,2);


% compute some simple statistics
mean_mu=mean(mu_sample);
median_mu=median(mu_sample);
p025_mu=prctile(mu_sample,2.5);
p975_mu=prctile(mu_sample,97.5);
std_mu=std(mu_sample);

mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);
p025_sigma=prctile(sigma_sample,2.5);
p975_sigma=prctile(sigma_sample,97.5);
std_sigma=std(sigma_sample);

mean_rlow=mean(rlow_sample);
median_rlow=median(rlow_sample);
p025_rlow=prctile(rlow_sample,2.5);
p975_rlow=prctile(rlow_sample,97.5);
std_rlow=std(rlow_sample);

mean_rup=mean(rup_sample);
median_rup=median(rup_sample);
p025_rup=prctile(rup_sample,2.5);
p975_rup=prctile(rup_sample,97.5);
std_rup=std(rup_sample);

mean_lambda=mean(lambda_sample);
median_lambda=median(lambda_sample);
p025_lambda=prctile(lambda_sample,2.5);
p975_lambda=prctile(lambda_sample,97.5);
std_lambda=std(lambda_sample);

mean_gamma=mean(gamma_sample);
median_gamma=median(gamma_sample);
p025_gamma=prctile(gamma_sample,2.5);
p975_gamma=prctile(gamma_sample,97.5);
std_gamma=std(gamma_sample);

mean_nu=mean(nu_sample);
median_nu=median(nu_sample);
p025_nu=prctile(nu_sample,2.5);
p975_nu=prctile(nu_sample,97.5);
std_nu=std(nu_sample);


medians=[median_mu;median_sigma;median_rlow*ones(1,NM);median_rup*ones(1,NM);median_gamma*ones(1,NM);median_lambda*ones(1,NM);median_nu];
p025=[p025_mu;p025_sigma;p025_rlow*ones(1,NM);p025_rup*ones(1,NM);p025_gamma*ones(1,NM);p025_lambda*ones(1,NM);p025_nu];
p975=[p975_mu;p975_sigma;p975_rlow*ones(1,NM);p975_rup*ones(1,NM);p975_gamma*ones(1,NM);p975_lambda*ones(1,NM);p975_nu];
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'mu','sigma','rlow','rup','gamma','lambda','nu'};
NV=7;

% save posterior medians and posterior 95% confidence intervals into a file
fid=fopen('irswap_hpev3t_sample4_panelstats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','Posterior Median',...
    'Posterior 2.5th percentile','Posterior 97.5th percentile');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            medians(j,i),p025(j,i),p975(j,i));
    end
end
fclose(fid);

% kernel-smoothed density plots of posterior marginal densities
NK=100;
% all maturity-dependent densities
% mu
ksd_mu=NaN(NM,NK);
xsd_mu=NaN(NM,NK);
for i=1:NM   
    lb=prctile(mu_sample(:,i),2.5);
    ub=prctile(mu_sample(:,i),97.5);
    il=find(mu_sample(:,i)>lb);
    gsample=mu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_mu(i,:),xsd_mu(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_mu(i,:),ksd_mu(i,:),'r-','LineWidth',2);
    xlabel('\mu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=['mu_',swap_maturity{i},'_sample4_panel_ksd_hpev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% sigma
ksd_sigma=NaN(NM,NK);
xsd_sigma=NaN(NM,NK);
for i=1:NM   
    lb=prctile(sigma_sample(:,i),2.5);
    ub=prctile(sigma_sample(:,i),97.5);
    il=find(sigma_sample(:,i)>lb);
    gsample=sigma_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_sigma(i,:),xsd_sigma(i,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
    figure;
    plot(xsd_sigma(i,:),ksd_sigma(i,:),'r-','LineWidth',2);
    xlabel('\sigma');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=['sigma_',swap_maturity{i},'_sample4_panel_ksd_hpev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% nu
ksd_nu=NaN(NM,NK);
xsd_nu=NaN(NM,NK);
for i=1:NM   
    lb=prctile(nu_sample(:,i),2.5);
    ub=prctile(nu_sample(:,i),97.5);
    il=find(nu_sample(:,i)>lb);
    gsample=nu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_nu(i,:),xsd_nu(i,:)]=ksdensity(fsample,'npoints',NK,'support',[0.99,130.1]);
    figure;
    plot(xsd_nu(i,:),ksd_nu(i,:),'r-','LineWidth',2);
    xlabel('\nu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=['nu_',swap_maturity{i},'_sample4_panel_ksd_hpev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% rlow is not maturity-dependent
lb=prctile(rlow_sample,2.5);
ub=prctile(rlow_sample,97.5);
il=find(rlow_sample>lb);
gsample=rlow_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_rlow(2,:),xsd_rlow(2,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_rlow(2,:),ksd_rlow(2,:),'r-','LineWidth',2);
xlabel('r_L');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (4-year sample)']);
filename=['rlow_sample4_panel_ksd_hpev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% rup is not maturity-dependent
lb=prctile(rup_sample,2.5);
ub=prctile(rup_sample,97.5);
il=find(rup_sample>lb);
gsample=rup_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_rup(2,:),xsd_rup(2,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
figure;
plot(xsd_rup(2,:),ksd_rup(2,:),'r-','LineWidth',2);
xlabel('r_U');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (4-year sample)']);
filename=['rup_sample4_panel_ksd_hpev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% gamma is not maturity-dependent
lb=prctile(gamma_sample,2.5);
ub=prctile(gamma_sample,97.5);
il=find(gamma_sample>lb);
gsample=gamma_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_gamma(2,:),xsd_gamma(2,:)]=ksdensity(fsample,'npoints',NK,'support',[-1.001,2.001]);
figure;
plot(xsd_gamma(2,:),ksd_gamma(2,:),'r-','LineWidth',2);
xlabel('\gamma');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (4-year sample)']);
filename=['gamma_sample4_panel_ksd_hpev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% lambda is not maturity-dependent
lb=prctile(lambda_sample,2.5);
ub=prctile(lambda_sample,97.5);
il=find(lambda_sample>lb);
gsample=lambda_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_lambda(2,:),xsd_lambda(2,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_lambda(2,:),ksd_lambda(2,:),'r-','LineWidth',2);
xlabel('\lambda');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (4-year sample)']);
filename=['lambda_sample4_panel_ksd_hpev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

save irswap_panel_hpev3t_sample4_postprocess.mat

%% 1-year subsample
% load saved samples of parameters
d=load('mu_sample1_hpev3t_panel_chain1.txt');
mu_sample=reshape(d(:,2),NMC,NM);

d=load('sigma_sample1_hpev3t_panel_chain1.txt');
sigma_sample=reshape(d(:,2),NMC,NM);

% rlow is the same for all maturities
d=load('rlow_sample1_hpev3t_panel_chain1.txt');
rlow_sample=d(:,2);

% rup is the same for all maturities
d=load('rup_sample1_hpev3t_panel_chain1.txt');
rup_sample=d(:,2);

% gamma is the same for all maturities
d=load('gamma_sample1_hpev3t_panel_chain1.txt');
gamma_sample=d(:,2);

d=load('nu_sample1_hpev3t_panel_chain1.txt');
nu_sample=reshape(d(:,2),NMC,NM);

% lambda is the same for all maturities
d=load('lambda_sample1_hpev3t_panel_chain1.txt');
lambda_sample=d(:,2);


% compute some simple statistics
mean_mu=mean(mu_sample);
median_mu=median(mu_sample);
p025_mu=prctile(mu_sample,2.5);
p975_mu=prctile(mu_sample,97.5);
std_mu=std(mu_sample);

mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);
p025_sigma=prctile(sigma_sample,2.5);
p975_sigma=prctile(sigma_sample,97.5);
std_sigma=std(sigma_sample);

mean_rlow=mean(rlow_sample);
median_rlow=median(rlow_sample);
p025_rlow=prctile(rlow_sample,2.5);
p975_rlow=prctile(rlow_sample,97.5);
std_rlow=std(rlow_sample);

mean_rup=mean(rup_sample);
median_rup=median(rup_sample);
p025_rup=prctile(rup_sample,2.5);
p975_rup=prctile(rup_sample,97.5);
std_rup=std(rup_sample);

mean_lambda=mean(lambda_sample);
median_lambda=median(lambda_sample);
p025_lambda=prctile(lambda_sample,2.5);
p975_lambda=prctile(lambda_sample,97.5);
std_lambda=std(lambda_sample);

mean_gamma=mean(gamma_sample);
median_gamma=median(gamma_sample);
p025_gamma=prctile(gamma_sample,2.5);
p975_gamma=prctile(gamma_sample,97.5);
std_gamma=std(gamma_sample);

mean_nu=mean(nu_sample);
median_nu=median(nu_sample);
p025_nu=prctile(nu_sample,2.5);
p975_nu=prctile(nu_sample,97.5);
std_nu=std(nu_sample);


medians=[median_mu;median_sigma;median_rlow*ones(1,NM);median_rup*ones(1,NM);median_gamma*ones(1,NM);median_lambda*ones(1,NM);median_nu];
p025=[p025_mu;p025_sigma;p025_rlow*ones(1,NM);p025_rup*ones(1,NM);p025_gamma*ones(1,NM);p025_lambda*ones(1,NM);p025_nu];
p975=[p975_mu;p975_sigma;p975_rlow*ones(1,NM);p975_rup*ones(1,NM);p975_gamma*ones(1,NM);p975_lambda*ones(1,NM);p975_nu];
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'mu','sigma','rlow','rup','gamma','lambda','nu'};
NV=7;

% save posterior medians and posterior 95% confidence intervals into a file
fid=fopen('irswap_hpev3t_sample1_panelstats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','Posterior Median',...
    'Posterior 2.5th percentile','Posterior 97.5th percentile');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            medians(j,i),p025(j,i),p975(j,i));
    end
end
fclose(fid);

% kernel-smoothed density plots of posterior marginal densities
NK=100;
% all maturity-dependent densities
% mu
ksd_mu=NaN(NM,NK);
xsd_mu=NaN(NM,NK);
for i=1:NM   
    lb=prctile(mu_sample(:,i),2.5);
    ub=prctile(mu_sample(:,i),97.5);
    il=find(mu_sample(:,i)>lb);
    gsample=mu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_mu(i,:),xsd_mu(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_mu(i,:),ksd_mu(i,:),'r-','LineWidth',2);
    xlabel('\mu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=['mu_',swap_maturity{i},'_sample1_panel_ksd_hpev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% sigma
ksd_sigma=NaN(NM,NK);
xsd_sigma=NaN(NM,NK);
for i=1:NM   
    lb=prctile(sigma_sample(:,i),2.5);
    ub=prctile(sigma_sample(:,i),97.5);
    il=find(sigma_sample(:,i)>lb);
    gsample=sigma_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_sigma(i,:),xsd_sigma(i,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
    figure;
    plot(xsd_sigma(i,:),ksd_sigma(i,:),'r-','LineWidth',2);
    xlabel('\sigma');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=['sigma_',swap_maturity{i},'_sample1_panel_ksd_hpev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% nu
ksd_nu=NaN(NM,NK);
xsd_nu=NaN(NM,NK);
for i=1:NM   
    lb=prctile(nu_sample(:,i),2.5);
    ub=prctile(nu_sample(:,i),97.5);
    il=find(nu_sample(:,i)>lb);
    gsample=nu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_nu(i,:),xsd_nu(i,:)]=ksdensity(fsample,'npoints',NK,'support',[0.99,130.1]);
    figure;
    plot(xsd_nu(i,:),ksd_nu(i,:),'r-','LineWidth',2);
    xlabel('\nu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=['nu_',swap_maturity{i},'_sample1_panel_ksd_hpev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% rlow is not maturity-dependent
lb=prctile(rlow_sample,2.5);
ub=prctile(rlow_sample,97.5);
il=find(rlow_sample>lb);
gsample=rlow_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_rlow(3,:),xsd_rlow(3,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_rlow(3,:),ksd_rlow(3,:),'r-','LineWidth',2);
xlabel('r_L');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (1-year sample)']);
filename=['rlow_sample1_panel_ksd_hpev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% rup is not maturity-dependent
lb=prctile(rup_sample,2.5);
ub=prctile(rup_sample,97.5);
il=find(rup_sample>lb);
gsample=rup_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_rup(3,:),xsd_rup(3,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
figure;
plot(xsd_rup(3,:),ksd_rup(3,:),'r-','LineWidth',2);
xlabel('r_U');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (1-year sample)']);
filename=['rup_sample1_panel_ksd_hpev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% gamma is not maturity-dependent
lb=prctile(gamma_sample,2.5);
ub=prctile(gamma_sample,97.5);
il=find(gamma_sample>lb);
gsample=gamma_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_gamma(3,:),xsd_gamma(3,:)]=ksdensity(fsample,'npoints',NK,'support',[-1.001,2.001]);
figure;
plot(xsd_gamma(3,:),ksd_gamma(3,:),'r-','LineWidth',2);
xlabel('\gamma');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (1-year sample)']);
filename=['gamma_sample1_panel_ksd_hpev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% lambda is not maturity-dependent
lb=prctile(lambda_sample,2.5);
ub=prctile(lambda_sample,97.5);
il=find(lambda_sample>lb);
gsample=lambda_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_lambda(3,:),xsd_lambda(3,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_lambda(3,:),ksd_lambda(3,:),'r-','LineWidth',2);
xlabel('\lambda');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (1-year sample)']);
filename=['lambda_sample1_panel_ksd_hpev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% save data to mat file
save irswap_panel_hpev3t_sample1_postprocess.mat

%% combined plots of 3 rlow, rup, lambda and gamma densities

figure;
plot(xsd_rlow(1,:),ksd_rlow(1,:),'r-','LineWidth',2);hold on;
plot(xsd_rlow(2,:),ksd_rlow(2,:),'b-','LineWidth',2);hold on;
plot(xsd_rlow(3,:),ksd_rlow(3,:),'g-','LineWidth',2);
xlabel('r_L');
ylabel('Marginal Posterior Density');
legend('Full sample','4-year sample','1-year sample');
filename=['rlow_bcev3_panel_ksd_comparison'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

figure;
plot(xsd_rup(1,:),ksd_rup(1,:),'r-','LineWidth',2);hold on;
plot(xsd_rup(2,:),ksd_rup(2,:),'b-','LineWidth',2);hold on;
plot(xsd_rup(3,:),ksd_rup(3,:),'g-','LineWidth',2);
xlabel('r_U');
ylabel('Marginal Posterior Density');
legend('Full sample','4-year sample','1-year sample');
filename=['rup_hpev3t_panel_ksd_comparison'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

figure;
plot(xsd_lambda(1,:),ksd_lambda(1,:),'r-','LineWidth',2);hold on;
plot(xsd_lambda(2,:),ksd_lambda(2,:),'b-','LineWidth',2);hold on;
plot(xsd_lambda(3,:),ksd_lambda(3,:),'g-','LineWidth',2);
xlabel('\lambda');
ylabel('Marginal Posterior Density');
legend('Full sample','4-year sample','1-year sample');
filename=['lambda_hpev3t_panel_ksd_comparison'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

figure;
plot(xsd_gamma(1,:),ksd_gamma(1,:),'r-','LineWidth',2);hold on;
plot(xsd_gamma(2,:),ksd_gamma(2,:),'b-','LineWidth',2);hold on;
plot(xsd_gamma(3,:),ksd_gamma(3,:),'g-','LineWidth',2);
xlabel('\gamma');
ylabel('Marginal Posterior Density');
legend('Full sample','4-year sample','1-year sample');
filename=['gamma_hpev3t_panel_ksd_comparison'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);