% testing hpev3_normal_mle function

% generate artificial time-series from the model
T=10240;
r0=2.9;
r_l=2.4;
r_u=3.4;
sigmabar=0.2;
mu=0.001;
lambda=0.50;
gamma=0.75;
[r,H] = hpev3_normal_simulator(T,mu,sigmabar,gamma,lambda,r_l,r_u,r0);
figure;
plot(r);axis tight;
xlabel('t');
ylabel('r');

% regime counts
['CEV Regime,  ','Difference Regime,  ','Return Regime  ']
disp([sum(H<1),sum(H==1),sum(H>1)]);

% evaluate loglikelihood of the sample
L=hpev3_normal_loglikelihood(r0,r,mu,sigmabar,gamma,lambda,r_l,r_u);

% estimate
alpha=0.05; % significance level
% preliminary search for good starting values
fun=@(x)(-hpev3_normal_llf(x,r));
start=[0,log(std(diff(r))),0.75,0.5,2,1];
lb=[-Inf,-10,-10,0,1,-10];
ub=Inf(1,6);ub(3)=0;ub(6)=log(10);
[x0,f0]=simulannealbnd(fun,start,lb,ub)

[p,ci,aic] = hpev3_normal_mle(r,alpha,x0);
% report
disp(['   True mu             ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([mu, p(1),ci(1,1),ci(2,1)]);
disp(['   True sigmabar       ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([sigmabar, p(2),ci(1,2),ci(2,2)]);
disp(['   True gamma          ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([gamma, p(3),ci(1,3),ci(2,3)]);
disp(['   True lambda         ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([lambda, p(4),ci(1,4),ci(2,4)]);
disp(['   True r_l            ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([r_l, p(5),ci(1,5),ci(2,5)]);
disp(['   True r_u            ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([r_u, p(6),ci(1,6),ci(2,6)]);

% test convergence of estimates
T0=1024;
dT=128;
TF=linspace(T0,T,(T-T0)/dT+1);
NT=size(TF,2);
pt=NaN(NT,6);
cit=NaN(2,6,NT);
aict=NaN(NT,1);
for t=1:NT
    [t,TF(t)]
    % select best starting point
    st=x0;
    if t>1
        L1=hpev3_normal_loglikelihood(r0,r,pt(t-1,1),pt(t-1,2),pt(t-1,3),pt(t-1,4),pt(t-1,5),pt(t-1,6));
        L2=hpev3_normal_loglikelihood(r0,r,x0(1),exp(x0(2)),x0(3),x0(4),x0(5),x0(5)+exp(x0(6)));
        if L1>L2
            st=[pt(t-1,1),log(pt(t-1,2)),pt(t-1,3),pt(t-1,4),pt(t-1,5),log(pt(t-1,6)-pt(t-1,5))];
        end
    end
    [pt(t,:),cit(:,:,t),aict(t)] = hpev3_normal_mle(r(1:TF(t)),alpha,st);
end

% convergence of mean estimates
figure;
plot(TF,pt(:,1),'r-'); hold on;
plot(TF,ones(size(TF))*mu,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \mu');

% convergence of estimates of volatility scale, gamma and lambda
figure;
subplot(3,1,1);
plot(TF,pt(:,2),'r-'); hold on;
plot(TF,ones(size(TF))*sigmabar,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \sigma');
subplot(3,1,2);
plot(TF,pt(:,3),'r-'); hold on;
plot(TF,ones(size(TF))*gamma,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \gamma');
subplot(3,1,3);
plot(TF,pt(:,4),'r-'); hold on;
plot(TF,ones(size(TF))*lambda,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \lambda');

% convergence of estimates for regime bounds
figure;
subplot(2,1,1);
plot(TF,pt(:,5),'r-'); hold on;
plot(TF,ones(size(TF))*r_l,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated r_l');
subplot(2,1,2);
plot(TF,pt(:,6),'r-'); hold on;
plot(TF,ones(size(TF))*r_u,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated r_u');
