% testing hpev_normal_loglikelihood function

% generate artificial time-series from the model
T=1024;
r0=2.9;
r_l=2.4;
r_u=3.4;
sigmabar=0.2;
theta=2.6;
kappa=0.03;
lambda=0.45;
gamma=0.5;
[r,H] = hpev_normal_simulator(T,theta,kappa,sigmabar,gamma,lambda,r_l,r_u,r0);
% regime counts
['CEV Regime  ','Difference Regime  ','Return Regime  ']
disp([sum(H<1),sum(H==1),sum(H>1)]);

% evaluate loglikelihood of the sample
L=hpev_normal_loglikelihood(r0,r,theta,kappa,sigmabar,gamma,lambda,r_l,r_u)

% evaluate loglikelihood on a one-dimensional slice surrounding true values
N=64;% slice size
% theta slice
theta_grid=linspace(2,3,N);
L_theta=NaN(N,1);
for i=1:N
    L_theta(i)=hpev_normal_loglikelihood(r0,r,theta_grid(i),kappa,sigmabar,gamma,lambda,r_l,r_u);
end
figure1=figure;
set(figure1,'DefaultTextInterpreter','tex');
plot(theta_grid,L_theta,'b-'); hold on;
plot(theta,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([theta,theta],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\theta');
ylabel('Log-likelihood');


% kappa slice
kappa_grid=linspace(-0.3,0.3,N);
L_kappa=NaN(N,1);
for i=1:N
    L_kappa(i)=hpev_normal_loglikelihood(r0,r,theta,kappa_grid(i),sigmabar,gamma,lambda,r_l,r_u);
end
figure2=figure;
set(figure2,'DefaultTextInterpreter','tex');
plot(kappa_grid,L_kappa,'b-'); hold on;
plot(kappa,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([kappa,kappa],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\kappa');
ylabel('Log-likelihood');

% sigmabar slice
sigmabar_grid=logspace(-3,0,N);
L_sigmabar=NaN(N,1);
for i=1:N
    L_sigmabar(i)=hpev_normal_loglikelihood(r0,r,theta,kappa,sigmabar_grid(i),gamma,lambda,r_l,r_u);
end
figure3=figure;
set(figure3,'DefaultTextInterpreter','tex');
plot(log(sigmabar_grid),L_sigmabar,'b-'); hold on;
plot(log(sigmabar),L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([log(sigmabar),log(sigmabar)],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('log \sigma');
ylabel('Log-likelihood');

% gamma slice
gamma_grid=linspace(0,1.5,N);
L_gamma=NaN(N,1);
for i=1:N
    L_gamma(i)=hpev_normal_loglikelihood(r0,r,theta,kappa,sigmabar,gamma_grid(i),lambda,r_l,r_u);
end
figure4=figure;
set(figure4,'DefaultTextInterpreter','tex');
plot(gamma_grid,L_gamma,'b-'); hold on;
plot(gamma,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([gamma,gamma],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\gamma');
ylabel('Log-likelihood');

% lambda slice
lambda_grid=linspace(0,1.5,N);
L_lambda=NaN(N,1);
for i=1:N
    L_lambda(i)=hpev_normal_loglikelihood(r0,r,theta,kappa,sigmabar,gamma,lambda_grid(i),r_l,r_u);
end
figure5=figure;
set(figure5,'DefaultTextInterpreter','tex');
plot(lambda_grid,L_lambda,'b-'); hold on;
plot(lambda,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([lambda,lambda],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\lambda');
ylabel('Log-likelihood');

% r_l slice
rl_grid=linspace(0.2,3,N);
L_rl=NaN(N,1);
for i=1:N
    L_rl(i)=hpev_normal_loglikelihood(r0,r,theta,kappa,sigmabar,gamma,lambda,rl_grid(i),r_u);
end
figure6=figure;
set(figure6,'DefaultTextInterpreter','tex');
plot(rl_grid,L_rl,'b-'); hold on;
plot(r_l,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([r_l,r_l],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('r_l');
ylabel('Log-likelihood');

% r_u slice
ru_grid=linspace(2,6,N);
L_ru=NaN(N,1);
for i=1:N
    L_ru(i)=hpev_normal_loglikelihood(r0,r,theta,kappa,sigmabar,gamma,lambda,r_l,ru_grid(i));
end
figure7=figure;
set(figure7,'DefaultTextInterpreter','tex');
plot(ru_grid,L_ru,'b-'); hold on;
plot(r_u,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([r_u,r_u],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('r_u');
ylabel('Log-likelihood');



