% testing hpev_t_loglikelihood function

% generate artificial time-series from the model
T=1024;
r0=2.67;
r_l=2.9;
r_u=3.4;
sigmabar=0.2;
theta=2.6;
kappa=0.03;
lambda=0.45;
gamma=0.5;
nu=3.5;
[rt,Ht] = hpev_t_simulator(T,theta,kappa,sigmabar,gamma,lambda,r_l,r_u,nu,r0);
% regime counts
['CEV Regime  ','Difference Regime  ','Return Regime  ']
disp([sum(Ht<1),sum(Ht==1),sum(Ht>1)]);

% evaluate normal and t loglikelihoods of the sample
'Normal likelihood'
Ln=hpev_normal_loglikelihood(r0,rt,theta,kappa,sigmabar,gamma,lambda,r_l,r_u)
'Student t likelihood'
Lt=hpev_t_loglikelihood(r0,rt,theta,kappa,sigmabar,gamma,lambda,r_l,r_u,nu)

% evaluate loglikelihood on a one-dimensional slice surrounding true values
N=64;% slice size
% theta slice
theta_grid=linspace(0.1,6,N);
Ln_theta=NaN(N,1);
Lt_theta=NaN(N,1);
for i=1:N
    Ln_theta(i)=hpev_normal_loglikelihood(r0,rt,theta_grid(i),kappa,sigmabar,gamma,lambda,r_l,r_u);
    Lt_theta(i)=hpev_t_loglikelihood(r0,rt,theta_grid(i),kappa,sigmabar,gamma,lambda,r_l,r_u,nu);
end
figure1=figure;
set(figure1,'DefaultTextInterpreter','tex');
plot(theta_grid,Ln_theta,'b-'); hold on;
plot(theta_grid,Lt_theta,'m-'); hold on;
plot(theta,Lt,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([theta,theta],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\theta');
ylabel('Log-likelihood');
legend('Normal log-likelihood','t log-likelihood');


% kappa slice
kappa_grid=linspace(-0.3,0.3,N);
Ln_kappa=NaN(N,1);
Lt_kappa=NaN(N,1);
for i=1:N
    Ln_kappa(i)=hpev_normal_loglikelihood(r0,rt,theta,kappa_grid(i),sigmabar,gamma,lambda,r_l,r_u);
    Lt_kappa(i)=hpev_t_loglikelihood(r0,rt,theta,kappa_grid(i),sigmabar,gamma,lambda,r_l,r_u,nu);
end
figure2=figure;
set(figure2,'DefaultTextInterpreter','tex');
plot(kappa_grid,Ln_kappa,'b-'); hold on;
plot(kappa_grid,Lt_kappa,'m-'); hold on;
plot(kappa,Lt,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([kappa,kappa],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\kappa');
ylabel('Log-likelihood');
legend('Normal log-likelihood','t log-likelihood');

% sigmabar slice
sigmabar_grid=logspace(-3,0,N);
Ln_sigmabar=NaN(N,1);
Lt_sigmabar=NaN(N,1);
for i=1:N
    Ln_sigmabar(i)=hpev_normal_loglikelihood(r0,rt,theta,kappa,sigmabar_grid(i),gamma,lambda,r_l,r_u);
    Lt_sigmabar(i)=hpev_t_loglikelihood(r0,rt,theta,kappa,sigmabar_grid(i),gamma,lambda,r_l,r_u,nu);
end
figure3=figure;
set(figure3,'DefaultTextInterpreter','tex');
plot(log(sigmabar_grid),Ln_sigmabar,'b-'); hold on;
plot(log(sigmabar_grid),Lt_sigmabar,'m-'); hold on;
plot(log(sigmabar),Lt,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([log(sigmabar),log(sigmabar)],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('log\sigma');
ylabel('Log-likelihood');
legend('Normal log-likelihood','t log-likelihood');

% gamma slice
gamma_grid=linspace(0,1.5,N);
Ln_gamma=NaN(N,1);
Lt_gamma=NaN(N,1);
for i=1:N
    Ln_gamma(i)=hpev_normal_loglikelihood(r0,rt,theta,kappa,sigmabar,gamma_grid(i),lambda,r_l,r_u);
    Lt_gamma(i)=hpev_t_loglikelihood(r0,rt,theta,kappa,sigmabar,gamma_grid(i),lambda,r_l,r_u,nu);
end
figure4=figure;
set(figure4,'DefaultTextInterpreter','tex');
plot(gamma_grid,Ln_gamma,'b-'); hold on;
plot(gamma_grid,Lt_gamma,'m-'); hold on;
plot(gamma,Lt,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([gamma,gamma],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\gamma');
ylabel('Log-likelihood');
legend('Normal log-likelihood','t log-likelihood');

% lambda slice
lambda_grid=linspace(0,1.5,N);
Ln_lambda=NaN(N,1);
Lt_lambda=NaN(N,1);
for i=1:N
    Ln_lambda(i)=hpev_normal_loglikelihood(r0,rt,theta,kappa,sigmabar,gamma,lambda_grid(i),r_l,r_u);
    Lt_lambda(i)=hpev_t_loglikelihood(r0,rt,theta,kappa,sigmabar,gamma,lambda_grid(i),r_l,r_u,nu);
end
figure5=figure;
set(figure5,'DefaultTextInterpreter','tex');
plot(lambda_grid,Ln_lambda,'b-'); hold on;
plot(lambda_grid,Lt_lambda,'m-'); hold on;
plot(lambda,Lt,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([lambda,lambda],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\lambda');
ylabel('Log-likelihood');
legend('Normal log-likelihood','t log-likelihood');

% r_l slice
rl_grid=linspace(0.2,5,N);
Ln_rl=NaN(N,1);
Lt_rl=NaN(N,1);
for i=1:N
    Ln_rl(i)=hpev_normal_loglikelihood(r0,rt,theta,kappa,sigmabar,gamma,lambda,rl_grid(i),r_u);
    Lt_rl(i)=hpev_t_loglikelihood(r0,rt,theta,kappa,sigmabar,gamma,lambda,rl_grid(i),r_u,nu);
end
figure6=figure;
set(figure6,'DefaultTextInterpreter','tex');
plot(rl_grid,Ln_rl,'b-'); hold on;
plot(rl_grid,Lt_rl,'m-'); hold on;
plot(r_l,Lt,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([r_l,r_l],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('r_l');
ylabel('Log-likelihood');
legend('Normal log-likelihood','t log-likelihood');

% r_u slice
ru_grid=linspace(2,6,N);
Ln_ru=NaN(N,1);
Lt_ru=NaN(N,1);
for i=1:N
    Ln_ru(i)=hpev_normal_loglikelihood(r0,rt,theta,kappa,sigmabar,gamma,lambda,r_l,ru_grid(i));
    Lt_ru(i)=hpev_t_loglikelihood(r0,rt,theta,kappa,sigmabar,gamma,lambda,r_l,ru_grid(i),nu);
end
figure7=figure;
set(figure7,'DefaultTextInterpreter','tex');
plot(ru_grid,Ln_ru,'b-'); hold on;
plot(ru_grid,Lt_ru,'m-'); hold on;
plot(r_u,Lt,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([r_u,r_u],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('r_u');
ylabel('Log-likelihood');
legend('Normal log-likelihood','t log-likelihood');

% nu slice
nu_grid=linspace(2,32,N);
Ln_nu=NaN(N,1);
Lt_nu=NaN(N,1);
for i=1:N
    Ln_nu(i)=hpev_normal_loglikelihood(r0,rt,theta,kappa,sigmabar,gamma,lambda,r_l,r_u);
    Lt_nu(i)=hpev_t_loglikelihood(r0,rt,theta,kappa,sigmabar,gamma,lambda,r_l,r_u,nu_grid(i));
end
figure8=figure;
set(figure8,'DefaultTextInterpreter','tex');
plot(nu_grid,Ln_nu,'b-'); hold on;
plot(nu_grid,Lt_nu,'m-'); hold on;
plot(nu,Lt,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;
l0=line([nu,nu],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\nu');
ylabel('Log-likelihood');
legend('Normal log-likelihood','t log-likelihood');