% testing hpev_t_mle function

% generate artificial time-series from the model
T=10240;
r0=2.9;
r_l=2.4;
r_u=3.4;
sigmabar=0.2;
theta=2.6;
kappa=0.03;
lambda=0.50;
gamma=0.75;
nu=4.5;
[r,H] = hpev_t_simulator(T,theta,kappa,sigmabar,gamma,lambda,r_l,r_u,r0,nu);
figure;
plot(r);axis tight;
xlabel('t');
ylabel('r');

% regime counts
['CEV Regime,  ','Difference Regime,  ','Return Regime  ']
disp([sum(H<1),sum(H==1),sum(H>1)]);

% evaluate loglikelihood of the sample
L=hpev_t_loglikelihood(r(1),r(2:end),theta,kappa,sigmabar,gamma,lambda,r_l,r_u,nu);

% estimate
alpha=0.05; % significance level
% preliminary search for good starting values
fun=@(x)(-hpev_t_llf(x,r));
s0=std(diff(r));
s1=std(diff(r)./r(1:end-1));
ss=min(s0,s1);
start=[mean(r),0,log(ss),0.75,0.5,2,0,4.4];
lb=[-Inf,-Inf,-10,-10,0,1,-10,1];
ub=Inf(1,8);ub(3)=0;ub(6)=10;ub(7)=log(10);ub(5)=4;
options = saoptimset('HybridFcn',@fminsearch,'InitialTemperature',1200,'TemperatureFcn',@temperatureboltz,'AnnealingFcn',@annealingboltz,'MaxFunEval',100000); 
[x0,f0]=simulannealbnd(fun,start,lb,ub,options);
[x0,f0,L]


[p,ci,aic] = hpev_t_mle(r,alpha,x0);
% report
disp(['   True theta          ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([theta, p(1),ci(1,1),ci(2,1)]);
disp(['   True kappa          ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([kappa, p(2),ci(1,2),ci(2,2)]);
disp(['   True sigmabar       ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([sigmabar, p(3),ci(1,3),ci(2,3)]);
disp(['   True gamma          ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([gamma, p(4),ci(1,4),ci(2,4)]);
disp(['   True lambda         ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([lambda, p(5),ci(1,5),ci(2,5)]);
disp(['   True r_l            ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([r_l, p(6),ci(1,6),ci(2,6)]);
disp(['   True r_u            ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([r_u, p(7),ci(1,7),ci(2,7)]);
disp(['   True nu             ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([nu, p(8),ci(1,8),ci(2,8)]);

% test convergence of estimates
T0=1024;
dT=128;
TF=linspace(T0,T,(T-T0)/dT+1);
NT=size(TF,2);
pt=NaN(NT,8);
cit=NaN(2,8,NT);
aict=NaN(NT,1);
for t=1:NT
    [t,TF(t)]
    % select best starting point
    st=x0;
    if t>1
        L1=hpev_t_loglikelihood(r0,r,pt(t-1,1),pt(t-1,2),pt(t-1,3),pt(t-1,4),pt(t-1,5),pt(t-1,6),pt(t-1,7),pt(t-1,8));
        L2=hpev_t_loglikelihood(r0,r,x0(1),x0(2),exp(x0(3)),x0(4),x0(5),x0(6),x0(6)+exp(x0(7)),x0(8));
        if L1>L2
            st=[pt(t-1,1),pt(t-1,2),log(pt(t-1,3)),pt(t-1,4),pt(t-1,5),pt(t-1,6),log(pt(t-1,7)-pt(t-1,6)),pt(t-1,8)];
        end
    end
    [pt(t,:),cit(:,:,t),aict(t)] = hpev_t_mle(r(1:TF(t)),alpha,st);
end

% convergence of mean estimates
figure;
subplot(2,1,1);
plot(TF,pt(:,1),'r-'); hold on;
plot(TF,ones(size(TF))*theta,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \theta');
subplot(2,1,2);
plot(TF,pt(:,2),'r-'); hold on;
plot(TF,ones(size(TF))*kappa,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \kappa');

% convergence of estimates of volatility scale, gamma and lambda
figure;
subplot(3,1,1);
plot(TF,pt(:,3),'r-'); hold on;
plot(TF,ones(size(TF))*sigmabar,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \sigma');
subplot(3,1,2);
plot(TF,pt(:,4),'r-'); hold on;
plot(TF,ones(size(TF))*gamma,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \gamma');
subplot(3,1,3);
plot(TF,pt(:,5),'r-'); hold on;
plot(TF,ones(size(TF))*lambda,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \lambda');

% convergence of estimates for regime bounds
figure;
subplot(2,1,1);
plot(TF,pt(:,6),'r-'); hold on;
plot(TF,ones(size(TF))*r_l,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated r_l');
subplot(2,1,2);
plot(TF,pt(:,7),'r-'); hold on;
plot(TF,ones(size(TF))*r_u,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated r_u');

% convergence of estimates of nu
figure;
plot(TF,pt(:,8),'r-'); hold on;
plot(TF,ones(size(TF))*nu,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \nu');