% estimate nonparametric diffusion functions on irswap data, common for the
% entire panel

% load data
data=csvread('../data/irswap_daily_20000703_20120726.csv',1,1);
[T,N]=size(data);
dates=csvread('../data/irswap_daily_20000703_20120726.csv',1,0,[1,0,T,0]);
p=NaN(N,4);
ci=NaN(2,4,N);
aic=NaN(N,1);
p4=NaN(N,4);
ci4=NaN(2,4,N);
aic4=NaN(N,1);
p1=NaN(N,4);
ci1=NaN(2,4,N);
aic1=NaN(N,1);
alpha=0.05;
% last 4 years
i4=find(dates>=dates(end)-40000);
data4=data(i4,:);
T4=size(data4,1);
% last 1 year
i1=find(dates>=dates(end)-10000);
data1=data(i1,:);
T1=size(data1,1);

    
% panel stanton profiles
[V,yv,B] = panel_stanton(data);
[V4,yv4,B] = panel_stanton(data4,yv,B);
[V1,yv1,B] = panel_stanton(data1,yv,B);


figure;
plot(yv,sqrt(V),'b-'); hold on;
plot(yv4,sqrt(V4),'r-');hold on;
plot(yv1,sqrt(V1),'g-');
xlabel('Level of Interest Rate');
ylabel('Volatility');
legend('Full sample','4-year window','1-year window');
print('-depsc2','irswaps_panel_stanton.eps');
print('-djpeg','irswaps_panel_stanton.jpg');
print('-dpdf','irswaps_panel_stanton.pdf');

% separate subsamples with histograms
% full sample
figure;
plot(yv,sqrt(V),'b-');hold on;
ax1=gca;
v=axis;
ylim([0,max(v(4),max(sqrt(V))*2)]);
ylabel('Volatility');
ax2 = axes('Position',get(ax1,'Position'),'YAxisLocation','right','Color','none','XAxisLocation','bottom');
hist(ax2,reshape(data,T*N,1),100);hold on;
set(ax2,'YAxisLocation','right','Visible','off');
h = findobj(ax2,'Type','patch');
set(h,'FaceColor','w','EdgeColor',[0.5,0.5,0.5])
xlabel('Level of Interest Rate');
title(ax1,'Full panel sample');
outname1=['irswaps_panel_full_stanton.eps'];
outname2=['irswaps_panel_full_stanton.jpg'];
outname3=['irswaps_panel_full_stanton.pdf'];
print('-depsc2',outname1);
print('-djpeg',outname2);
print('-dpdf',outname3);
% 4y sample
figure;
plot(yv4,sqrt(V4),'r-');hold on;
ax1=gca;
v=axis;
ylim([0,max(v(4),max(sqrt(V4))*2)]);
ylabel('Volatility');
ax2 = axes('Position',get(ax1,'Position'),'YAxisLocation','right','Color','none','XAxisLocation','bottom');
hist(ax2,reshape(data4,T4*N,1),100);hold on;
set(ax2,'YAxisLocation','right','Visible','off');
h = findobj(ax2,'Type','patch');
set(h,'FaceColor','w','EdgeColor',[0.5,0.5,0.5])
xlabel('Level of Interest Rate');
title(ax1,'4-year panel sample');
outname1=['irswaps_panel_4y_stanton.eps'];
outname2=['irswaps_panel_4y_stanton.jpg'];
outname3=['irswaps_panel_4y_stanton.pdf'];
print('-depsc2',outname1);
print('-djpeg',outname2);
print('-dpdf',outname3);
% 1y sample
figure;
plot(yv1,sqrt(V1),'g-');hold on;
ax1=gca;
v=axis;
ylim([0,max(v(4),max(sqrt(V1))*2)]);
ylabel('Volatility');
ax2 = axes('Position',get(ax1,'Position'),'YAxisLocation','right','Color','none','XAxisLocation','bottom');
hist(ax2,reshape(data1,T1*N,1),100);hold on;
set(ax2,'YAxisLocation','right','Visible','off');
h = findobj(ax2,'Type','patch');
set(h,'FaceColor','w','EdgeColor',[0.5,0.5,0.5])
xlabel('Level of Interest Rate');
title(ax1,'1-year panel sample');
outname1=['irswaps_panel_1y_stanton.eps'];
outname2=['irswaps_panel_1y_stanton.jpg'];
outname3=['irswaps_panel_1y_stanton.pdf'];
print('-depsc2',outname1);
print('-djpeg',outname2);
print('-dpdf',outname3);

