% estimate nonparametric diffusion functions on irswap data

% load data
data=csvread('../data/irswap_daily_20000703_20120726.csv',1,1);
[T,N]=size(data);
dates=csvread('../data/irswap_daily_20000703_20120726.csv',1,0,[1,0,T,0]);
p=NaN(N,4);
ci=NaN(2,4,N);
aic=NaN(N,1);
p4=NaN(N,4);
ci4=NaN(2,4,N);
aic4=NaN(N,1);
p1=NaN(N,4);
ci1=NaN(2,4,N);
aic1=NaN(N,1);
alpha=0.05;
% last 4 years
i4=find(dates>=dates(end)-40000);
data4=data(i4,:);
% last 1 year
i1=find(dates>=dates(end)-10000);
data1=data(i1,:);
names={'US IRSWAPS 1y','US IRSWAPS 2y','US IRSWAPS 3y','US IRSWAPS 4y',...
    'US IRSWAPS 5y','US IRSWAPS 7y','US IRSWAPS 10y','US IRSWAPS 30y'};
filenames={'usirswaps_1y','usirswaps_2y','usirswaps_3y','usirswaps_4y',...
    'usirswaps_5y','usirswaps_7y','usirswaps_10y','usirswaps_30y'};
    
% univariate stanton profiles
for i=1:N
     [V,yv,B] = stanton(data(:,i));
     [V4,yv4,B] = stanton(data4(:,i),yv,B);
     [V1,yv1,B] = stanton(data1(:,i),yv,B);
     % all 3 together
     figure;
     plot(yv,sqrt(V),'b-'); hold on;
     plot(yv4,sqrt(V4),'r-');hold on;
     plot(yv1,sqrt(V1),'g-');
     xlabel('Level of Interest Rate');
     ylabel('Volatility');
     title(names{i});
     legend('Full sample','4-year window','1-year window');
     outname1=[filenames{i},'_stanton.eps'];
     outname2=[filenames{i},'_stanton.jpg'];
     outname3=[filenames{i},'_stanton.pdf'];
     print('-depsc2',outname1);
     print('-djpeg',outname2);
     print('-dpdf',outname3);
     % full sample
     figure;
     plot(yv,sqrt(V),'b-');hold on;
     ax1=gca;
     v=axis;
     ylim([0,max(v(4),max(sqrt(V))*2)]);
     ylabel('Volatility');
     ax2 = axes('Position',get(ax1,'Position'),'YAxisLocation','right','Color','none','XAxisLocation','bottom');
     hist(ax2,data(:,i),100);hold on;
     set(ax2,'YAxisLocation','right','Visible','off');
     h = findobj(ax2,'Type','patch');
     set(h,'FaceColor','w','EdgeColor',[0.5,0.5,0.5])
     xlabel('Level of Interest Rate');
     title(ax1,[names{i},',  full sample']);
     outname1=[filenames{i},'_full_stanton.eps'];
     outname2=[filenames{i},'_full_stanton.jpg'];
     outname3=[filenames{i},'_full_stanton.pdf'];
     print('-depsc2',outname1);
     print('-djpeg',outname2);
     print('-dpdf',outname3);
     % 4 year window
     figure;
     plot(yv4,sqrt(V4),'r-');
     ax1=gca;
     v=axis;
     ylim([0,max(v(4),max(sqrt(V4))*2)]);
     ylabel('Volatility');
     ax2 = axes('Position',get(ax1,'Position'),'YAxisLocation','right','Color','none','XAxisLocation','bottom');
     hist(ax2,data4(:,i),100);hold on;
     set(ax2,'YAxisLocation','right','Visible','off');
     h = findobj(ax2,'Type','patch');
     set(h,'FaceColor','w','EdgeColor',[0.5,0.5,0.5])
     xlabel('Level of Interest Rate');
     ylabel('Volatility');
     title(ax1,[names{i},'   4y sample']);
     outname1=[filenames{i},'_4y_stanton.eps'];
     outname2=[filenames{i},'_4y_stanton.jpg'];
     outname3=[filenames{i},'_4y_stanton.pdf'];
     print('-depsc2',outname1);
     print('-djpeg',outname2);
     print('-dpdf',outname3);
     % 1 year window
     figure;
     plot(yv1,sqrt(V1),'g-'); 
     ax1=gca;
     v=axis;
     ylim([0,max(v(4),max(sqrt(V1))*2)]);
     ylabel('Volatility');
     ax2 = axes('Position',get(ax1,'Position'),'YAxisLocation','right','Color','none','XAxisLocation','bottom');
     hist(ax2,data1(:,i),50);hold on;
     set(ax2,'YAxisLocation','right','Visible','off');
     h = findobj(ax2,'Type','patch');
     set(h,'FaceColor','w','EdgeColor',[0.5,0.5,0.5])
     xlabel('Level of Interest Rate');
     ylabel('Volatility');
     v=axis;
     ylim([0,max(v(4),max(sqrt(V1))*2)]);
     title(ax1,[names{i},'   1y sample']);
     outname1=[filenames{i},'_1y_stanton.eps'];
     outname2=[filenames{i},'_1y_stanton.jpg'];
     outname3=[filenames{i},'_1y_stanton.pdf'];
     print('-depsc2',outname1);
     print('-djpeg',outname2);
     print('-dpdf',outname3);
end

% given results create a figure with 2x2 subplots
figure;
subplot(2,2,1);
i=1; % 1y maturity
[V,yv,B] = stanton(data(:,i));
[V4,yv4,B] = stanton(data4(:,i),yv,B);
[V1,yv1,B] = stanton(data1(:,i),yv,B);
plot(yv,sqrt(V),'r-'); hold on;
plot(yv4,sqrt(V4),'b-');hold on;
plot(yv1,sqrt(V1),'g-');
xlabel('Level of Interest Rate');
ylabel('Volatility');
title(names{i});
subplot(2,2,2);
i=5; % 5y maturity
[V,yv,B] = stanton(data(:,i));
[V4,yv4,B] = stanton(data4(:,i),yv,B);
[V1,yv1,B] = stanton(data1(:,i),yv,B);
plot(yv,sqrt(V),'r-'); hold on;
plot(yv4,sqrt(V4),'b-');hold on;
plot(yv1,sqrt(V1),'g-');
xlabel('Level of Interest Rate');
ylabel('Volatility');
title(names{i});
lg=legend('Full sample','4-year window','1-year window');
set(lg,'FontSize',8,'Location','NorthWest');
subplot(2,2,3);
i=8; % 30y maturity
[V,yv,B] = stanton(data(:,i));
[V4,yv4,B] = stanton(data4(:,i),yv,B);
[V1,yv1,B] = stanton(data1(:,i),yv,B);
plot(yv,sqrt(V),'r-'); hold on;
plot(yv4,sqrt(V4),'b-');hold on;
plot(yv1,sqrt(V1),'g-');
xlabel('Level of Interest Rate');
ylabel('Volatility');
title(names{i});
%legend('Full sample','4-year window','1-year window');
subplot(2,2,4);
[V,yv,B] = panel_stanton(data);
[V4,yv4,B] = panel_stanton(data4,yv,B);
[V1,yv1,B] = panel_stanton(data1,yv,B);
plot(yv,sqrt(V),'r-'); hold on;
plot(yv4,sqrt(V4),'b-');hold on;
plot(yv1,sqrt(V1),'g-');
xlabel('Level of Interest Rate');
ylabel('Volatility');
title('All maturities');
%legend('Full sample','4-year window','1-year window');
print('-depsc2','usirswaps_all_stanton.eps');
print('-djpeg','usirswaps_all_stanton.jpg');
print('-dpdf','usirswaps_all_stanton.pdf');