% compute panel Stanton estimator of diffusion function with Gaussian kernel
% function [V,yv1,B] = panel_stanton(y,yv,b0)
% INPUTS:
% y(1:T,1:N)     = multivariate time-series (Tx1)
% yv(1:M,1)    = vector of values where diffusion function is to be estimated (optional)
% b0           = kernel bandwidth (optional)
% OUTPUTS:
% V(1:M,1)     = vector of values of level-dependent variance
% yv1(1:M,1)   = vector of values where diffusion function is estimated
% B            = bandwidth used
function [V,yv1,B] = panel_stanton(y,yv,b0)

[T,N]=size(y);
% argument checking
if nargin<2
    yv=linspace(min(min(y)),max(max(y)),100)'; 
    b0=4*min(var(y))*T^(-0.2);
elseif nargin<3
    b0=4*min(var(y))*T^(-0.2);
end
yv1=yv;
B=b0;
M=size(yv,1);
V=NaN(M,1);
for i=1:M
    V(i)=0;
    D=0;
    for j=1:N
        V(i)=V(i)+(diff(y(:,j)).^2)'*normpdf((yv(i)-y(1:end-1,j))/B);
        D=D+sum(normpdf((yv(i)-y(1:end-1,j))/B));
    end
    V(i)=V(i)/D;    
end;

