% compute Stanton estimator of diffusion function with Gaussian kernel
% function [V,yv1,B] = stanton(y,yv,b0)
% INPUTS:
% y(1:T,1)     = univariate time-series (Tx1)
% yv(1:N,1)    = vector of values where diffusion function is to be estimated (optional)
% b0           = kernel bandwidth (optional)
% OUTPUTS:
% V(1:N,1)     = vector of values of level-dependent variance
% yv1(1:N,1)   = vector of values where diffusion function is estimated
% B            = bandwidth used
function [V,yv1,B] = stanton(y,yv,b0)

 T=size(y,1);
% argument checking
if nargin<2
    yv=linspace(min(y),max(y),100)'; 
    b0=4*var(y)*T^(-0.2);
elseif nargin<3
    b0=4*var(y)*T^(-0.2);
end
    yv1=yv;
    B=b0;%/2;
    N=size(yv,1);
    V=NaN(N,1);
    for i=1:N
        V(i)=(diff(y).^2)'*normpdf((yv(i)-y(1:end-1))/B)/sum(normpdf((yv(i)-y(1:end-1))/B));
    end;
end
    
