% function cv= critvalue_kpss(trend,p,N,NMC)
% Compute (right-sided) critical values of KPSS distribution
% INPUTS
% trend     = indicator variable whether trend should be included (0/1)
% p         = vector of significance levels
% N         = sample size
% NMC       = number of Monte Carlo simulations
% OUTPUTS:
% cv        = critical values at p
function cv = critvalue_kpss(trend,p,N,NMC)

% input checking
if trend>1||trend<0
    error('Invalid trend specification');
end

if max(p)>1||min(p)<0
    error('Invalid significance levels');
end

if ~isscalar(N) || N<=0
        error('Invalid sample size' );
end

if ~isscalar(NMC) || NMC<=0
        error('Invalid number of Monte Carlo Draws' );
end

kpss=NaN(NMC,1);
if trend==0
    if N*NMC<100000000
        y=randn(N,NMC);
        u=y-ones(N,1)*mean(y);
        S=cumsum(u);
        kpss=sum(S.^2)/N^2;
    else
        for i=1:NMC
            y=randn(N,1);
            u=y-mean(y);
            S=cumsum(u);
            kpss(i)=sum(S.^2)/N^2;
        end
    end
    
else
    if N*NMC<100000000
      y=randn(N,NMC);
      for i=1:NMC
        b=regress(y(:,i),[ones(N,1),linspace(1,N,N)']);
        u=y(:,i)-b(1)-b(2)*linspace(1,N,N)';
        S=cumsum(u);
        kpss(i)=sum(S.^2)/N^2;
      end
    else
        if N*NMC>1000000000
            h=waitbar(0,'Simulating critical values ...');
        end
        for i=1:NMC
            if N*NMC>10000000000
                waitbar(i/NMC);
            end
            y=randn(N,1);
            %b=regress(y,[ones(N,1),linspace(1,N,N)']);
            s1=sum(y);
            s2=sum([1:1:N]'.*y);
            b(1)=(4*N+2)/(N*(N-1))*s1-6*s2/(N*(N-1));
            b(2)=-6*s1/(N*(N-1))+12/((N+1)*N*(N-1))*s2;
            u=y-b(1)-b(2)*linspace(1,N,N)';
            S=cumsum(u);
            kpss(i)=sum(S.^2)/N^2;
        end
        if N*NMC>10000000000
            close(h);
        end
    end
end
cv=quantile(kpss,1-p);
