% compute log-likelihood function for driftless cev process with Student t innovations
% INPUTS
% r0        = initial value
% r(1:T)    = sample, purpotedly from CEV with Student t innovations
% sigma     = scale of variance
% beta      = arctan slope coeff in elasticity of variance
% gamma     = arctan intercept coeff in elasticity of variance
% nu        = degrees of freedom parameter
% OUTPUTS
% L         = log-likelihood function

function L = arctanvev2_t_loglik(r0,r,sigma,beta0,beta1,beta2,nu)


alpha=beta0*2/pi*atan(beta1*r+beta2);
alpha0=beta0*2/pi*atan(beta1*r0+beta2);
L=log(tpdf((r(1)-r0)/(sigma*r0^alpha0),nu)/(sigma*r0^alpha0));
L=L+nansum(log(tpdf(diff(r)./(sigma.*r(1:end-1).^alpha(1:end-1)),nu)./(sigma.*r(1:end-1).^alpha(1:end-1))));