%function sample = arctanvevnorm_simulate(x0,TS,sigma,beta1,beta2)
% simulate from varaible elasticity of volatility model:
% x(t)-x(t-1)=sigma*x(t-1)^gamma(x(t-1))*epsilon where
% gamma(x) is elasticity function given by
% gamma(x)=2/pi*atan(beta1*x+beta2) and epsilon ~ N(0,1)
% INPUTS:
% x0    = statring value for the simulation, must be positive
% TS    = sample length
% sigma = scale of variance
% beta1 = slope coefficient under atan
% beta2 = intercept coefficient inside variable elasticity
% OUTPUTS
% sample = sample from variable elasticity of volatility process 
% sample(1)=x0
function sample = arctanvevnorm_simulate(x0,TS,sigma,beta1,beta2)
% ARGUMENT HANDLING
error(nargchk(2,15,nargin));
%error(nargoutchk(1,6,nargout));
if x0<0
    error('negative starting value is not allowed');
end
if sigma<0
    error('negative scale of volatility is not allowed');
end
if TS<1
    error('sample length should be >1')
end;

sample=NaN(TS,1);
sample(1)=x0;
if TS>1
    sample(2:TS)=-1;
    for t=2:TS
        gamma=2/pi*atan(beta1*sample(t-1)+beta2);
        while sample(t)<0
            sample(t)=sample(t-1)+sigma*sample(t-1)^gamma*randn(1,1);
        end
    end
end





