% compute log-likelihood function for driftless vev process with Gaussian innovations
% INPUTS
% r0        = initial value
% r(1:T)    = sample, purpotedly from CEV with Student t innovations
% mu        = mean parameter
% sigma     = scale of variance
% beta2     = arctan slope coeff in elasticity of variance
% beta1     = arctan intercept coeff in elasticity of variance
% OUTPUTS
% L         = log-likelihood function

function L = atanvev3_normal_loglik(r0,r,mu,sigma,beta1,beta2)


alpha=6/pi*atan(beta1+beta2*r)-1;
alpha0=6/pi*atan(beta1+beta2*r0)-1;

T=size(r,1); % determine the sample size
L=log(1/(sqrt(2*pi)*sigma*abs(r0)^alpha0))-((r(1)-r0-mu)^2/(2*sigma^2*abs(r0)^(2*alpha0)));
if isnan(L)
    L=0;
end
for t=2:T
    L1=log(1/(sqrt(2*pi)*sigma*abs(r(t-1))^alpha(t-1)))-((r(t)-r(t-1)-mu)^2/(2*sigma^2*abs(r(t-1))^(2*alpha(t-1))));
    if ~isnan(L1)
        L=L+L1;
    end
end

