% maximum likelihood estimator of variable elasticity of volatility
% model with normal innovations
% INPUTS:
% y(1:T)     = univariate data time-series
% alpha      = (optional) confidence level for estimates, default is 0.95
% start      = (optional) vector of starting guesses
% OUTPUTS:
% p(1:3) = estimated model parameters, namely
%   p(1)    = mu = constant drift parameter
%   p(2)    = sigmabar = scale of volatility
%   p(3)    = beta1 = constant term in elsticity of volatility
%   p(4)    = beta2 = slope term in elasticity of volatility
% ci(1:2,1:3)   = confidence bounds at significance level alpha
% aic       = Akaike information criterion
function [p,ci,aic] = atanvev3_normal_mle(y,alpha,start)

if nargin<2
    alpha=0.05;
end
if nargin<3
    start=[mean(diff(y)),log(std(diff(y))),0.0,0.0];
end
T=size(y,1);

myoptions=statset('MaxFunEvals',10*T,'MaxIter',10000);


lb=[-Inf,-10,-Inf,-Inf];
ub=Inf(1,4);ub(2)=1;


atanvevnormal_loglikelihood=@(params,data,cens,freq)(-atanvev3_normal_llf(params,data,cens,freq));
[p,ci]=mle(y, 'nloglf', atanvevnormal_loglikelihood, 'start',start,'options',myoptions,'lowerbound',lb,'upperbound',ub,'optimfun','fmincon','alpha',alpha);
%[p,ci]=mle(y, 'nloglf', hpevnormal_loglikelihood, 'start',start,'options',myoptions,'optimfun','fmincon','alpha',alpha);
%[p,ci]=mle(y, 'nloglf', hpevnormal_loglikelihood, 'start',start,'options',myoptions,'lowerbound',lb,'upperbound',ub,'optimfun','fminsearch','alpha',alpha);
aic=2*4+2*atanvevnormal_loglikelihood(p,y,[],[]);
% back to scale levels
p(2)=exp(p(2));
ci(:,2)=exp(ci(:,2));