% compute log-likelihood function for driftless vev process with Student t innovations
% INPUTS
% r0        = initial value
% r(1:T)    = sample, purpotedly from CEV with Student t innovations
% mu        = mean parameter
% sigma     = scale of variance
% beta1     = arctan intercept coeff in elasticity of variance
% beta2     = arctan slope coeff in elasticity of variance
% nu        = degrees of freedom parameter
% OUTPUTS
% L         = log-likelihood function

function L = atanvev3_t_loglik(r0,r,mu,sigma,beta1,beta2,nu)


alpha=6/pi*atan(beta2*r+beta1)-1;
alpha0=6/pi*atan(beta2*r0+beta1)-1;
L=log(tpdf((r(1)-mu-r0)/(sigma*r0^alpha0),nu)/(sigma*abs(r0)^alpha0));
L=L+nansum(log(tpdf((diff(r)-mu)./(sigma.*abs(r(1:end-1)).^alpha(1:end-1)),nu)./(sigma.*abs(r(1:end-1)).^alpha(1:end-1))));