% function r =
% atanvev3_t_simulator(T,mu,sigmabar,beta1,beta2,nu,r0)
% Simulating constant elasticity of volatility model
% r(t)-r(t-1)=mu+sigmabar*(abs(r(t-1)))^gamma(t-1)*epsilon(t) where
% gamma(t-1)=6/pi*atan(beta1+beta2*r(t-1))-1
% epsilon(t)~iid N(0,1)
% INPUTS
% T         = length of time-series to simulate
% mu        = mean parameter
% sigmabar  = scale of volatility
% beta1     = constant term in variable elasticity
% beta2     = slope term in variable elasticity
% r0 = initial value of observed time-series
% nu = degrees of freedom parameter
% OUTPUTS
% r(1:T)    = simulated output series
% sigma(1:T)= simulated volatility series
% gamma(1:T)=variable elasticity of volatility
function [r,sigma,gamma] = atanvev3_t_simulator(T,mu,sigmabar,beta1,beta2,nu,r0)

r=NaN(T,1);
sigma=NaN(T,1);
gamma=NaN(T,1);
epsilon=trnd(nu,T,1);
gamma0=6/pi*atan(beta1+beta2*r0)-1;
r(1)=r0+mu+sigmabar*abs(r0)^gamma0*epsilon(1);
sigma(1)=sigmabar*abs(r0)^gamma0;
if T>1
    for t=2:T
        gamma(t-1)=6/pi*atan(beta1+beta2*r(t-1))-1;
        r(t)=r(t-1)+mu+sigmabar*abs(r(t-1))^gamma(t-1)*epsilon(t);
        sigma(t)=sigmabar*abs(r(t-1))^gamma(t-1);
    end
end
gamma(T)=6/pi*atan(beta1+beta2*r(T))-1;