% variable elasticity profiles implied by posterior median estimates
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
sample={' (full sample)',' (4-year sample)',' (1-year sample)'};
sample1={'Full sample','4-year sample','1-year sample'};
sample0={'_full_','_sample4_','_sample1_'};
data=csvread('../irswap_daily_20000703_20120726.csv',1,1);
[T,N]=size(data);
dates=csvread('../irswap_daily_20000703_20120726.csv',1,0,[1,0,T,0]);
NR=64;
elast=NaN(NR,N,3);
vl=NaN(NR,N,3);
r=linspace(0.15,max(max(data)),NR)';
beta1=NaN(N,3);
beta2=NaN(N,3);
sigma=NaN(N,3);

params=csvread('irswap_atanvev3t_full_stats.csv',1,2);
sigma(:,1)=params(2:5:37,1);
beta1(:,1)=params(3:5:38,1);
beta2(:,1)=params(4:5:39,1);
params4=csvread('irswap_atanvev3t_sample4_stats.csv',1,2);
sigma(:,2)=params4(2:5:37,1);
beta1(:,2)=params4(3:5:38,1);
beta2(:,2)=params4(4:5:39,1);
params1=csvread('irswap_atanvev3t_sample1_stats.csv',1,2);
sigma(:,3)=params1(2:5:37,1);
beta1(:,3)=params1(3:5:38,1);
beta2(:,3)=params1(4:5:39,1);

gamma=NaN(N,3);
pcev=csvread('../cev/irswap_bcev3_full_stats.csv',1,2);
gamma(:,1)=pcev(3:4:31,1);
pcev4=csvread('../cev/irswap_bcev3_sample4_stats.csv',1,2);
gamma(:,2)=pcev4(3:4:31,1);
pcev1=csvread('../cev/irswap_bcev3_sample1_stats.csv',1,2);
gamma(:,3)=pcev1(3:4:31,1);

for j=1:3
    for i=1:N
        elast(:,i,j)=3/pi*atan(beta1(i,j)+beta2(i,j)*r)+0.5;
        vl(:,i,j)=sigma(i,j)*r.^elast(:,i,j);
    end
end
        
% figures
for j=1:3
    for i=1:N
        figure;
        plot(r,elast(:,i,j),'r','LineWidth',2);hold on;
        plot(r,gamma(i,j)*ones(size(r)),'b','LineWidth',2);
        legend('VEV','CEV');
        axis([0 max(max(data)) -2 2.5]);
        xlabel('Swap Rate');
        ylabel('Elasticity of Volatility');
        title([swap_maturity{i},' US Interest Rate Swaps', sample{j}]);
        filename=[swap_maturity{i},sample0{j},'bcev_bvev_median_elasticity_profile'];
        print('-depsc2',[filename,'.eps']);
        print('-djpeg',[filename,'.jpg']);
        print('-dpdf',[filename,'.pdf']);
        
        figure;
        plot(r,vl(:,i,j),'r','LineWidth',2);hold on;
        plot(r,sigma(i,j)*r.^(gamma(i,j)*ones(size(r))),'b','LineWidth',2);
        legend('VEV','CEV');
        xlabel('Swap Rate');
        ylabel('Volatility');
        title([swap_maturity{i},' US Interest Rate Swaps', sample{j}]);
        filename=[swap_maturity{i},sample0{j},'bcev_bvev_median_volatility_profile'];
        print('-depsc2',[filename,'.eps']);
        print('-djpeg',[filename,'.jpg']);
        print('-dpdf',[filename,'.pdf']);
    end
end

% figures in groups of 3
for i=1:N
    figure;
    for j=1:3
        ga=subplot(3,1,j);
        plot(r,vl(:,i,j),'r','LineWidth',1);hold on;
        plot(r,sigma(i,j)*r.^(gamma(i,j)*ones(size(r))),'b','LineWidth',1);
        ylabel(swap_maturity{i},'FontSize',8);
        title(sample1{j},'FontSize',8);
        set(ga,'FontSize',8);
    end
    print('-depsc2',['bcev_bvev_',swap_maturity{i},'_volatility_comparison.eps']);
    print('-djpeg',['bcev_bvev_',swap_maturity{i},'_volatility_comparison.jpg']);
    print('-dpdf',['bcev_bvev_',swap_maturity{i},'_volatility_comparison.pdf']);
    
    figure;
    for j=1:3
        ga=subplot(3,1,j);
        plot(r,elast(:,i,j),'r','LineWidth',1);hold on;
        plot(r,gamma(i,j)*ones(size(r)),'b','LineWidth',1);
        axis([0 max(max(data)) -2 2.5]);
        ylabel(swap_maturity{i},'FontSize',8);
        title(sample1{j},'FontSize',8);
        set(ga,'FontSize',8);
    end
    print('-depsc2',['bcev_bvev_',swap_maturity{i},'_elasticity_comparison.eps']);
    print('-djpeg',['bcev_bvev_',swap_maturity{i},'_elasticity_comparison.jpg']);
    print('-dpdf',['bcev_bvev_',swap_maturity{i},'_elasticity_comparison.pdf']);
end

% all in one figure
figure;
for j=1:3
    for i=1:N
        ga=subplot(N,3,(i-1)*3+j);
        plot(r,elast(:,i,j),'r','LineWidth',1);hold on;
        plot(r,gamma(i,j)*ones(size(r)),'b','LineWidth',1);
        if j<2
            ylabel(swap_maturity{i},'FontSize',6);
        end
        if i<2
            title(sample1{j},'FontSize',6);
        end
        axis([0 max(max(data)) -2 2.5]);
        set(ga,'FontSize',6);
    end
end
print('-depsc2','bcev_bvev_elasticity_comparison.eps');
print('-djpeg','bcev_bvev_elasticity_comparison.jpg');
print('-dpdf','bcev_bvev_elasticity_comparison.pdf');

figure;
for j=1:3
    for i=1:N
        ga=subplot(N,3,(i-1)*3+j);
        plot(r,vl(:,i,j),'r','LineWidth',1);hold on;
        plot(r,sigma(i,j)*r.^(gamma(i,j)*ones(size(r))),'b','LineWidth',1);
        if j<2
            ylabel(swap_maturity{i},'FontSize',6);
        end
        if i<2
            title(sample1{j},'FontSize',6);
        end
        set(ga,'FontSize',6);
    end
end
print('-depsc2','bcev_bvev_volatility_comparison.eps');
print('-djpeg','bcev_bvev_volatility_comparison.jpg');
print('-dpdf','bcev_bvev_volatility_comparison.pdf');

% representative examples of two kinds of profiles
figure;
subplot(2,2,1);
plot(r,elast(:,1,1),'r','LineWidth',1);hold on;
plot(r,gamma(1,1)*ones(size(r)),'b','LineWidth',1);
ylabel('Elasticity');
title('1y');
subplot(2,2,2);
plot(r,elast(:,5,1),'r','LineWidth',1);hold on;
plot(r,gamma(5,1)*ones(size(r)),'b','LineWidth',1);
title('5y');
legend('VEV','CEV');
subplot(2,2,3);
plot(r,vl(:,1,1),'r','LineWidth',1);hold on;
plot(r,sigma(1,1)*r.^(gamma(1,1)*ones(size(r))),'b','LineWidth',1);
ylabel('Volatility');
subplot(2,2,4);
plot(r,vl(:,5,1),'r','LineWidth',1);hold on;
plot(r,sigma(5,1)*r.^(gamma(5,1)*ones(size(r))),'b','LineWidth',1);
print('-depsc2','bcev_bvev_typical_comparison.eps');
print('-djpeg','bcev_bvev_typical_comparison.jpg');
print('-dpdf','bcev_bvev_typical_comparison.pdf');