% function fanchartinsample(X,T,NMC,dates,colorcentral,colorperiph,mediancolor)
% plot in-sample fanchart according to the Bank of England quantile list
% X(1:T,1:NMC) time-series simulated NMC times
% T, NMC - dimensions of X
% dates(1:T) - dates for the x labels
% colorcentral(1:3) - RGB specification of color in the central band
% (optional)
% colorperiph(1:3) - RGB specification of color in the most periphereal
% band (optional)
% mediancolor(1:3) - RGB specification of color of the median line
% (optional)
function fanchartinsample(X,T,NMC,dates,colorcentral,colorperiph,mediancolor)
% darkest_green=[0.2 0.5 0.45];
% list of percentiles (17 bands as per BOE report)
if nargin<7
    mediancolor=[0 0 1];
end
if nargin<6
   colorperiph=[0.85 1.0 0.9]; 
end
if nargin<5
  colorcentral=[0.2 0.5 0.45];  
end
qqs=[5 10 15 20 25 30 35 40 45 55 60 65 70 75 80 85 90 95];
NB=length(qqs)-1; % number of bands
rgbmatrix(length(qqs)/2,:)=colorcentral;
NNCB=length(qqs)/2-1;
%  change in color between successive bands
delta_green=(colorperiph-colorcentral)/NNCB;
for i=1:NNCB
    %  bands
    rgbmatrix(length(qqs)/2+i,:)=colorcentral+i*delta_green;
    rgbmatrix(length(qqs)/2-i,:)=colorcentral+i*delta_green;
end;
ART=[dates',fliplr(dates')];
% compute percentiles
if numel(X)>1000000
    han=waitbar(0,'Computing percentiles ...');
end
for l=1:NB+1
    for j=1:T
        if numel(X)>1000000
            waitbar((j+T*(l-1))/((NB+1)*T));
        end
        pctlX(j,l)=prctile(X(j,:)',qqs(l));
    end
end
if numel(X)>1000000
    close(han);
end
% define polygons
for i=1:NB
    ARS(i,:)=[squeeze(pctlX(:,NB+2-i));flipud(squeeze(pctlX(:,NB+1-i)))]';
end;
%figure;
% central band
HH=fill(ART,squeeze(ARS(NNCB+1,:)),rgbmatrix(NNCB+1,:));
set(HH,'LineStyle','none');
hold on;
% non-central bands
for i=1:NNCB
    HH=fill(ART,squeeze(ARS(NNCB+1+i,:))',rgbmatrix(NNCB+1+i,:));
    set(HH,'LineStyle','none');
    hold on;
    HH=fill(ART,squeeze(ARS(NNCB+1-i,:))',rgbmatrix(NNCB+1-i,:));
    set(HH,'LineStyle','none');
    hold on;
end;
medianX=median(X,2);
lpl=plot(dates,medianX);
set(lpl,'LineWidth',1);
set(lpl,'Color',mediancolor);
%xlabel('Year');
%legend('45-55','40-45','55-60','35-40','60-65','30-35','65-70','25-30','70
%-75','20-25','75-80','15-20','80-85','10-15','85-90','5-10','90-95','MI Median','MI Random Draw','EM Imputation');
%legend1 = legend(gca,{'45-55','40-45','55-60','35-40','60-65','30-35','65-70','25-30','70-75','20-25','75-80','15-20','80-85','10-15','85-90','5-10','90-95','MI Median','MI Random Draw','EM Imputation'},'FontSize',8);

