% process results of Panel Bayesian Variable Elasticity of Volatility model

%% results using full sample

% load saved samples of parameters
d=load('mu_full_atanvev3t_panel_chain1.txt');
T8=size(d,1);
mu_sample=reshape(d(:,2),T8/8,8);
d=load('sigma_full_atanvev3t_panel_chain1.txt');
sigma_sample=reshape(d(:,2),T8/8,8);
d=load('beta1_full_atanvev3t_panel_chain1.txt');
beta1_sample=d(:,2);
d=load('beta2_full_atanvev3t_panel_chain1.txt');
beta2_sample=d(:,2);
d=load('nu_full_atanvev3t_panel_chain1.txt');
nu_sample=reshape(d(:,2),T8/8,8);


NMC=10000;

% compute some simple statistics
mean_mu=mean(mu_sample);
median_mu=median(mu_sample);
p025_mu=prctile(mu_sample,2.5);
p975_mu=prctile(mu_sample,97.5);
std_mu=std(mu_sample);

mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);
p025_sigma=prctile(sigma_sample,2.5);
p975_sigma=prctile(sigma_sample,97.5);
std_sigma=std(sigma_sample);

mean_beta1=mean(beta1_sample);
median_beta1=median(beta1_sample);
p025_beta1=prctile(beta1_sample,2.5);
p975_beta1=prctile(beta1_sample,97.5);
std_beta1=std(beta1_sample);

mean_beta2=mean(beta2_sample);
median_beta2=median(beta2_sample);
p025_beta2=prctile(beta2_sample,2.5);
p975_beta2=prctile(beta2_sample,97.5);
std_beta2=std(beta2_sample);

mean_nu=mean(nu_sample);
median_nu=median(nu_sample);
p025_nu=prctile(nu_sample,2.5);
p975_nu=prctile(nu_sample,97.5);
std_nu=std(nu_sample);

NM=8;
NV=5;
medians=[median_mu;median_sigma;median_beta1*ones(1,NM);median_beta2*ones(1,NM);median_nu];
p025=[p025_mu;p025_sigma;p025_beta1*ones(1,NM);p025_beta2*ones(1,NM);p025_nu];
p975=[p975_mu;p975_sigma;p975_beta1*ones(1,NM);p975_beta2*ones(1,NM);p975_nu];
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'mu','sigma','beta1','beta2','nu'};


% save posterior medians and posterior 95% confidence intervals into a file
fid=fopen('irswap_atanvev3t_full_panelstats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','Posterior Median',...
    'Posterior 2.5th percentile','Posterior 97.5th percentile');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            medians(j,i),p025(j,i),p975(j,i));
    end
end
fclose(fid);

% kernel-smoothed density plots of posterior marginal densities
NK=100;

ksd=NaN(NV,NK,NM);
xsd=NaN(NV,NK,NM);

% all maturity-dependent densities
% mu
ksd_mu=NaN(NM,NK);
xsd_mu=NaN(NM,NK);
for i=1:NM
    lb=prctile(mu_sample(:,i),2.5);
    ub=prctile(mu_sample(:,i),97.5);
    il=find(mu_sample(:,i)>lb);
    gsample=mu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_mu(i,:),xsd_mu(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_mu(i,:),ksd_mu(i,:),'r-','LineWidth',2);
    xlabel('\mu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=['mu_',swap_maturity{i},'_fullpanel_ksd_atanvev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% sigma
ksd_sigma=NaN(NM,NK);
xsd_sigma=NaN(NM,NK);
for i=1:NM
    lb=prctile(sigma_sample(:,i),2.5);
    ub=prctile(sigma_sample(:,i),97.5);
    il=find(sigma_sample(:,i)>lb);
    gsample=sigma_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_sigma(i,:),xsd_sigma(i,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
    figure;
    plot(xsd_sigma(i,:),ksd_sigma(i,:),'r-','LineWidth',2);
    xlabel('\sigma');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=['sigma_',swap_maturity{i},'_fullpanel_ksd_atanvev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% nu
ksd_nu=NaN(NM,NK);
xsd_nu=NaN(NM,NK);
for i=1:NM
    lb=prctile(nu_sample(:,i),2.5);
    ub=prctile(nu_sample(:,i),97.5);
    il=find(nu_sample(:,i)>lb);
    gsample=nu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_nu(i,:),xsd_nu(i,:)]=ksdensity(fsample,'npoints',NK,'support',[1.99,130.1]);
    figure;
    plot(xsd_nu(i,:),ksd_nu(i,:),'r-','LineWidth',2);
    xlabel('\nu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=['nu_',swap_maturity{i},'_fullpanel_ksd_atanvev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% beta1 is not maturity dependent
ksd_beta1=NaN(3,NK); % for 3 sub-samples
xsd_beta1=NaN(3,NK);
lb=prctile(beta1_sample,2.5);
ub=prctile(beta1_sample,97.5);
il=find(beta1_sample>lb);
gsample=beta1_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta1(1,:),xsd_beta1(1,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta1(1,:),ksd_beta1(1,:),'r-','LineWidth',2);
xlabel('\beta_1');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (full sample)']);
filename=['beta1_fullpanel_ksd_atanvev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% beta2 is not maturity dependent
ksd_beta2=NaN(3,NK); % for 3 sub-samples
xsd_beta2=NaN(3,NK);
lb=prctile(beta2_sample,2.5);
ub=prctile(beta2_sample,97.5);
il=find(beta2_sample>lb);
gsample=beta2_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta2(1,:),xsd_beta2(1,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta2(1,:),ksd_beta2(1,:),'r-','LineWidth',2);
xlabel('\beta_2');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (full sample)']);
filename=['beta2_fullpanel_ksd_atanvev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);


save irswap_atanvev3t_fullpanel_postprocess.mat


%% 4-year subsample
% load saved samples of parameters
d=load('mu_sample4_atanvev3t_panel_chain1.txt');
T8=size(d,1);
mu_sample=reshape(d(:,2),T8/8,8);
d=load('sigma_sample4_atanvev3t_panel_chain1.txt');
sigma_sample=reshape(d(:,2),T8/8,8);
d=load('beta1_sample4_atanvev3t_panel_chain1.txt');
beta1_sample=d(:,2);
d=load('beta2_sample4_atanvev3t_panel_chain1.txt');
beta2_sample=d(:,2);
d=load('nu_sample4_atanvev3t_panel_chain1.txt');
nu_sample=reshape(d(:,2),T8/8,8);


NMC=10000;

% compute some simple statistics
mean_mu=mean(mu_sample);
median_mu=median(mu_sample);
p025_mu=prctile(mu_sample,2.5);
p975_mu=prctile(mu_sample,97.5);
std_mu=std(mu_sample);

mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);
p025_sigma=prctile(sigma_sample,2.5);
p975_sigma=prctile(sigma_sample,97.5);
std_sigma=std(sigma_sample);

mean_beta1=mean(beta1_sample);
median_beta1=median(beta1_sample);
p025_beta1=prctile(beta1_sample,2.5);
p975_beta1=prctile(beta1_sample,97.5);
std_beta1=std(beta1_sample);

mean_beta2=mean(beta2_sample);
median_beta2=median(beta2_sample);
p025_beta2=prctile(beta2_sample,2.5);
p975_beta2=prctile(beta2_sample,97.5);
std_beta2=std(beta2_sample);

mean_nu=mean(nu_sample);
median_nu=median(nu_sample);
p025_nu=prctile(nu_sample,2.5);
p975_nu=prctile(nu_sample,97.5);
std_nu=std(nu_sample);

NM=8;
NV=5;
medians=[median_mu;median_sigma;median_beta1*ones(1,NM);median_beta2*ones(1,NM);median_nu];
p025=[p025_mu;p025_sigma;p025_beta1*ones(1,NM);p025_beta2*ones(1,NM);p025_nu];
p975=[p975_mu;p975_sigma;p975_beta1*ones(1,NM);p975_beta2*ones(1,NM);p975_nu];
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'mu','sigma','beta1','beta2','nu'};


% save posterior medians and posterior 95% confidence intervals into a file
fid=fopen('irswap_atanvev3t_sample4_panelstats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','Posterior Median',...
    'Posterior 2.5th percentile','Posterior 97.5th percentile');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            medians(j,i),p025(j,i),p975(j,i));
    end
end
fclose(fid);

% kernel-smoothed density plots of posterior marginal densities
NK=100;

ksd=NaN(NV,NK,NM);
xsd=NaN(NV,NK,NM);

% all maturity-dependent densities
% mu
ksd_mu=NaN(NM,NK);
xsd_mu=NaN(NM,NK);
for i=1:NM
    lb=prctile(mu_sample(:,i),2.5);
    ub=prctile(mu_sample(:,i),97.5);
    il=find(mu_sample(:,i)>lb);
    gsample=mu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_mu(i,:),xsd_mu(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_mu(i,:),ksd_mu(i,:),'r-','LineWidth',2);
    xlabel('\mu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=['mu_',swap_maturity{i},'_sample4panel_ksd_atanvev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% sigma
ksd_sigma=NaN(NM,NK);
xsd_sigma=NaN(NM,NK);
for i=1:NM
    lb=prctile(sigma_sample(:,i),2.5);
    ub=prctile(sigma_sample(:,i),97.5);
    il=find(sigma_sample(:,i)>lb);
    gsample=sigma_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_sigma(i,:),xsd_sigma(i,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
    figure;
    plot(xsd_sigma(i,:),ksd_sigma(i,:),'r-','LineWidth',2);
    xlabel('\sigma');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=['sigma_',swap_maturity{i},'_sample4panel_ksd_atanvev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% nu
ksd_nu=NaN(NM,NK);
xsd_nu=NaN(NM,NK);
for i=1:NM
    lb=prctile(nu_sample(:,i),2.5);
    ub=prctile(nu_sample(:,i),97.5);
    il=find(nu_sample(:,i)>lb);
    gsample=nu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_nu(i,:),xsd_nu(i,:)]=ksdensity(fsample,'npoints',NK,'support',[1.99,130.1]);
    figure;
    plot(xsd_nu(i,:),ksd_nu(i,:),'r-','LineWidth',2);
    xlabel('\nu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=['nu_',swap_maturity{i},'_sample4panel_ksd_atanvev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% beta1 is not maturity dependent
lb=prctile(beta1_sample,2.5);
ub=prctile(beta1_sample,97.5);
il=find(beta1_sample>lb);
gsample=beta1_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta1(2,:),xsd_beta1(2,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta1(2,:),ksd_beta1(2,:),'r-','LineWidth',2);
xlabel('\beta_1');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (4-year sample)']);
filename=['beta1_sample4panel_ksd_atanvev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% beta2 is not maturity dependent
lb=prctile(beta2_sample,2.5);
ub=prctile(beta2_sample,97.5);
il=find(beta2_sample>lb);
gsample=beta2_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta2(2,:),xsd_beta2(2,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta2(2,:),ksd_beta2(2,:),'r-','LineWidth',2);
xlabel('\beta_2');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (4-year sample)']);
filename=['beta2_sample4panel_ksd_atanvev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);


save irswap_atanvev3t_sample4panel_postprocess.mat

%% 1-year subsample
% load saved samples of parameters
d=load('mu_sample1_atanvev3t_panel_chain1.txt');
T8=size(d,1);
mu_sample=reshape(d(:,2),T8/8,8);
d=load('sigma_sample1_atanvev3t_panel_chain1.txt');
sigma_sample=reshape(d(:,2),T8/8,8);
d=load('beta1_sample1_atanvev3t_panel_chain1.txt');
beta1_sample=d(:,2);
d=load('beta2_sample1_atanvev3t_panel_chain1.txt');
beta2_sample=d(:,2);
d=load('nu_sample1_atanvev3t_panel_chain1.txt');
nu_sample=reshape(d(:,2),T8/8,8);


NMC=10000;

% compute some simple statistics
mean_mu=mean(mu_sample);
median_mu=median(mu_sample);
p025_mu=prctile(mu_sample,2.5);
p975_mu=prctile(mu_sample,97.5);
std_mu=std(mu_sample);

mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);
p025_sigma=prctile(sigma_sample,2.5);
p975_sigma=prctile(sigma_sample,97.5);
std_sigma=std(sigma_sample);

mean_beta1=mean(beta1_sample);
median_beta1=median(beta1_sample);
p025_beta1=prctile(beta1_sample,2.5);
p975_beta1=prctile(beta1_sample,97.5);
std_beta1=std(beta1_sample);

mean_beta2=mean(beta2_sample);
median_beta2=median(beta2_sample);
p025_beta2=prctile(beta2_sample,2.5);
p975_beta2=prctile(beta2_sample,97.5);
std_beta2=std(beta2_sample);

mean_nu=mean(nu_sample);
median_nu=median(nu_sample);
p025_nu=prctile(nu_sample,2.5);
p975_nu=prctile(nu_sample,97.5);
std_nu=std(nu_sample);

NM=8;
NV=5;
medians=[median_mu;median_sigma;median_beta1*ones(1,NM);median_beta2*ones(1,NM);median_nu];
p025=[p025_mu;p025_sigma;p025_beta1*ones(1,NM);p025_beta2*ones(1,NM);p025_nu];
p975=[p975_mu;p975_sigma;p975_beta1*ones(1,NM);p975_beta2*ones(1,NM);p975_nu];
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'mu','sigma','beta1','beta2','nu'};


% save posterior medians and posterior 95% confidence intervals into a file
fid=fopen('irswap_atanvev3t_sample1_panelstats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','Posterior Median',...
    'Posterior 2.5th percentile','Posterior 97.5th percentile');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            medians(j,i),p025(j,i),p975(j,i));
    end
end
fclose(fid);

% kernel-smoothed density plots of posterior marginal densities
NK=100;

ksd=NaN(NV,NK,NM);
xsd=NaN(NV,NK,NM);

% all maturity-dependent densities
% mu
ksd_mu=NaN(NM,NK);
xsd_mu=NaN(NM,NK);
for i=1:NM
    lb=prctile(mu_sample(:,i),2.5);
    ub=prctile(mu_sample(:,i),97.5);
    il=find(mu_sample(:,i)>lb);
    gsample=mu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_mu(i,:),xsd_mu(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_mu(i,:),ksd_mu(i,:),'r-','LineWidth',2);
    xlabel('\mu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=['mu_',swap_maturity{i},'_sample1panel_ksd_atanvev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% sigma
ksd_sigma=NaN(NM,NK);
xsd_sigma=NaN(NM,NK);
for i=1:NM
    lb=prctile(sigma_sample(:,i),2.5);
    ub=prctile(sigma_sample(:,i),97.5);
    il=find(sigma_sample(:,i)>lb);
    gsample=sigma_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_sigma(i,:),xsd_sigma(i,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
    figure;
    plot(xsd_sigma(i,:),ksd_sigma(i,:),'r-','LineWidth',2);
    xlabel('\sigma');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=['sigma_',swap_maturity{i},'_sample1panel_ksd_atanvev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% nu
ksd_nu=NaN(NM,NK);
xsd_nu=NaN(NM,NK);
for i=1:NM
    lb=prctile(nu_sample(:,i),2.5);
    ub=prctile(nu_sample(:,i),97.5);
    il=find(nu_sample(:,i)>lb);
    gsample=nu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_nu(i,:),xsd_nu(i,:)]=ksdensity(fsample,'npoints',NK,'support',[1.99,130.1]);
    figure;
    plot(xsd_nu(i,:),ksd_nu(i,:),'r-','LineWidth',2);
    xlabel('\nu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=['nu_',swap_maturity{i},'_sample1panel_ksd_atanvev3t'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% beta1 is not maturity dependent
lb=prctile(beta1_sample,2.5);
ub=prctile(beta1_sample,97.5);
il=find(beta1_sample>lb);
gsample=beta1_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta1(3,:),xsd_beta1(3,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta1(3,:),ksd_beta1(3,:),'r-','LineWidth',2);
xlabel('\beta_1');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (1-year sample)']);
filename=['beta1_sample1panel_ksd_atanvev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% beta2 is not maturity dependent
lb=prctile(beta2_sample,2.5);
ub=prctile(beta2_sample,97.5);
il=find(beta2_sample>lb);
gsample=beta2_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta2(3,:),xsd_beta2(3,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta2(3,:),ksd_beta2(3,:),'r-','LineWidth',2);
xlabel('\beta_2');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (1-year sample)']);
filename=['beta2_sample1panel_ksd_atanvev3t'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);


save irswap_atanvev3t_sample1panel_postprocess.mat

% all maturity independent parameters together
figure;
% beta1
subplot(2,1,1);
plot(xsd_beta1(1,:),ksd_beta1(1,:),'r-','LineWidth',2);hold on;
plot(xsd_beta1(2,:),ksd_beta1(2,:),'b-','LineWidth',2);hold on;
plot(xsd_beta1(3,:),ksd_beta1(3,:),'g-','LineWidth',2);
xlabel('\beta_1');
ylabel('Marginal Posterior Density');
legend('Full sample','4-year sample','1-year sample');
% beta2
subplot(2,1,2);
plot(xsd_beta2(1,:),ksd_beta2(1,:),'r-','LineWidth',2);hold on;
plot(xsd_beta2(2,:),ksd_beta2(2,:),'b-','LineWidth',2);hold on;
plot(xsd_beta2(3,:),ksd_beta2(3,:),'g-','LineWidth',2);
xlabel('\beta_2');
ylabel('Marginal Posterior Density');
legend('Full sample','4-year sample','1-year sample');
print('-depsc2','betas_ksd_atanvev3t.eps');
print('-djpeg','betas_ksd_atanvev3t.eps');
print('-depsc2','betas_ksd_atanvev3t.eps');