% estimate variable elasticity of volatility model with normal
% innovations on irswap data with maximum likelihood

% load data
data=csvread('../data/irswap_daily_20000703_20120726.csv',1,1);
[T,N]=size(data);
dates=csvread('../data/irswap_daily_20000703_20120726.csv',1,0,[1,0,T,0]);
p=NaN(N,4);
ci=NaN(2,4,N);
aic=NaN(N,1);
p4=NaN(N,4);
ci4=NaN(2,4,N);
aic4=NaN(N,1);
p1=NaN(N,4);
ci1=NaN(2,4,N);
aic1=NaN(N,1);
alpha=0.05;
% last 4 years
i4=find(dates>=dates(end)-40000);
data4=data(i4,:);
T4=size(data4,1);
% last 1 year
i1=find(dates>=dates(end)-10000);
data1=data(i1,:);
T1=size(data1,1);
names={'US IRSWAPS 1y','US IRSWAPS 2y','US IRSWAPS 3y','US IRSWAPS 4y',...
    'US IRSWAPS 5y','US IRSWAPS 7y','US IRSWAPS 10y','US IRSWAPS 30y'};

% statistics on fill-forwards

% full sample
for i=1:N
    % starting guess for full sample
    i
    start=[0,log(std(diff(data(:,i)))),1,0];
    [p(i,:),ci(:,:,i),aic(i)] = atanvev3_normal_mle(data(:,i),alpha,start);
    
    
end

% last 4 years
for i=1:N
    % starting guess for full sample
    i
    start=[0,log(std(diff(data4(:,i)))),1,0];
    [p4(i,:),ci4(:,:,i),aic4(i)] = atanvev3_normal_mle(data4(:,i),alpha,start);
    
    
end

% last 1 year
for i=1:N
    % starting guess for full sample
    i
    start=[0,log(std(diff(data1(:,i)))),1,0];
    [p1(i,:),ci1(:,:,i),aic1(i)] = atanvev3_normal_mle(data1(:,i),alpha,start);
    
    
end

% save results in csv files
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'mu','sigma','beta1','beta2'};
NM=8;
NV=4;

% full sample
fid=fopen('irswap_atanvev3_normal_full_mle_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','ML Estimate',...
    '2.5th percentile bound','97.5th percentile bound');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            p(i,j),ci(1,j,i),ci(2,j,i));
    end
end
fclose(fid);

% 4-year sample
fid=fopen('irswap_atanvev3_normal_sample4_mle_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','ML Estimate',...
    '2.5th percentile bound','97.5th percentile bound');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            p4(i,j),ci4(1,j,i),ci4(2,j,i));
    end
end
fclose(fid);

% 1-year sample
fid=fopen('irswap_atanvev3_normal_sample1_mle_stats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','ML Estimate',...
    '2.5th percentile bound','97.5th percentile bound');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            p1(i,j),ci1(1,j,i),ci1(2,j,i));
    end
end
fclose(fid);

% add plots of estimated elasticity profiles
rlow=min(min(data));
rup=max(max(data));
NR=128;
rgrid=linspace(rlow,rup,NR);
ve=NaN(NR,NM);
ve4=NaN(NR,NM);
ve1=NaN(NR,NM);
for i=1:NM
    for j=1:NR
        ve(j,i)=6/pi*atan(p(i,3)+p(i,4)*rgrid(j))-1;
        ve4(j,i)=6/pi*atan(p4(i,3)+p4(i,4)*rgrid(j))-1;
        ve1(j,i)=6/pi*atan(p1(i,3)+p1(i,4)*rgrid(j))-1;
    end
    figure;
    plot(rgrid,ve(:,i),'r-','LineWidth',2); hold on;
    plot(rgrid,ve4(:,i),'b-','LineWidth',2); hold on;
    plot(rgrid,ve1(:,i),'g-','LineWidth',2); hold on;
    xlabel('Interest Rate');
    ylabel('Elasticity of Volatility');
    title([swap_maturity{i}, ' US interest rate swaps']);
    legend('Full sample','4-year sample', '1-year sample');
    filename=['mle_normal_elasticity_profile_',swap_maturity{i}];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end