% process results of Bayesian Variable Elasticity of Volatility model
% additional processing to show estimated elasticity profiles

% full dataset
data=csvread('../data/irswap_daily_20000703_20120726.csv',1,1);
[T,N]=size(data);
rlow=min(min(data));
rup=max(max(data));
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
NM=8;
NR=128;
rgrid=linspace(rlow,rup,NR)';

%% results using full sample
% load saved samples of parameters
d=load('beta1_atanvev3t_full_1y_chain1.txt');
beta1_sample1y=d(:,2);
d=load('beta1_atanvev3t_full_2y_chain1.txt');
beta1_sample2y=d(:,2);
d=load('beta1_atanvev3t_full_3y_chain1.txt');
beta1_sample3y=d(:,2);
d=load('beta1_atanvev3t_full_4y_chain1.txt');
beta1_sample4y=d(:,2);
d=load('beta1_atanvev3t_full_5y_chain1.txt');
beta1_sample5y=d(:,2);
d=load('beta1_atanvev3t_full_7y_chain1.txt');
beta1_sample7y=d(:,2);
d=load('beta1_atanvev3t_full_10y_chain1.txt');
beta1_sample10y=d(:,2);
d=load('beta1_atanvev3t_full_30y_chain1.txt');
beta1_sample30y=d(:,2);

d=load('beta2_atanvev3t_full_1y_chain1.txt');
beta2_sample1y=d(:,2);
d=load('beta2_atanvev3t_full_2y_chain1.txt');
beta2_sample2y=d(:,2);
d=load('beta2_atanvev3t_full_3y_chain1.txt');
beta2_sample3y=d(:,2);
d=load('beta2_atanvev3t_full_4y_chain1.txt');
beta2_sample4y=d(:,2);
d=load('beta2_atanvev3t_full_5y_chain1.txt');
beta2_sample5y=d(:,2);
d=load('beta2_atanvev3t_full_7y_chain1.txt');
beta2_sample7y=d(:,2);
d=load('beta2_atanvev3t_full_10y_chain1.txt');
beta2_sample10y=d(:,2);
d=load('beta2_atanvev3t_full_30y_chain1.txt');
beta2_sample30y=d(:,2);

d=load('sigma_atanvev3t_full_1y_chain1.txt');
sigma_sample1y=d(:,2);
d=load('sigma_atanvev3t_full_2y_chain1.txt');
sigma_sample2y=d(:,2);
d=load('sigma_atanvev3t_full_3y_chain1.txt');
sigma_sample3y=d(:,2);
d=load('sigma_atanvev3t_full_4y_chain1.txt');
sigma_sample4y=d(:,2);
d=load('sigma_atanvev3t_full_5y_chain1.txt');
sigma_sample5y=d(:,2);
d=load('sigma_atanvev3t_full_7y_chain1.txt');
sigma_sample7y=d(:,2);
d=load('sigma_atanvev3t_full_10y_chain1.txt');
sigma_sample10y=d(:,2);
d=load('sigma_atanvev3t_full_30y_chain1.txt');
sigma_sample30y=d(:,2);


% compute mean and median statistics on elsaticity coefficients
mean_beta1=mean([beta1_sample1y,beta1_sample2y,beta1_sample3y,beta1_sample4y,...
    beta1_sample5y,beta1_sample7y,beta1_sample10y,beta1_sample30y]);
median_beta1=median([beta1_sample1y,beta1_sample2y,beta1_sample3y,beta1_sample4y,...
    beta1_sample5y,beta1_sample7y,beta1_sample10y,beta1_sample30y]);

mean_beta2=mean([beta2_sample1y,beta2_sample2y,beta2_sample3y,beta2_sample4y,...
    beta2_sample5y,beta2_sample7y,beta2_sample10y,beta2_sample30y]);
median_beta2=median([beta2_sample1y,beta2_sample2y,beta2_sample3y,beta2_sample4y,...
    beta2_sample5y,beta2_sample7y,beta2_sample10y,beta2_sample30y]);

mean_sigma=mean([sigma_sample1y,sigma_sample2y,sigma_sample3y,sigma_sample4y,...
    sigma_sample5y,sigma_sample7y,sigma_sample10y,sigma_sample30y]);
median_sigma=median([sigma_sample1y,sigma_sample2y,sigma_sample3y,sigma_sample4y,...
    sigma_sample5y,sigma_sample7y,sigma_sample10y,sigma_sample30y]);

% implied elasticity of volatility profiles
ve=NaN(NR,NM);
ve2=NaN(NR,NM);
% mean/median volatility profiles
vl=NaN(NR,NM);
vl2=NaN(NR,NM);
for i=1:NM
    for j=1:NR
        ve(j,i)=3/pi*atan(median_beta2(i)*rgrid(j)+median_beta1(i))+0.5;
        ve2(j,i)=3/pi*atan(mean_beta2(i)*rgrid(j)+mean_beta1(i))+0.5;
        vl(j,i)=median_sigma(i)*rgrid(j)^ve(j,i);
        vl2(j,i)=mean_sigma(i)*rgrid(j)^ve2(j,i);
    end
    % median elasticity profile
    figure;
    plot(rgrid,ve(:,i),'r-','LineWidth',2);
    axis tight;
    xlabel('Interest Rate');
    ylabel('Elasticity of Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=[swap_maturity{i},'_full_atanvev3t_median_elasticity_profile'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    % mean elasticity profile
    figure;
    plot(rgrid,ve2(:,i),'r-','LineWidth',2);
    axis tight;
    xlabel('Interest Rate');
    ylabel('Elasticity of Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=[swap_maturity{i},'_full_atanvev3t_mean_elasticity_profile'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    
    % median and mean elasticity profiles together
    figure;
    plot(rgrid,ve(:,i),'r-','LineWidth',2);hold on;
    plot(rgrid,ve2(:,i),'b-','LineWidth',2);
    legend('Median-based','Mean-based');
    axis tight;
    xlabel('Interest Rate');
    ylabel('Elasticity of Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=[swap_maturity{i},'_full_atanvev3t_elasticity_profiles'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    
    % median volatility profile
    figure;
    plot(rgrid,vl(:,i),'r-','LineWidth',2);
    axis tight;
    xlabel('Interest Rate');
    ylabel('Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=[swap_maturity{i},'_full_atanvev3t_median_volatility_profile'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    % mean volatility profile
    figure;
    plot(rgrid,vl2(:,i),'r-','LineWidth',2);
    axis tight;
    xlabel('Interest Rate');
    ylabel('Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=[swap_maturity{i},'_full_atanvev3t_mean_volatility_profile'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    
    % median and mean elasticity profiles together
    figure;
    plot(rgrid,vl(:,i),'r-','LineWidth',2);hold on;
    plot(rgrid,vl2(:,i),'b-','LineWidth',2);
    legend('Median-based','Mean-based');
    axis tight;
    xlabel('Interest Rate');
    ylabel('Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=[swap_maturity{i},'_full_atanvev3t_volatility_profiles'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% colors
co=[0,0,1;  0,0.5,0; 1,0,0; 0,0.75,0.75;   0.75,0,0.75; 0.75,0.75,0; 0.25,0.25,0.25;0.31,0.4,0.58];

% all median elasticity profiles together
figure;
for i=1:NM
    plot(rgrid,ve(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title('US Interest Rate Swaps (full sample)');
filename=['atanvev3t_median_elasticity_profiles_full'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% all mean elasticity profiles together
figure;
for i=1:NM
    plot(rgrid,ve2(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title('US Interest Rate Swaps (full sample)');
filename=['atanvev3t_mean_elasticity_profiles_full'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% all median volatility profiles together
figure;
for i=1:NM
    plot(rgrid,vl(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Volatility');
title('US Interest Rate Swaps (full sample)');
filename=['atanvev3t_median_volatility_profiles_full'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% all mean volatility profiles together
figure;
for i=1:NM
    plot(rgrid,vl2(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Volatility');
title('US Interest Rate Swaps (full sample)');
filename=['atanvev3t_mean_volatility_profiles_full'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

%% 4-year subsample
% load saved samples of parameters
d=load('beta1_atanvev3t_sample4_1y_chain1.txt');
beta1_sample1y=d(:,2);
d=load('beta1_atanvev3t_sample4_2y_chain1.txt');
beta1_sample2y=d(:,2);
d=load('beta1_atanvev3t_sample4_3y_chain1.txt');
beta1_sample3y=d(:,2);
d=load('beta1_atanvev3t_sample4_4y_chain1.txt');
beta1_sample4y=d(:,2);
d=load('beta1_atanvev3t_sample4_5y_chain1.txt');
beta1_sample5y=d(:,2);
d=load('beta1_atanvev3t_sample4_7y_chain1.txt');
beta1_sample7y=d(:,2);
d=load('beta1_atanvev3t_sample4_10y_chain1.txt');
beta1_sample10y=d(:,2);
d=load('beta1_atanvev3t_sample4_30y_chain1.txt');
beta1_sample30y=d(:,2);

d=load('beta2_atanvev3t_sample4_1y_chain1.txt');
beta2_sample1y=d(:,2);
d=load('beta2_atanvev3t_sample4_2y_chain1.txt');
beta2_sample2y=d(:,2);
d=load('beta2_atanvev3t_sample4_3y_chain1.txt');
beta2_sample3y=d(:,2);
d=load('beta2_atanvev3t_sample4_4y_chain1.txt');
beta2_sample4y=d(:,2);
d=load('beta2_atanvev3t_sample4_5y_chain1.txt');
beta2_sample5y=d(:,2);
d=load('beta2_atanvev3t_sample4_7y_chain1.txt');
beta2_sample7y=d(:,2);
d=load('beta2_atanvev3t_sample4_10y_chain1.txt');
beta2_sample10y=d(:,2);
d=load('beta2_atanvev3t_sample4_30y_chain1.txt');
beta2_sample30y=d(:,2);

d=load('sigma_atanvev3t_sample4_1y_chain1.txt');
sigma_sample1y=d(:,2);
d=load('sigma_atanvev3t_sample4_2y_chain1.txt');
sigma_sample2y=d(:,2);
d=load('sigma_atanvev3t_sample4_3y_chain1.txt');
sigma_sample3y=d(:,2);
d=load('sigma_atanvev3t_sample4_4y_chain1.txt');
sigma_sample4y=d(:,2);
d=load('sigma_atanvev3t_sample4_5y_chain1.txt');
sigma_sample5y=d(:,2);
d=load('sigma_atanvev3t_sample4_7y_chain1.txt');
sigma_sample7y=d(:,2);
d=load('sigma_atanvev3t_sample4_10y_chain1.txt');
sigma_sample10y=d(:,2);
d=load('sigma_atanvev3t_sample4_30y_chain1.txt');
sigma_sample30y=d(:,2);



% compute mean and median statistics on elsaticity coefficients
mean_beta1=mean([beta1_sample1y,beta1_sample2y,beta1_sample3y,beta1_sample4y,...
    beta1_sample5y,beta1_sample7y,beta1_sample10y,beta1_sample30y]);
median_beta1=median([beta1_sample1y,beta1_sample2y,beta1_sample3y,beta1_sample4y,...
    beta1_sample5y,beta1_sample7y,beta1_sample10y,beta1_sample30y]);

mean_beta2=mean([beta2_sample1y,beta2_sample2y,beta2_sample3y,beta2_sample4y,...
    beta2_sample5y,beta2_sample7y,beta2_sample10y,beta2_sample30y]);
median_beta2=median([beta2_sample1y,beta2_sample2y,beta2_sample3y,beta2_sample4y,...
    beta2_sample5y,beta2_sample7y,beta2_sample10y,beta2_sample30y]);

mean_sigma=mean([sigma_sample1y,sigma_sample2y,sigma_sample3y,sigma_sample4y,...
    sigma_sample5y,sigma_sample7y,sigma_sample10y,sigma_sample30y]);
median_sigma=median([sigma_sample1y,sigma_sample2y,sigma_sample3y,sigma_sample4y,...
    sigma_sample5y,sigma_sample7y,sigma_sample10y,sigma_sample30y]);

% implied elasticity of volatility profiles
ve=NaN(NR,NM);
ve2=NaN(NR,NM);
% mean/median volatility profiles
vl=NaN(NR,NM);
vl2=NaN(NR,NM);
for i=1:NM
    for j=1:NR
        ve(j,i)=3/pi*atan(median_beta2(i)*rgrid(j)+median_beta1(i))+0.5;
        ve2(j,i)=3/pi*atan(mean_beta2(i)*rgrid(j)+mean_beta1(i))+0.5;
        vl(j,i)=median_sigma(i)*rgrid(j)^ve(j,i);
        vl2(j,i)=mean_sigma(i)*rgrid(j)^ve2(j,i);
    end
    % median profile
    figure;
    plot(rgrid,ve(:,i),'r-','LineWidth',2);
    axis tight;
    xlabel('Interest Rate');
    ylabel('Elasticity of Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=[swap_maturity{i},'_sample4_atanvev3t_median_elasticity_profile'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    % mean profile
    figure;
    plot(rgrid,ve2(:,i),'r-','LineWidth',2);
    axis tight;
    xlabel('Interest Rate');
    ylabel('Elasticity of Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=[swap_maturity{i},'_sample4_atanvev3t_mean_elasticity_profile'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    
    % median and mean profile together
    figure;
    plot(rgrid,ve(:,i),'r-','LineWidth',2);hold on;
    plot(rgrid,ve2(:,i),'b-','LineWidth',2);
    legend('Median-based','Mean-based');
    axis tight;
    xlabel('Interest Rate');
    ylabel('Elasticity of Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=[swap_maturity{i},'_sample4_atanvev3t_elasticity_profiles'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    
    % median profile
    figure;
    plot(rgrid,vl(:,i),'r-','LineWidth',2);
    axis tight;
    xlabel('Interest Rate');
    ylabel('Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=[swap_maturity{i},'_sample4_atanvev3t_median_volatility_profile'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    % mean profile
    figure;
    plot(rgrid,vl2(:,i),'r-','LineWidth',2);
    axis tight;
    xlabel('Interest Rate');
    ylabel('Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=[swap_maturity{i},'_sample4_atanvev3t_mean_volatility_profile'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    
    % median and mean profile together
    figure;
    plot(rgrid,vl(:,i),'r-','LineWidth',2);hold on;
    plot(rgrid,vl2(:,i),'b-','LineWidth',2);
    legend('Median-based','Mean-based');
    axis tight;
    xlabel('Interest Rate');
    ylabel('Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=[swap_maturity{i},'_sample4_atanvev3t_volatility_profiles'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% colors
co=[0,0,1;  0,0.5,0; 1,0,0; 0,0.75,0.75;   0.75,0,0.75; 0.75,0.75,0; 0.25,0.25,0.25;0.31,0.4,0.58];

% all median profiles together
figure;
for i=1:NM
    plot(rgrid,ve(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title('US Interest Rate Swaps (4-year sample)');
filename=['atanvev3t_median_elasticity_profiles_sample4'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% all mean profiles together
figure;
for i=1:NM
    plot(rgrid,ve2(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title('US Interest Rate Swaps (4-year sample)');
filename=['atanvev3t_mean_elasticity_profiles_sample4'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% all median volatility profiles together
figure;
for i=1:NM
    plot(rgrid,vl(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Volatility');
title('US Interest Rate Swaps (4-year sample)');
filename=['atanvev3t_median_volatility_profiles_sample4'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% all mean volatility profiles together
figure;
for i=1:NM
    plot(rgrid,vl2(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Volatility');
title('US Interest Rate Swaps (4-year sample)');
filename=['atanvev3t_mean_volatility_profiles_sample4'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

%% 1-year subsample
% load saved samples of parameters
d=load('beta1_atanvev3t_sample1_1y_chain1.txt');
beta1_sample1y=d(:,2);
d=load('beta1_atanvev3t_sample1_2y_chain1.txt');
beta1_sample2y=d(:,2);
d=load('beta1_atanvev3t_sample1_3y_chain1.txt');
beta1_sample3y=d(:,2);
d=load('beta1_atanvev3t_sample1_4y_chain1.txt');
beta1_sample4y=d(:,2);
d=load('beta1_atanvev3t_sample1_5y_chain1.txt');
beta1_sample5y=d(:,2);
d=load('beta1_atanvev3t_sample1_7y_chain1.txt');
beta1_sample7y=d(:,2);
d=load('beta1_atanvev3t_sample1_10y_chain1.txt');
beta1_sample10y=d(:,2);
d=load('beta1_atanvev3t_sample1_30y_chain1.txt');
beta1_sample30y=d(:,2);

d=load('beta2_atanvev3t_sample1_1y_chain1.txt');
beta2_sample4y=d(:,2);
d=load('beta2_atanvev3t_sample1_2y_chain1.txt');
beta2_sample2y=d(:,2);
d=load('beta2_atanvev3t_sample1_3y_chain1.txt');
beta2_sample3y=d(:,2);
d=load('beta2_atanvev3t_sample1_4y_chain1.txt');
beta2_sample1y=d(:,2);
d=load('beta2_atanvev3t_sample1_5y_chain1.txt');
beta2_sample5y=d(:,2);
d=load('beta2_atanvev3t_sample1_7y_chain1.txt');
beta2_sample7y=d(:,2);
d=load('beta2_atanvev3t_sample1_10y_chain1.txt');
beta2_sample10y=d(:,2);
d=load('beta2_atanvev3t_sample1_30y_chain1.txt');
beta2_sample30y=d(:,2);

d=load('sigma_atanvev3t_sample1_1y_chain1.txt');
sigma_sample4y=d(:,2);
d=load('sigma_atanvev3t_sample1_2y_chain1.txt');
sigma_sample2y=d(:,2);
d=load('sigma_atanvev3t_sample1_3y_chain1.txt');
sigma_sample3y=d(:,2);
d=load('sigma_atanvev3t_sample1_4y_chain1.txt');
sigma_sample1y=d(:,2);
d=load('sigma_atanvev3t_sample1_5y_chain1.txt');
sigma_sample5y=d(:,2);
d=load('sigma_atanvev3t_sample1_7y_chain1.txt');
sigma_sample7y=d(:,2);
d=load('sigma_atanvev3t_sample1_10y_chain1.txt');
sigma_sample10y=d(:,2);
d=load('sigma_atanvev3t_sample1_30y_chain1.txt');
sigma_sample30y=d(:,2);


% compute mean and median statistics on elsaticity coefficients
mean_beta1=mean([beta1_sample1y,beta1_sample2y,beta1_sample3y,beta1_sample4y,...
    beta1_sample5y,beta1_sample7y,beta1_sample10y,beta1_sample30y]);
median_beta1=median([beta1_sample1y,beta1_sample2y,beta1_sample3y,beta1_sample4y,...
    beta1_sample5y,beta1_sample7y,beta1_sample10y,beta1_sample30y]);

mean_beta2=mean([beta2_sample1y,beta2_sample2y,beta2_sample3y,beta2_sample4y,...
    beta2_sample5y,beta2_sample7y,beta2_sample10y,beta2_sample30y]);
median_beta2=median([beta2_sample1y,beta2_sample2y,beta2_sample3y,beta2_sample4y,...
    beta2_sample5y,beta2_sample7y,beta2_sample10y,beta2_sample30y]);

mean_sigma=mean([sigma_sample1y,sigma_sample2y,sigma_sample3y,sigma_sample4y,...
    sigma_sample5y,sigma_sample7y,sigma_sample10y,sigma_sample30y]);
median_sigma=median([sigma_sample1y,sigma_sample2y,sigma_sample3y,sigma_sample4y,...
    sigma_sample5y,sigma_sample7y,sigma_sample10y,sigma_sample30y]);

% implied elasticity of volatility profiles
ve=NaN(NR,NM);
ve2=NaN(NR,NM);
% mean/median volatility profiles
vl=NaN(NR,NM);
vl2=NaN(NR,NM);
for i=1:NM
    for j=1:NR
        ve(j,i)=3/pi*atan(median_beta2(i)*rgrid(j)+median_beta1(i))+0.5;
        ve2(j,i)=3/pi*atan(mean_beta2(i)*rgrid(j)+mean_beta1(i))+0.5;
        vl(j,i)=median_sigma(i)*rgrid(j)^ve(j,i);
        vl2(j,i)=mean_sigma(i)*rgrid(j)^ve2(j,i);
    end
    % median profile
    figure;
    plot(rgrid,ve(:,i),'r-','LineWidth',2);
    axis tight;
    xlabel('Interest Rate');
    ylabel('Elasticity of Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=[swap_maturity{i},'_sample1_atanvev3t_median_elasticity_profile'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    % mean profile
    figure;
    plot(rgrid,ve2(:,i),'r-','LineWidth',2);
    axis tight;
    xlabel('Interest Rate');
    ylabel('Elasticity of Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=[swap_maturity{i},'_sample1_atanvev3t_mean_elasticity_profile'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    
    % median and mean profile together
    figure;
    plot(rgrid,ve(:,i),'r-','LineWidth',2);hold on;
    plot(rgrid,ve2(:,i),'b-','LineWidth',2);
    legend('Median-based','Mean-based');
    axis tight;
    xlabel('Interest Rate');
    ylabel('Elasticity of Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=[swap_maturity{i},'_sample1_atanvev3t_elasticity_profiles'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    
    % median volatility profile
    figure;
    plot(rgrid,vl(:,i),'r-','LineWidth',2);
    axis tight;
    xlabel('Interest Rate');
    ylabel('Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=[swap_maturity{i},'_sample1_atanvev3t_median_volatility_profile'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    % mean profile
    figure;
    plot(rgrid,vl2(:,i),'r-','LineWidth',2);
    axis tight;
    xlabel('Interest Rate');
    ylabel('Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=[swap_maturity{i},'_sample1_atanvev3t_mean_volatility_profile'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
    
    % median and mean volatility profiles together
    figure;
    plot(rgrid,vl(:,i),'r-','LineWidth',2);hold on;
    plot(rgrid,vl2(:,i),'b-','LineWidth',2);
    legend('Median-based','Mean-based');
    axis tight;
    xlabel('Interest Rate');
    ylabel('Volatility');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=[swap_maturity{i},'_sample1_atanvev3t_volatility_profiles'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% colors
co=[0,0,1;  0,0.5,0; 1,0,0; 0,0.75,0.75;   0.75,0,0.75; 0.75,0.75,0; 0.25,0.25,0.25;0.31,0.4,0.58];

% all median profiles together
figure;
for i=1:NM
    plot(rgrid,ve(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title('US Interest Rate Swaps (1-year sample)');
filename=['atanvev3t_median_elasticity_profiles_sample1'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% all mean profiles together
figure;
for i=1:NM
    plot(rgrid,ve2(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title('US Interest Rate Swaps (1-year sample)');
filename=['atanvev3t_mean_elasticity_profiles_sample1'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% all median volatility profiles together
figure;
for i=1:NM
    plot(rgrid,vl(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Volatility');
title('US Interest Rate Swaps (1-year sample)');
filename=['atanvev3t_median_volatility_profiles_sample1'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% all mean volatility profiles together
figure;
for i=1:NM
    plot(rgrid,vl2(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title('US Interest Rate Swaps (1-year sample)');
filename=['atanvev3t_mean_volatility_profiles_sample1'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);