% process results of panel Bayesian Variable Elasticity of Volatility model with
% quadratic elasticity function
% additional processing to show estimated elasticity profiles

% full dataset
data=csvread('../data/irswap_daily_20000703_20120726.csv',1,1);
[T,N]=size(data);
rlow=min(min(data));
rup=max(max(data));
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
NM=8;
NR=128;
rgrid=linspace(rlow,rup,NR)';

%% results using full sample
% load saved samples of parameters
d=load('sigma_vevtsq_panel_full_chain1.txt');
T8=size(d,1);
sigma_sample=reshape(d(:,2),T8/8,8);
d=load('beta0_vevtsq_panel_full_chain1.txt');
beta0_sample=d(:,2);
d=load('beta1_vevtsq_panel_full_chain1.txt');
beta1_sample=d(:,2);
d=load('beta2_vevtsq_panel_full_chain1.txt');
beta2_sample=d(:,2);

% compute mean and median statistics on elsaticity coefficients
mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);

mean_beta0=mean(beta0_sample);
median_beta0=median(beta0_sample);

mean_beta1=mean(beta1_sample);
median_beta1=median(beta1_sample);

mean_beta2=mean(beta2_sample);
median_beta2=median(beta2_sample);



% implied elasticity of volatility profiles
ve=NaN(NR,1);
ve2=NaN(NR,1);
% mean/median volatility profiles
vl=NaN(NR,NM);
vl2=NaN(NR,NM);
for j=1:NR
    ve(j,1)=median_beta2*rgrid(j)^2+median_beta1*rgrid(j)+median_beta0;
    ve2(j,1)=mean_beta2*rgrid(j)^2+mean_beta1*rgrid(j)+mean_beta0;
    for i=1:NM
        vl(j,i)=median_sigma(i)*rgrid(j)^ve(j,1);
        vl2(j,i)=mean_sigma(i)*rgrid(j)^ve2(j,1);
    end
end
% median elasticity profile
figure;
plot(rgrid,ve(:,1),'r-','LineWidth',2);
axis tight;
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title([' US Interest Rate Swaps (full sample)']);
filename=['panel_full_vevtsq_median_elasticity_profile'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);
% mean elasticity profile
figure;
plot(rgrid,ve2(:,1),'r-','LineWidth',2);
axis tight;
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title([' US Interest Rate Swaps (full sample)']);
filename=['panel_full_vevtsq_mean_elasticity_profile'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);
    
% median and mean elasticity profiles together
figure;
plot(rgrid,ve(:,1),'r-','LineWidth',2);hold on;
plot(rgrid,ve2(:,1),'b-','LineWidth',2);
legend('Median-based','Mean-based');
axis tight;
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title([' US Interest Rate Swaps (full sample)']);
filename=['panel_full_vevtsq_elasticity_profiles'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% colors
co=[0,0,1;  0,0.5,0; 1,0,0; 0,0.75,0.75;   0.75,0,0.75; 0.75,0.75,0; 0.25,0.25,0.25;0.31,0.4,0.58];



% all median volatility profiles together
figure;
for i=1:NM
    plot(rgrid,vl(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Volatility');
title('US Interest Rate Swaps (full sample)');
filename=['panel_vevtsq_median_volatility_profiles_full'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% all mean volatility profiles together
figure;
for i=1:NM
    plot(rgrid,vl2(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Volatility');
title('US Interest Rate Swaps (full sample)');
filename=['panel_vevtsq_mean_volatility_profiles_full'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

%% 4-year subsample
% load saved samples of parameters
d=load('sigma_vevtsq_panel_sample4_chain1.txt');
T8=size(d,1);
sigma_sample=reshape(d(:,2),T8/8,8);
d=load('beta0_vevtsq_panel_sample4_chain1.txt');
beta0_sample=d(:,2);
d=load('beta1_vevtsq_panel_sample4_chain1.txt');
beta1_sample=d(:,2);
d=load('beta2_vevtsq_panel_sample4_chain1.txt');
beta2_sample=d(:,2);

% compute mean and median statistics on elsaticity coefficients
mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);

mean_beta0=mean(beta0_sample);
median_beta0=median(beta0_sample);

mean_beta1=mean(beta1_sample);
median_beta1=median(beta1_sample);

mean_beta2=mean(beta2_sample);
median_beta2=median(beta2_sample);



% implied elasticity of volatility profiles
ve=NaN(NR,1);
ve2=NaN(NR,1);
% mean/median volatility profiles
vl=NaN(NR,NM);
vl2=NaN(NR,NM);
for j=1:NR
    ve(j,1)=median_beta2*rgrid(j)^2+median_beta1*rgrid(j)+median_beta0;
    ve2(j,1)=mean_beta2*rgrid(j)^2+mean_beta1*rgrid(j)+mean_beta0;
    for i=1:NM
        vl(j,i)=median_sigma(i)*rgrid(j)^ve(j,1);
        vl2(j,i)=mean_sigma(i)*rgrid(j)^ve2(j,1);
    end
end
% median elasticity profile
figure;
plot(rgrid,ve(:,1),'r-','LineWidth',2);
axis tight;
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title([' US Interest Rate Swaps (4-year sample)']);
filename=['panel_sample4_vevtsq_median_elasticity_profile'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);
% mean elasticity profile
figure;
plot(rgrid,ve2(:,1),'r-','LineWidth',2);
axis tight;
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title([' US Interest Rate Swaps (4-year sample)']);
filename=['panel_sample4_vevtsq_mean_elasticity_profile'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);
    
% median and mean elasticity profiles together
figure;
plot(rgrid,ve(:,1),'r-','LineWidth',2);hold on;
plot(rgrid,ve2(:,1),'b-','LineWidth',2);
legend('Median-based','Mean-based');
axis tight;
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title([' US Interest Rate Swaps (4-year sample)']);
filename=['panel_sample4_vevtsq_elasticity_profiles'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% colors
co=[0,0,1;  0,0.5,0; 1,0,0; 0,0.75,0.75;   0.75,0,0.75; 0.75,0.75,0; 0.25,0.25,0.25;0.31,0.4,0.58];



% all median volatility profiles together
figure;
for i=1:NM
    plot(rgrid,vl(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Volatility');
title('US Interest Rate Swaps (4-year sample)');
filename=['panel_vevtsq_median_volatility_profiles_sample4'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% all mean volatility profiles together
figure;
for i=1:NM
    plot(rgrid,vl2(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Volatility');
title('US Interest Rate Swaps (4-year sample)');
filename=['panel_vevtsq_mean_volatility_profiles_sample4'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

%% 1-year subsample
% load saved samples of parameters
d=load('sigma_vevtsq_panel_sample1_chain1.txt');
T8=size(d,1);
sigma_sample=reshape(d(:,2),T8/8,8);
d=load('beta0_vevtsq_panel_sample1_chain1.txt');
beta0_sample=d(:,2);
d=load('beta1_vevtsq_panel_sample1_chain1.txt');
beta1_sample=d(:,2);
d=load('beta2_vevtsq_panel_sample1_chain1.txt');
beta2_sample=d(:,2);

% compute mean and median statistics on elsaticity coefficients
mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);

mean_beta0=mean(beta0_sample);
median_beta0=median(beta0_sample);

mean_beta1=mean(beta1_sample);
median_beta1=median(beta1_sample);

mean_beta2=mean(beta2_sample);
median_beta2=median(beta2_sample);



% implied elasticity of volatility profiles
ve=NaN(NR,1);
ve2=NaN(NR,1);
% mean/median volatility profiles
vl=NaN(NR,NM);
vl2=NaN(NR,NM);
for j=1:NR
    ve(j,1)=median_beta2*rgrid(j)^2+median_beta1*rgrid(j)+median_beta0;
    ve2(j,1)=mean_beta2*rgrid(j)^2+mean_beta1*rgrid(j)+mean_beta0;
    for i=1:NM
        vl(j,i)=median_sigma(i)*rgrid(j)^ve(j,1);
        vl2(j,i)=mean_sigma(i)*rgrid(j)^ve2(j,1);
    end
end
% median elasticity profile
figure;
plot(rgrid,ve(:,1),'r-','LineWidth',2);
axis tight;
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title([' US Interest Rate Swaps (1-year sample)']);
filename=['panel_sample1_vevtsq_median_elasticity_profile'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);
% mean elasticity profile
figure;
plot(rgrid,ve2(:,1),'r-','LineWidth',2);
axis tight;
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title([' US Interest Rate Swaps (1-year sample)']);
filename=['panel_sample1_vevtsq_mean_elasticity_profile'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);
    
% median and mean elasticity profiles together
figure;
plot(rgrid,ve(:,1),'r-','LineWidth',2);hold on;
plot(rgrid,ve2(:,1),'b-','LineWidth',2);
legend('Median-based','Mean-based');
axis tight;
xlabel('Interest Rate');
ylabel('Elasticity of Volatility');
title([' US Interest Rate Swaps (1-year sample)']);
filename=['panel_sample1_vevtsq_elasticity_profiles'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% colors
co=[0,0,1;  0,0.5,0; 1,0,0; 0,0.75,0.75;   0.75,0,0.75; 0.75,0.75,0; 0.25,0.25,0.25;0.31,0.4,0.58];



% all median volatility profiles together
figure;
for i=1:NM
    plot(rgrid,vl(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Volatility');
title('US Interest Rate Swaps (1-year sample)');
filename=['panel_vevtsq_median_volatility_profiles_sample1'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% all mean volatility profiles together
figure;
for i=1:NM
    plot(rgrid,vl2(:,i),'Color',co(i,:)); hold on;
end
axis tight;
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Interest Rate');
ylabel('Volatility');
title('US Interest Rate Swaps (1-year sample)');
filename=['panel_vevtsq_mean_volatility_profiles_sample1'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);