% process results of Panel Bayesian Variable Elasticity of Volatility model
% with quadratic ealsticity function

%% results using full sample

% load saved samples of parameters
d=load('mu_vevtsq_panel_full_chain1.txt');
T8=size(d,1);
mu_sample=reshape(d(:,2),T8/8,8);
d=load('sigma_vevtsq_panel_full_chain1.txt');
sigma_sample=reshape(d(:,2),T8/8,8);
d=load('beta0_vevtsq_panel_full_chain1.txt');
beta0_sample=d(:,2);
d=load('beta1_vevtsq_panel_full_chain1.txt');
beta1_sample=d(:,2);
d=load('beta2_vevtsq_panel_full_chain1.txt');
beta2_sample=d(:,2);
d=load('nu_vevtsq_panel_full_chain1.txt');
nu_sample=reshape(d(:,2),T8/8,8);


NMC=10000;

% compute some simple statistics
mean_mu=mean(mu_sample);
median_mu=median(mu_sample);
p025_mu=prctile(mu_sample,2.5);
p975_mu=prctile(mu_sample,97.5);
std_mu=std(mu_sample);

mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);
p025_sigma=prctile(sigma_sample,2.5);
p975_sigma=prctile(sigma_sample,97.5);
std_sigma=std(sigma_sample);

mean_beta0=mean(beta0_sample);
median_beta0=median(beta0_sample);
p025_beta0=prctile(beta0_sample,2.5);
p975_beta0=prctile(beta0_sample,97.5);
std_beta0=std(beta0_sample);

mean_beta1=mean(beta1_sample);
median_beta1=median(beta1_sample);
p025_beta1=prctile(beta1_sample,2.5);
p975_beta1=prctile(beta1_sample,97.5);
std_beta1=std(beta1_sample);

mean_beta2=mean(beta2_sample);
median_beta2=median(beta2_sample);
p025_beta2=prctile(beta2_sample,2.5);
p975_beta2=prctile(beta2_sample,97.5);
std_beta2=std(beta2_sample);

mean_nu=mean(nu_sample);
median_nu=median(nu_sample);
p025_nu=prctile(nu_sample,2.5);
p975_nu=prctile(nu_sample,97.5);
std_nu=std(nu_sample);

NM=8;
NV=6;
medians=[median_mu;median_sigma;median_beta0*ones(1,NM);median_beta1*ones(1,NM);median_beta2*ones(1,NM);median_nu];
p025=[p025_mu;p025_sigma;p025_beta1*ones(1,NM);p025_beta1*ones(1,NM);p025_beta2*ones(1,NM);p025_nu];
p975=[p975_mu;p975_sigma;p025_beta1*ones(1,NM);p975_beta1*ones(1,NM);p975_beta2*ones(1,NM);p975_nu];
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'mu','sigma','beta0','beta1','beta2','nu'};


% save posterior medians and posterior 95% confidence intervals into a file
fid=fopen('irswap_vevtsq_full_panelstats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','Posterior Median',...
    'Posterior 2.5th percentile','Posterior 97.5th percentile');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            medians(j,i),p025(j,i),p975(j,i));
    end
end
fclose(fid);

% kernel-smoothed density plots of posterior marginal densities
NK=100;

ksd=NaN(NV,NK,NM);
xsd=NaN(NV,NK,NM);

% all maturity-dependent densities
% mu
ksd_mu=NaN(NM,NK);
xsd_mu=NaN(NM,NK);
for i=1:NM
    lb=prctile(mu_sample(:,i),2.5);
    ub=prctile(mu_sample(:,i),97.5);
    il=find(mu_sample(:,i)>lb);
    gsample=mu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_mu(i,:),xsd_mu(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_mu(i,:),ksd_mu(i,:),'r-','LineWidth',2);
    xlabel('\mu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=['mu_',swap_maturity{i},'_fullpanel_ksd_vevtsq'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% sigma
ksd_sigma=NaN(NM,NK);
xsd_sigma=NaN(NM,NK);
for i=1:NM
    lb=prctile(sigma_sample(:,i),2.5);
    ub=prctile(sigma_sample(:,i),97.5);
    il=find(sigma_sample(:,i)>lb);
    gsample=sigma_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_sigma(i,:),xsd_sigma(i,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
    figure;
    plot(xsd_sigma(i,:),ksd_sigma(i,:),'r-','LineWidth',2);
    xlabel('\sigma');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=['sigma_',swap_maturity{i},'_fullpanel_ksd_vevtsq'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% nu
ksd_nu=NaN(NM,NK);
xsd_nu=NaN(NM,NK);
for i=1:NM
    lb=prctile(nu_sample(:,i),2.5);
    ub=prctile(nu_sample(:,i),97.5);
    il=find(nu_sample(:,i)>lb);
    gsample=nu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_nu(i,:),xsd_nu(i,:)]=ksdensity(fsample,'npoints',NK,'support',[1.99,130.1]);
    figure;
    plot(xsd_nu(i,:),ksd_nu(i,:),'r-','LineWidth',2);
    xlabel('\nu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (full sample)']);
    filename=['nu_',swap_maturity{i},'_fullpanel_ksd_vevtsq'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% beta0 is not maturity dependent
ksd_beta0=NaN(3,NK); % for 3 sub-samples
xsd_beta0=NaN(3,NK);
lb=prctile(beta0_sample,2.5);
ub=prctile(beta0_sample,97.5);
il=find(beta0_sample>lb);
gsample=beta0_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta0(1,:),xsd_beta0(1,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta0(1,:),ksd_beta0(1,:),'r-','LineWidth',2);
xlabel('\beta_0');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (full sample)']);
filename=['beta0_fullpanel_ksd_vevtsq'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% beta1 is not maturity dependent
ksd_beta1=NaN(3,NK); % for 3 sub-samples
xsd_beta1=NaN(3,NK);
lb=prctile(beta1_sample,2.5);
ub=prctile(beta1_sample,97.5);
il=find(beta1_sample>lb);
gsample=beta1_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta1(1,:),xsd_beta1(1,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta1(1,:),ksd_beta1(1,:),'r-','LineWidth',2);
xlabel('\beta_1');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (full sample)']);
filename=['beta1_fullpanel_ksd_vevtsq'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% beta2 is not maturity dependent
ksd_beta2=NaN(3,NK); % for 3 sub-samples
xsd_beta2=NaN(3,NK);
lb=prctile(beta2_sample,2.5);
ub=prctile(beta2_sample,97.5);
il=find(beta2_sample>lb);
gsample=beta2_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta2(1,:),xsd_beta2(1,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta2(1,:),ksd_beta2(1,:),'r-','LineWidth',2);
xlabel('\beta_2');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (full sample)']);
filename=['beta2_fullpanel_ksd_vevtsq'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

data=csvread('../data/irswap_daily_20000703_20120726.csv',1,1);
[T,N]=size(data);
dates=csvread('../data/irswap_daily_20000703_20120726.csv',1,0,[1,0,T,0]);
% last 4 years
i4=find(dates>=dates(end)-40000);
data4=data(i4,:);
T4=size(data4,1);
% last 1 year
i1=find(dates>=dates(end)-10000);
data1=data(i1,:);
T1=size(data1,1);
names={'US IRSWAPS 1y','US IRSWAPS 2y','US IRSWAPS 3y','US IRSWAPS 4y',...
    'US IRSWAPS 5y','US IRSWAPS 7y','US IRSWAPS 10y','US IRSWAPS 30y'};
TTT=T;
years=floor(dates/10000);
months=floor((dates-years*10000)/100);
days=(dates-years*10000-months*100);
T0=floor(TTT/7);
label_indices=1:T0:TTT;
N0=numel(label_indices);
date_label={};
for i=1:N0
    date_label{i}=[num2str(years(label_indices(i))),'.',num2str(months(label_indices(i))),'.',num2str(days(label_indices(i)))];
end


% plot of posterior median elasticity of volatility over time
co=[0,0,1;  0,0.5,0; 1,0,0; 0,0.75,0.75;   0.75,0,0.75; 0.75,0.75,0; 0.25,0.25,0.25;0.31,0.4,0.58];

figure;
for i=1:NM-1
    plot(median_beta0+median_beta1*data(:,i)+median_beta2*data(:,i).^2,'Color',co(i,:)); hold on;
end
plot(median_beta0+median_beta1*data(:,i)+median_beta2*data(:,i).^2,'Color',[0.31,0.4,0.58]);hold on;
axis tight;
set(gca,'XTick',label_indices);
set(gca,'XTickLabel',date_label);
xticklabel_rotate([],60,[]);
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Date');
ylabel('Median elasticity of volatility');
print('-depsc2','gammamedians_full_vevtsq_panel.eps');
print('-djpeg','gammamedians_full_vevtsq_panel.jpg');
print('-dpdf','gammamedians_full_vevtsq_panel.pdf');

save irswap_vevtsq_fullpanel_postprocess.mat


%% 4-year subsample
% load saved samples of parameters
d=load('mu_vevtsq_panel_sample4_chain1.txt');
T8=size(d,1);
mu_sample=reshape(d(:,2),T8/8,8);
d=load('sigma_vevtsq_panel_sample4_chain1.txt');
sigma_sample=reshape(d(:,2),T8/8,8);
d=load('beta0_vevtsq_panel_sample4_chain1.txt');
beta0_sample=d(:,2);
d=load('beta1_vevtsq_panel_sample4_chain1.txt');
beta1_sample=d(:,2);
d=load('beta2_vevtsq_panel_sample4_chain1.txt');
beta2_sample=d(:,2);
d=load('nu_vevtsq_panel_sample4_chain1.txt');
nu_sample=reshape(d(:,2),T8/8,8);


NMC=10000;

% compute some simple statistics
mean_mu=mean(mu_sample);
median_mu=median(mu_sample);
p025_mu=prctile(mu_sample,2.5);
p975_mu=prctile(mu_sample,97.5);
std_mu=std(mu_sample);

mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);
p025_sigma=prctile(sigma_sample,2.5);
p975_sigma=prctile(sigma_sample,97.5);
std_sigma=std(sigma_sample);

mean_beta0=mean(beta0_sample);
median_beta0=median(beta0_sample);
p025_beta0=prctile(beta0_sample,2.5);
p975_beta0=prctile(beta0_sample,97.5);
std_beta0=std(beta0_sample);

mean_beta1=mean(beta1_sample);
median_beta1=median(beta1_sample);
p025_beta1=prctile(beta1_sample,2.5);
p975_beta1=prctile(beta1_sample,97.5);
std_beta1=std(beta1_sample);

mean_beta2=mean(beta2_sample);
median_beta2=median(beta2_sample);
p025_beta2=prctile(beta2_sample,2.5);
p975_beta2=prctile(beta2_sample,97.5);
std_beta2=std(beta2_sample);

mean_nu=mean(nu_sample);
median_nu=median(nu_sample);
p025_nu=prctile(nu_sample,2.5);
p975_nu=prctile(nu_sample,97.5);
std_nu=std(nu_sample);

NM=8;
NV=6;
medians=[median_mu;median_sigma;median_beta0*ones(1,NM);median_beta1*ones(1,NM);median_beta2*ones(1,NM);median_nu];
p025=[p025_mu;p025_sigma;p025_beta1*ones(1,NM);p025_beta1*ones(1,NM);p025_beta2*ones(1,NM);p025_nu];
p975=[p975_mu;p975_sigma;p025_beta1*ones(1,NM);p975_beta1*ones(1,NM);p975_beta2*ones(1,NM);p975_nu];
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'mu','sigma','beta0','beta1','beta2','nu'};



% save posterior medians and posterior 95% confidence intervals into a file
fid=fopen('irswap_vevtsq_sample4_panelstats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','Posterior Median',...
    'Posterior 2.5th percentile','Posterior 97.5th percentile');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            medians(j,i),p025(j,i),p975(j,i));
    end
end
fclose(fid);

% kernel-smoothed density plots of posterior marginal densities
NK=100;

ksd=NaN(NV,NK,NM);
xsd=NaN(NV,NK,NM);

% all maturity-dependent densities
% mu
ksd_mu=NaN(NM,NK);
xsd_mu=NaN(NM,NK);
for i=1:NM
    lb=prctile(mu_sample(:,i),2.5);
    ub=prctile(mu_sample(:,i),97.5);
    il=find(mu_sample(:,i)>lb);
    gsample=mu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_mu(i,:),xsd_mu(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_mu(i,:),ksd_mu(i,:),'r-','LineWidth',2);
    xlabel('\mu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=['mu_',swap_maturity{i},'_sample4panel_ksd_vevtsq'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% sigma
ksd_sigma=NaN(NM,NK);
xsd_sigma=NaN(NM,NK);
for i=1:NM
    lb=prctile(sigma_sample(:,i),2.5);
    ub=prctile(sigma_sample(:,i),97.5);
    il=find(sigma_sample(:,i)>lb);
    gsample=sigma_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_sigma(i,:),xsd_sigma(i,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
    figure;
    plot(xsd_sigma(i,:),ksd_sigma(i,:),'r-','LineWidth',2);
    xlabel('\sigma');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=['sigma_',swap_maturity{i},'_sample4panel_ksd_vevtsq'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% nu
ksd_nu=NaN(NM,NK);
xsd_nu=NaN(NM,NK);
for i=1:NM
    lb=prctile(nu_sample(:,i),2.5);
    ub=prctile(nu_sample(:,i),97.5);
    il=find(nu_sample(:,i)>lb);
    gsample=nu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_nu(i,:),xsd_nu(i,:)]=ksdensity(fsample,'npoints',NK,'support',[1.99,130.1]);
    figure;
    plot(xsd_nu(i,:),ksd_nu(i,:),'r-','LineWidth',2);
    xlabel('\nu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (4-year sample)']);
    filename=['nu_',swap_maturity{i},'_sample4panel_ksd_vevtsq'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% beta0 is not maturity dependent
lb=prctile(beta0_sample,2.5);
ub=prctile(beta0_sample,97.5);
il=find(beta0_sample>lb);
gsample=beta0_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta0(2,:),xsd_beta0(2,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta0(2,:),ksd_beta0(2,:),'r-','LineWidth',2);
xlabel('\beta_0');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (4-year sample)']);
filename=['beta0_sample4panel_ksd_vevtsq'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']); 

% beta1 is not maturity dependent
lb=prctile(beta1_sample,2.5);
ub=prctile(beta1_sample,97.5);
il=find(beta1_sample>lb);
gsample=beta1_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta1(2,:),xsd_beta1(2,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta1(2,:),ksd_beta1(2,:),'r-','LineWidth',2);
xlabel('\beta_1');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (4-year sample)']);
filename=['beta1_sample4panel_ksd_vevtsq'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% beta2 is not maturity dependent
lb=prctile(beta2_sample,2.5);
ub=prctile(beta2_sample,97.5);
il=find(beta2_sample>lb);
gsample=beta2_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta2(2,:),xsd_beta2(2,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta2(2,:),ksd_beta2(2,:),'r-','LineWidth',2);
xlabel('\beta_2');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (4-year sample)']);
filename=['beta2_sample4panel_ksd_vevtsq'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% starting date of 4 year window
T04=dates(end)-40000;
i04=min(find(dates>=T04));
dates=dates(i04:end);
years=floor(dates/10000);
months=floor((dates-years*10000)/100);
days=(dates-years*10000-months*100);
T0=floor((T4)/7);
label_indices=1:T0:T4;
N0=numel(label_indices);
date_label={};
for i=1:N0
    date_label{i}=[num2str(years(label_indices(i))),'.',num2str(months(label_indices(i))),'.',num2str(days(label_indices(i)))];
end


% plot of posterior median elasticity of volatility over time
co=[0,0,1;  0,0.5,0; 1,0,0; 0,0.75,0.75;   0.75,0,0.75; 0.75,0.75,0; 0.25,0.25,0.25;0.31,0.4,0.58];

figure;
for i=1:NM-1
    plot(median_beta0+median_beta1*data4(:,i)+median_beta2*data4(:,i).^2,'Color',co(i,:)); hold on;
end
plot(median_beta0+median_beta1*data4(:,i)+median_beta2*data4(:,i).^2,'Color',[0.31,0.4,0.58]);hold on;
axis tight;
set(gca,'XTick',label_indices);
set(gca,'XTickLabel',date_label);
xticklabel_rotate([],60,[]);
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Date');
ylabel('Median elasticity of volatility');
print('-depsc2','gammamedians_sample4_vevtsq_panel.eps');
print('-djpeg','gammamedians_sample4_vevtsq_panel.jpg');
print('-dpdf','gammamedians_sample4_vevtsq_panel.pdf');

save irswap_vevtsq_sample4panel_postprocess.mat

%% 1-year subsample
% load saved samples of parameters
d=load('mu_vevtsq_panel_sample1_chain1.txt');
T8=size(d,1);
mu_sample=reshape(d(:,2),T8/8,8);
d=load('sigma_vevtsq_panel_sample1_chain1.txt');
sigma_sample=reshape(d(:,2),T8/8,8);
d=load('beta0_vevtsq_panel_sample1_chain1.txt');
beta0_sample=d(:,2);
d=load('beta1_vevtsq_panel_sample1_chain1.txt');
beta1_sample=d(:,2);
d=load('beta2_vevtsq_panel_sample1_chain1.txt');
beta2_sample=d(:,2);
d=load('nu_vevtsq_panel_sample1_chain1.txt');
nu_sample=reshape(d(:,2),T8/8,8);


NMC=10000;

% compute some simple statistics
mean_mu=mean(mu_sample);
median_mu=median(mu_sample);
p025_mu=prctile(mu_sample,2.5);
p975_mu=prctile(mu_sample,97.5);
std_mu=std(mu_sample);

mean_sigma=mean(sigma_sample);
median_sigma=median(sigma_sample);
p025_sigma=prctile(sigma_sample,2.5);
p975_sigma=prctile(sigma_sample,97.5);
std_sigma=std(sigma_sample);

mean_beta0=mean(beta0_sample);
median_beta0=median(beta0_sample);
p025_beta0=prctile(beta0_sample,2.5);
p975_beta0=prctile(beta0_sample,97.5);
std_beta0=std(beta0_sample);

mean_beta1=mean(beta1_sample);
median_beta1=median(beta1_sample);
p025_beta1=prctile(beta1_sample,2.5);
p975_beta1=prctile(beta1_sample,97.5);
std_beta1=std(beta1_sample);

mean_beta2=mean(beta2_sample);
median_beta2=median(beta2_sample);
p025_beta2=prctile(beta2_sample,2.5);
p975_beta2=prctile(beta2_sample,97.5);
std_beta2=std(beta2_sample);

mean_nu=mean(nu_sample);
median_nu=median(nu_sample);
p025_nu=prctile(nu_sample,2.5);
p975_nu=prctile(nu_sample,97.5);
std_nu=std(nu_sample);

NM=8;
NV=6;
medians=[median_mu;median_sigma;median_beta0*ones(1,NM);median_beta1*ones(1,NM);median_beta2*ones(1,NM);median_nu];
p025=[p025_mu;p025_sigma;p025_beta1*ones(1,NM);p025_beta1*ones(1,NM);p025_beta2*ones(1,NM);p025_nu];
p975=[p975_mu;p975_sigma;p025_beta1*ones(1,NM);p975_beta1*ones(1,NM);p975_beta2*ones(1,NM);p975_nu];
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
pname={'mu','sigma','beta0','beta1','beta2','nu'};



% save posterior medians and posterior 95% confidence intervals into a file
fid=fopen('irswap_vevtsq_sample1_panelstats.csv','w');
fprintf(fid,'%s,%s,%s,%s,%s\n','Swap Maturity','Parameter','Posterior Median',...
    'Posterior 2.5th percentile','Posterior 97.5th percentile');
for i=1:NM
    for j=1:NV
        fprintf(fid,'%s,%s,%7.4f,%7.4f,%7.4f\n',swap_maturity{i},pname{j},...
            medians(j,i),p025(j,i),p975(j,i));
    end
end
fclose(fid);

% kernel-smoothed density plots of posterior marginal densities
NK=100;

ksd=NaN(NV,NK,NM);
xsd=NaN(NV,NK,NM);

% all maturity-dependent densities
% mu
ksd_mu=NaN(NM,NK);
xsd_mu=NaN(NM,NK);
for i=1:NM
    lb=prctile(mu_sample(:,i),2.5);
    ub=prctile(mu_sample(:,i),97.5);
    il=find(mu_sample(:,i)>lb);
    gsample=mu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_mu(i,:),xsd_mu(i,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
    figure;
    plot(xsd_mu(i,:),ksd_mu(i,:),'r-','LineWidth',2);
    xlabel('\mu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=['mu_',swap_maturity{i},'_sample1panel_ksd_vevtsq'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% sigma
ksd_sigma=NaN(NM,NK);
xsd_sigma=NaN(NM,NK);
for i=1:NM
    lb=prctile(sigma_sample(:,i),2.5);
    ub=prctile(sigma_sample(:,i),97.5);
    il=find(sigma_sample(:,i)>lb);
    gsample=sigma_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_sigma(i,:),xsd_sigma(i,:)]=ksdensity(fsample,'npoints',NK,'support','positive');
    figure;
    plot(xsd_sigma(i,:),ksd_sigma(i,:),'r-','LineWidth',2);
    xlabel('\sigma');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=['sigma_',swap_maturity{i},'_sample1panel_ksd_vevtsq'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end
% nu
ksd_nu=NaN(NM,NK);
xsd_nu=NaN(NM,NK);
for i=1:NM
    lb=prctile(nu_sample(:,i),2.5);
    ub=prctile(nu_sample(:,i),97.5);
    il=find(nu_sample(:,i)>lb);
    gsample=nu_sample(il,i);
    iu=find(gsample<ub);
    fsample=gsample(iu);
    [ksd_nu(i,:),xsd_nu(i,:)]=ksdensity(fsample,'npoints',NK,'support',[1.99,130.1]);
    figure;
    plot(xsd_nu(i,:),ksd_nu(i,:),'r-','LineWidth',2);
    xlabel('\nu');
    ylabel('Marginal Posterior Density');
    title([swap_maturity{i},' US Interest Rate Swaps (1-year sample)']);
    filename=['nu_',swap_maturity{i},'_sample1panel_ksd_vevtsq'];
    print('-depsc2',[filename,'.eps']);
    print('-djpeg',[filename,'.jpg']);
    print('-dpdf',[filename,'.pdf']);
end

% beta0 is not maturity dependent
lb=prctile(beta0_sample,2.5);
ub=prctile(beta0_sample,97.5);
il=find(beta0_sample>lb);
gsample=beta0_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta0(3,:),xsd_beta0(3,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta0(3,:),ksd_beta0(3,:),'r-','LineWidth',2);
xlabel('\beta_0');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (1-year sample)']);
filename=['beta0_sample1panel_ksd_vevtsq'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% beta1 is not maturity dependent
lb=prctile(beta1_sample,2.5);
ub=prctile(beta1_sample,97.5);
il=find(beta1_sample>lb);
gsample=beta1_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta1(3,:),xsd_beta1(3,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta1(3,:),ksd_beta1(3,:),'r-','LineWidth',2);
xlabel('\beta_1');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (1-year sample)']);
filename=['beta1_sample1panel_ksd_vevtsq'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% beta2 is not maturity dependent
lb=prctile(beta2_sample,2.5);
ub=prctile(beta2_sample,97.5);
il=find(beta2_sample>lb);
gsample=beta2_sample(il);
iu=find(gsample<ub);
fsample=gsample(iu);
[ksd_beta2(3,:),xsd_beta2(3,:)]=ksdensity(fsample,'npoints',NK,'support','unbounded');
figure;
plot(xsd_beta2(3,:),ksd_beta2(3,:),'r-','LineWidth',2);
xlabel('\beta_2');
ylabel('Marginal Posterior Density');
title(['US Interest Rate Swaps (1-year sample)']);
filename=['beta2_sample1panel_ksd_vevtsq'];
print('-depsc2',[filename,'.eps']);
print('-djpeg',[filename,'.jpg']);
print('-dpdf',[filename,'.pdf']);

% starting date of 1 year window
T01=dates(end)-10000;
i01=min(find(dates>=T01));
dates=dates(i01:end);
years=floor(dates/10000);
months=floor((dates-years*10000)/100);
days=(dates-years*10000-months*100);
T0=floor((T1)/7);
label_indices=1:T0:T1;
N0=numel(label_indices);
date_label={};
for i=1:N0
    date_label{i}=[num2str(years(label_indices(i))),'.',num2str(months(label_indices(i))),'.',num2str(days(label_indices(i)))];
end



% plot of posterior median elasticity of volatility over time
co=[0,0,1;  0,0.5,0; 1,0,0; 0,0.75,0.75;   0.75,0,0.75; 0.75,0.75,0; 0.25,0.25,0.25;0.31,0.4,0.58];

figure;
for i=1:NM-1
    plot(median_beta0+median_beta1*data1(:,i)+median_beta2*data1(:,i).^2,'Color',co(i,:)); hold on;
end
plot(median_beta0+median_beta1*data1(:,i)+median_beta2*data1(:,i).^2,'Color',[0.31,0.4,0.58]);hold on;
axis tight;
set(gca,'XTick',label_indices);
set(gca,'XTickLabel',date_label);
xticklabel_rotate([],60,[]);
legend('1y','2y','3y','4y','5y','7y','10y','30y');
xlabel('Date');
ylabel('Median elasticity of volatility');
print('-depsc2','gammamedians_sample1_vevtsq_panel.eps');
print('-djpeg','gammamedians_sample1_vevtsq_panel.jpg');
print('-dpdf','gammamedians_sample1_vevtsq_panel.pdf');


save irswap_vevtsq_sample1panel_postprocess.mat

% all maturity independent parameters together
figure;
% beta0
subplot(3,1,1);
plot(xsd_beta0(1,:),ksd_beta0(1,:),'r-','LineWidth',2);hold on;
plot(xsd_beta0(2,:),ksd_beta0(2,:),'b-','LineWidth',2);hold on;
plot(xsd_beta0(3,:),ksd_beta0(3,:),'g-','LineWidth',2);
xlabel('\beta_0');
ylabel('Marginal Posterior Density');
legend('Full sample','4-year sample','1-year sample');
% beta1
subplot(3,1,2);
plot(xsd_beta1(1,:),ksd_beta1(1,:),'r-','LineWidth',2);hold on;
plot(xsd_beta1(2,:),ksd_beta1(2,:),'b-','LineWidth',2);hold on;
plot(xsd_beta1(3,:),ksd_beta1(3,:),'g-','LineWidth',2);
xlabel('\beta_1');
ylabel('Marginal Posterior Density');
legend('Full sample','4-year sample','1-year sample');
% beta2
subplot(3,1,3);
plot(xsd_beta2(1,:),ksd_beta2(1,:),'r-','LineWidth',2);hold on;
plot(xsd_beta2(2,:),ksd_beta2(2,:),'b-','LineWidth',2);hold on;
plot(xsd_beta2(3,:),ksd_beta2(3,:),'g-','LineWidth',2);
xlabel('\beta_2');
ylabel('Marginal Posterior Density');
legend('Full sample','4-year sample','1-year sample');
print('-depsc2','betas_ksd_vevtsq_panel.eps');
print('-djpeg','betas_ksd_vevtsq_panel.eps');
print('-depsc2','betas_ksd_vevtsq_panel.eps');