% compute log-likelihood function for driftless cev process with Student t innovations
% INPUTS
% r0        = initial value
% r(1:T)    = sample, purpotedly from CEV with Student t innovations
% sigma     = scale of variance
% beta      = logit slope coeff in elasticity of variance
% c         = logit intercept coeff in elasticity of variance
% nu        = degrees of freedom parameter
% OUTPUTS
% L         = log-likelihood function

function L = logitvev_t_loglik(r0,r,sigma,beta,c,nu)

alpha=1./(1+exp(-beta*r+c));
alpha0=1./(1+exp(-beta*r0+c));
L=log(tpdf((r(1)-r0)/(sigma*r0^alpha0),nu)/(sigma*r0^alpha0));
L=L+nansum(log(tpdf(diff(r)./(sigma.*r(1:end-1).^alpha(1:end-1)),nu)./(sigma.*r(1:end-1).^alpha(1:end-1))));
