% testing atanvev3_t_loglik function

% generate artificial time-series from the model
T=1024;
r0=2.9;
sigmabar=0.2;
mu=0.01;
gamma=0.75;
nu=2.5;
beta1=0.01;
beta2=0.5;
[r,sigma] = atanvev3_t_simulator(T,mu,sigmabar,beta1,beta2,nu,r0);
% regime counts
['CEV Regime  ','Difference Regime  ','Return Regime  ']
disp([sum(sigma<sigmabar),sum(sigma==sigmabar),sum(sigma>sigmabar)]);

% evaluate loglikelihood of the sample
L=atanvev3_t_loglik(r0,r,mu,sigmabar,beta1,beta2,nu)

% evaluate loglikelihood on a one-dimensional slice surrounding true values
N=64;% slice size
% mu slice
mu_grid=linspace(-2,6,N);
Ln_mu=NaN(N,1);
Lt_mu=NaN(N,1);
for i=1:N
    Ln_mu(i)=atanvev3_normal_loglik(r0,r,mu_grid(i),sigmabar,beta1,beta2);
    Lt_mu(i)=atanvev3_t_loglik(r0,r,mu_grid(i),sigmabar,beta1,beta2,nu);
end
figure1=figure;
set(figure1,'DefaultTextInterpreter','tex');
plot(mu_grid,Ln_mu,'b-'); hold on;
plot(mu_grid,Lt_mu,'m-'); hold on;
plot(mu,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;legend('Normal','Student t');
v=axis;
l0=line([mu,mu],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\mu');
ylabel('Log-likelihood');

% sigmabar slice
sigmabar_grid=logspace(-1.5,1,N);
Ln_sigmabar=NaN(N,1);
Lt_sigmabar=NaN(N,1);
for i=1:N
    Ln_sigmabar(i)=atanvev3_normal_loglik(r0,r,mu,sigmabar_grid(i),beta1,beta2);
    Lt_sigmabar(i)=atanvev3_t_loglik(r0,r,mu,sigmabar_grid(i),beta1,beta2,nu);
end
figure3=figure;
set(figure3,'DefaultTextInterpreter','tex');
plot(log(sigmabar_grid),Ln_sigmabar,'b-'); hold on;
plot(log(sigmabar_grid),Lt_sigmabar,'m-'); hold on;
plot(log(sigmabar),L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;
v=axis;legend('Normal','Student t');
l0=line([log(sigmabar),log(sigmabar)],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('log \sigma');
ylabel('Log-likelihood');

% beta1 slice
beta1_grid=linspace(-0.5,1.5,N);
Ln_beta1=NaN(N,1);
Lt_beta1=NaN(N,1);
for i=1:N
    Ln_beta1(i)=atanvev3_normal_loglik(r0,r,mu,sigmabar,beta1_grid(i),beta2);
    Lt_beta1(i)=atanvev3_t_loglik(r0,r,mu,sigmabar,beta1_grid(i),beta2,nu);
end
figure4=figure;
set(figure4,'DefaultTextInterpreter','tex');
plot(beta1_grid,Ln_beta1,'b-'); hold on;
plot(beta1_grid,Lt_beta1,'m-'); hold on;
plot(beta1,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;legend('Normal','Student t');
v=axis;
l0=line([beta1,beta1],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\beta_1');
ylabel('Log-likelihood');

% beta2 slice
beta2_grid=linspace(-0.5,1.0,N);
Ln_beta2=NaN(N,1);
Lt_beta2=NaN(N,1);
for i=1:N
    Ln_beta2(i)=atanvev3_normal_loglik(r0,r,mu,sigmabar,beta1,beta2_grid(i));
    Lt_beta2(i)=atanvev3_t_loglik(r0,r,mu,sigmabar,beta1,beta2_grid(i),nu);
end
figure4=figure;
set(figure4,'DefaultTextInterpreter','tex');
plot(beta2_grid,Ln_beta2,'b-'); hold on;
plot(beta2_grid,Lt_beta2,'m-'); hold on;
plot(beta2,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;legend('Normal','Student t');
v=axis;
l0=line([beta2,beta2],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\beta_2');
ylabel('Log-likelihood');

% nu slice
nu_grid=linspace(1,32,N);
Ln_nu=NaN(N,1);
Lt_nu=NaN(N,1);
for i=1:N
    Ln_nu(i)=atanvev3_normal_loglik(r0,r,mu,sigmabar,beta1,beta2);
    Lt_nu(i)=atanvev3_t_loglik(r0,r,mu,sigmabar,beta1,beta2,nu_grid(i));
end
figure4=figure;
set(figure4,'DefaultTextInterpreter','tex');
plot(nu_grid,Ln_nu,'b-'); hold on;
plot(nu_grid,Lt_nu,'m-'); hold on;
plot(nu,L,'MarkerSize',30,'Marker','.','LineStyle','none','Color','r');
hold on;legend('Normal','Student t');
v=axis;
l0=line([nu,nu],[v(3),v(4)]);
set(l0,'Color','r','LineStyle','--');
xlabel('\nu');
ylabel('Log-likelihood');