% testing atanvev3_t_mle function

% generate artificial time-series from the model
T=10240;
r0=2.9;
sigmabar=0.02;
mu=-0.0001;
nu=3.5;
beta1=2.51;
beta2=-0.5;
[r,sigma] = atanvev3_t_simulator(T,mu,sigmabar,beta1,beta2,nu,r0);
figure;
plot(r);axis tight;
xlabel('t');
ylabel('r');

% regime counts
['CEV Regime  ','Difference Regime  ','Return Regime  ']
disp([sum(sigma<sigmabar),sum(sigma==sigmabar),sum(sigma>sigmabar)]);


% evaluate loglikelihood of the sample at true parameters
L=atanvev3_t_loglik(r0,r,mu,sigmabar,beta1,beta2,nu);

% estimate
alpha=0.05; % significance level
start=[0,log(std(diff(r))),1,0,8];


[p,ci,aic] = atanvev3_t_mle(r,alpha,start);
% report
disp(['   True mu             ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([mu, p(1),ci(1,1),ci(2,1)]);
disp(['   True sigmabar       ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([sigmabar, p(2),ci(1,2),ci(2,2)]);
disp(['   True beta1          ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([beta1, p(3),ci(1,3),ci(2,3)]);
disp(['   True beta2          ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([beta2, p(4),ci(1,4),ci(2,4)]);
disp(['   True nu             ','Estimator           ','Lower Bound         ','Upper Bound        ']);
disp([nu, p(5),ci(1,5),ci(2,5)]);

% test convergence of estimates
T0=1024;
dT=128;
TF=linspace(T0,T,(T-T0)/dT+1);
NT=size(TF,2);
pt=NaN(NT,5);
cit=NaN(2,5,NT);
aict=NaN(NT,1);
for t=1:NT
    [t,TF(t)]
    [pt(t,:),cit(:,:,t),aict(t)] = atanvev3_t_mle(r(1:TF(t)),alpha,start);
end

% convergence of mean and scale of volatility
figure;
subplot(2,1,1)
plot(TF,pt(:,1),'r-'); hold on;
plot(TF,ones(size(TF))*mu,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \mu');
subplot(2,1,2);
plot(TF,pt(:,2),'r-'); hold on;
plot(TF,ones(size(TF))*sigmabar,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \sigma');

% convergence of estimates of beta1 and beta2
figure;
subplot(2,1,1);
plot(TF,pt(:,3),'r-'); hold on;
plot(TF,ones(size(TF))*beta1,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \beta_1');
subplot(2,1,2);
plot(TF,pt(:,4),'r-'); hold on;
plot(TF,ones(size(TF))*beta2,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \beta_2');

% convergence of estimates of nu
figure;
plot(TF,pt(:,5),'r-'); hold on;
plot(TF,ones(size(TF))*nu,'b--');axis tight
xlabel('Sample Size');
ylabel('Estimated \nu');

