% latex tables
swap_maturity={'1y','2y','3y','4y','5y','7y','10y','30y'};
varnames={'$\mu$','$\sigma$','\beta_0$','$\beta_1$','$\beta_2$','$\nu$'};
N=8;
NV=6;

% version without panel restrictions
params=csvread('irswap_vevtsq_full_stats.csv',1,2);
params4=csvread('irswap_vevtsq_sample4_stats.csv',1,2);
params1=csvread('irswap_vevtsq_sample1_stats.csv',1,2);



FID = fopen('vevtsq_results.tex', 'w');
fprintf(FID, '\\begin{tabular}{clrrrrrr}\\hline\n');
fprintf(FID,'\\multirow{3}{1.1cm}{Swap Maturity} & \\multirow{3}{*}{Parameter} & \\multicolumn{2}{c}{Full Sample} & \\multicolumn{2}{c}{4-year Window} & \\multicolumn{2}{c}{1-year Window}\\\\ \n');
fprintf(FID,'\\cline{3-8} & & {Posterior} & Posterior & {Posterior} & Posterior& {Posterior} & Posterior  \\\\ \n');
fprintf(FID, ' & & {Median} & 95\\%% Bounds & {Median} & 95\\%% Bounds & {Median} & 95\\%% Bounds \\\\ \n');
fprintf(FID,'\\hline\\hline \n');
for i=1:N
    for j=1:NV
        if j==3
            fprintf(FID,'%s & %s & %7.3f &(%7.3f,%7.3f) & %7.3f &(%7.3f,%7.3f) & %7.3f &(%7.3f,%7.3f) \\\\ \n',...
                swap_maturity{i},varnames{j},params((i-1)*NV+j,1),params((i-1)*NV+j,2),params((i-1)*NV+j,3),...
                params4((i-1)*NV+j,1),params4((i-1)*NV+j,2),params4((i-1)*NV+j,3),...
                params1((i-1)*NV+j,1),params1((i-1)*NV+j,2),params1((i-1)*NV+j,3));
        else
            fprintf(FID,'& %s & %7.3f &(%7.3f,%7.3f) & %7.3f &(%7.3f,%7.3f) & %7.3f &(%7.3f,%7.3f) \\\\ \n',...
                varnames{j},params((i-1)*NV+j,1),params((i-1)*NV+j,2),params((i-1)*NV+j,3),...
                params4((i-1)*NV+j,1),params4((i-1)*NV+j,2),params4((i-1)*NV+j,3),...
                params1((i-1)*NV+j,1),params1((i-1)*NV+j,2),params1((i-1)*NV+j,3));
        end
        if j==5
            fprintf(FID,'\\hline\n');
        end
    end
end

 
fprintf(FID, '\\end{tabular}\n');
fclose(FID);

% panel version with common betas
clear params params1 params4
params=csvread('irswap_vevtsq_full_panelstats.csv',1,2);
params4=csvread('irswap_vevtsq_sample4_panelstats.csv',1,2);
params1=csvread('irswap_vevtsq_sample1_panelstats.csv',1,2);

FID = fopen('vevtsq_panel_results.tex', 'w');
fprintf(FID, '\\begin{tabular}{crrrrrrr}\\hline\n');
fprintf(FID,'\\multirow{3}{*}{Swap Maturity} & \\multirow{3}{*}{Parameter} & \\multicolumn{2}{c}{Full Sample} & \\multicolumn{2}{c}{4-year Window} & \\multicolumn{2}{c}{1-year Window}\\\\ \n');
fprintf(FID,'\\cline{3-8} & & {Posterior} & Posterior & {Posterior} & Posterior& {Posterior} & Posterior  \\\\ \n');
fprintf(FID, ' & & {Median} & 95\\%% Bounds & {Median} & 95\\%% Bounds & {Median} & 95\\%% Bounds \\\\ \n');
fprintf(FID,'\\hline\\hline \n');
for i=1:N
    for j=1:NV
        if j==2 % sigma row
            fprintf(FID,'%s & %s & %7.3f &(%7.3f,%7.3f) & %7.3f &(%7.3f,%7.3f) & %7.3f &(%7.3f,%7.3f) \\\\ \n',...
                swap_maturity{i},varnames{j},params((i-1)*NV+j,1),params((i-1)*NV+j,2),params((i-1)*NV+j,3),...
                params4((i-1)*NV+j,1),params4((i-1)*NV+j,2),params4((i-1)*NV+j,3),...
                params1((i-1)*NV+j,1),params1((i-1)*NV+j,2),params1((i-1)*NV+j,3));
        elseif (j~=3&j~=4&j~=5) % skip beta0, beta1 and beta2 rows
            fprintf(FID,'& %s & %7.3f &(%7.3f,%7.3f) & %7.3f &(%7.3f,%7.3f) & %7.3f &(%7.3f,%7.3f) \\\\ \n',...
                varnames{j},params((i-1)*NV+j,1),params((i-1)*NV+j,2),params((i-1)*NV+j,3),...
                params4((i-1)*NV+j,1),params4((i-1)*NV+j,2),params4((i-1)*NV+j,3),...
                params1((i-1)*NV+j,1),params1((i-1)*NV+j,2),params1((i-1)*NV+j,3));
        end
        if j==NV
            fprintf(FID,'\\hline\n');
        end
    end
end
% add beta0, beta1 and beta2 rows
i=1;
for j=3:5
   fprintf(FID,'& %s & %7.3f &(%7.3f,%7.3f) & %7.3f &(%7.3f,%7.3f) & %7.3f &(%7.3f,%7.3f) \\\\ \n',...
                varnames{j},params((i-1)*NV+j,1),params((i-1)*NV+j,2),params((i-1)*NV+j,3),...
                params4((i-1)*NV+j,1),params4((i-1)*NV+j,2),params4((i-1)*NV+j,3),...
                params1((i-1)*NV+j,1),params1((i-1)*NV+j,2),params1((i-1)*NV+j,3));
end
fprintf(FID,'\\hline\n');
fprintf(FID, '\\end{tabular}\n');
fclose(FID);

